<?php

class OSF_Import {
    private $config, $path_rev, $homepage, $blogpage, $settings, $templates;

    public function __construct() {
        if (is_admin()) {
            $this->path_rev = trailingslashit(wp_upload_dir()['basedir']) . 'opal_rev_sliders_import/';
            add_action('after_setup_theme', array($this, 'init'));
        }
    }

    public function init() {
        $this->init_hooks();
        add_filter('pt-ocdi/disable_pt_branding', '__return_true');
    }

    public function init_hooks() {
        add_action('osf_before_import_customizer', array($this, 'reset_theme_mods'));
        if (get_option('otf-oneclick-first-import', 'yes') === 'yes') {
            add_filter('pt-ocdi/import_files', array($this, 'import_file_base'));
            add_action('pt-ocdi/after_import', array($this, 'after_import_setup'));
            add_action('pt-ocdi/after_import', array($this, 'after_import_setup_base'), 20);
        } else {
            add_filter('pt-ocdi/import_files', array($this, 'import_files'));
            add_action('pt-ocdi/after_import', array($this, 'after_import_setup'));
            add_filter('pt-ocdi/enable_grid_layout_import_popup_confirmation', '__return_false');
            add_filter('otf-ocdi/reload_page', '__return_false');
        }
    }

    public function import_file_base() {
        $this->init_data();
        $imports   = array();
        $import    = array(
            'import_file_name'  => 'Home 1',
            'local_import_file' => trailingslashit(AUROS_CORE_PLUGIN_DIR) . 'dummy-data/content.xml',
            'import_notice'     => 'Basic import includes default version from our demo and a few products, blog posts and portfolio projects. It is a required minimum to see how our theme built and to be able to import additional versions or pages.',
            'slug'              => '1',
            'customizer'        => esc_url('http://source.wpopal.com/auros/dummy_data/auros/customizer.json'),
            'elementor'         => esc_url('http://source.wpopal.com/auros/dummy_data/auros/elementor.json'),
            'settings'          => esc_url('http://source.wpopal.com/auros/dummy_data/auros/settings.json'),

        );
        $imports[] = $import;

        return $imports;
    }

    public function import_files() {
        $this->init_data();
        $imports = array();
        if (!empty($this->config) && $this->config) {
            foreach ($this->config as $key => $item) {
                $import = array(
                    'import_file_name'         => $item['name'],
                    'import_preview_image_url' => $item['screenshot'],
                    'slug'                     => $key,
                    'settings'                 => esc_url('http://source.wpopal.com/auros/dummy_data/auros/settings.json')
                );

                if (isset($item['customizer'])) {
                    $import['customizer'] = $item['customizer'];
                }

                if (isset($item['xml'])) {
                    $import['import_file_url'] = $item['xml'];
                }

                $imports[] = $import;
            }
        }
        return $imports;
    }

    private function init_data() {

        $this->config   = $this->get_data_config();
        $this->blogpage = osf_get_page_by_title('Blog ');
    }

    public function after_import_setup_base($selected_import) {
        update_option('show_on_front', 'page');
        update_option('page_on_front', (($this->homepage instanceof WP_Post) ? $this->homepage->ID : 0));
        update_option('page_for_posts', (($this->blogpage instanceof WP_Post) ? $this->blogpage->ID : 0));
        update_option('otf-oneclick-first-import', 'no');

        // Setup Customizer
        $this->reset_theme_mods();
        $thememods = $this->get_remote_json($selected_import['customizer'], true);
        foreach ($thememods as $mod => $value) {
            set_theme_mod($mod, $value);
        }

        // Setup Elementor
        $this->fixelementor();
        $elementor      = $this->get_remote_json($selected_import['elementor'], true);
        if (osf_is_elementor_activated()) {
//            $this->updateElementor();
            foreach ($elementor as $key => $value) {
                update_option($key, $value);
            }
        }

        $this->setup_elementor_global();
        // Breadcrumb
        update_option('bcn_options', $this->settings['breadcrumb']);


        // Update Logo
        set_theme_mod('custom_logo', 4309);
        set_post_thumbnail(1, 4243);
    }


    public function after_import_setup($selected_import) {
        if (isset($this->config[$selected_import['slug']])) {

            $this->homepage = osf_get_page_by_title($selected_import['import_file_name']);

            $setup = $this->config[$selected_import['slug']];
            // REVSLIDER
            if ($sliders = $setup['rev_sliders']) {
                if (class_exists('RevSliderAdmin')) {
                    if (!file_exists($this->path_rev)) {
                        wp_mkdir_p($this->path_rev);
                    }
                    foreach ($sliders as $slider) {
                        $this->add_revslider($slider);
                    }
                }
            }

            // Setup Customizer
            remove_theme_mod('osf_theme_custom_style');
            $thememods = $this->get_remote_json($selected_import['customizer'], true);
            foreach ($thememods as $mod => $value) {
                set_theme_mod($mod, $value);
            }


            $this->setup_home_page($selected_import['slug']);

            $this->settings  = $this->get_remote_json($setup['settings'], true);
            $this->templates = $this->settings['templates'];


            // Setup Home page
            update_option('page_on_front', (($this->homepage instanceof WP_Post) ? $this->homepage->ID : 0));

            // Mailchimp
            $mailchimp = osf_get_page_by_title('Opal MailChimp', OBJECT, 'mc4wp-form');
            if ($mailchimp) {
                update_option('mc4wp_default_form_id', $mailchimp->ID);
            }
        }
        set_theme_mod('osf_dev_mode', false);
    }

    private function add_revslider($slider) {
        $dest_rev = $this->path_rev . basename($slider);
        if (!file_exists($dest_rev)) {
            file_put_contents($dest_rev, fopen($slider, 'r'));
            $_FILES['import_file']['error']    = UPLOAD_ERR_OK;
            $_FILES['import_file']['tmp_name'] = $dest_rev;

            $revslider = new RevSlider();
            $revslider->importSliderFromPost(true, 'none');
        }
    }

    public function setup_elementor_global() {
        $json
            = '
				{
				    "system_colors": [
				        {
				            "_id": "primary",
				            "title": "Primary",
				            "color": "#EB7025"
				        },
				        {
				            "_id": "secondary",
				            "title": "Secondary",
				            "color": "#FFD8D4"
				        },
				        {
				            "_id": "text",
				            "title": "Text",
				            "color": "#666666"
				        },
				        {
				            "_id": "accent",
				            "title": "Heading",
				            "color": "#222222"
				        }
				    ],
				    "custom_colors": [],
				    "system_typography": [
				        {
				            "_id": "primary",
				            "title": "Primary",
				            "typography_typography": "custom"
				        },
				        {
				            "_id": "secondary",
				            "title": "Secondary",
				            "typography_typography": "custom"
				        },
				        {
				            "_id": "text",
				            "title": "Text",
				            "typography_typography": "custom"
				        },
				        {
				            "_id": "accent",
				            "title": "Accent",
				            "typography_typography": "custom"
				        }
				    ],
				    "container_width": {
                        "unit": "px",
                        "size": 1360,
                        "sizes": []
                    },
				    "custom_typography": [],
				    "default_generic_fonts": "Sans-serif",
				    "site_name": "Wordpress One-Click",
				    "site_description": "Just another WordPress site",
				    "page_title_selector": "h1.entry-title",
				    "activeItemIndex": 1
				}';


        $options = json_decode( $json, true );
        $id      = Elementor\Plugin::$instance->kits_manager->get_active_id();
        update_post_meta( $id, '_elementor_page_settings', $options );
    }

    /**
     * @param $link
     *
     * @return object|boolean
     */
    private function get_remote_json($link, $assoc = false) {
        $content = wp_remote_get($link);
        if ($content instanceof WP_Error) {
            return false;
        }

        return json_decode($content['body'], $assoc);
    }

    public function reset_theme_mods() {
        $mods = json_decode(file_get_contents(trailingslashit(AUROS_CORE_PLUGIN_DIR) . 'reset-theme-mods.json'));
        foreach ($mods as $mod) {
            remove_theme_mod($mod);
        }
    }

    private function updateElementor() {
        $query = new WP_Query(array(
            'post_type'      => [
                'page',
                'elementor_library',
                'header',
                'footer'
            ],
            'posts_per_page' => -1
        ));
        while ($query->have_posts()): $query->the_post();
            $postid = get_the_ID();
            if (get_post_meta($postid, '_elementor_edit_mode', true) === 'builder') {
                $data = json_decode(get_post_meta($postid, '_elementor_data', true), true);
                $data = $this->updateElementorData($data);
                update_post_meta($postid, '_elementor_data', wp_slash(wp_json_encode($data)));
            }
        endwhile;
        wp_reset_postdata();
    }

    private function updateElementorData($datas) {
        if (count($datas) <= 0) {
            return $datas;
        }
        foreach ($datas as $key => $data) {

            // Contact Form
            if (!empty($data['widgetType']) && $data['widgetType'] === 'opal-contactform7') {
                $data['settings']['cf_id'] = $this->get_contact_form_id(absint($data['settings']['cf_id']));
            }

            if (!empty($data['elements'])) {
                $data['elements'] = $this->updateElementorData($data['elements']);
            }
            $datas[$key] = $data;
        }

        return $datas;
    }

    private function get_contact_form_id($id) {
        $contact = osf_get_page_by_title($this->settings['contact'][$id], OBJECT, 'wpcf7_contact_form');
        if ($contact) {
            return $contact->ID;
        }
        return $id;
    }

    private function setup_home_page($slug) {
        if ($slug == '16') {
            set_theme_mod('osf_woocommerce_product_style', '5');
        } else {
            remove_theme_mod('osf_woocommerce_product_style');
        }
    }

    private function fixelementor() {
        $datas = $this->get_data_elementor();
        $query = new WP_Query( array(
            'post_type'      => [
                'page',
                'post',
                'elementor_library',
                'header',
                'footer',
                'opal_menu_item'
            ],
            'posts_per_page' => - 1
        ) );
        while ( $query->have_posts() ): $query->the_post();
            global $post;
            $postid = get_the_ID();
            if ( get_post_meta( $post->ID, '_elementor_edit_mode', true ) === 'builder' ) {
                $data = json_decode( get_post_meta( $postid, '_elementor_data', true ) );
                if ( ! boolval( $data ) ) {
                    if ( isset( $datas[ $post->post_name ] ) ) {
                        update_post_meta( $postid, '_elementor_data', wp_slash( wp_json_encode( $datas[ $post->post_name ] ) ) );
                    }
                }
            }
        endwhile;
        wp_reset_postdata();
    }

    private function get_data_config() {
        return json_decode('{"1":{"name":"Home 1","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-1.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-1/home1_slider2.zip","http://source.wpopal.com/auros/dummy_data/revsliders/home-1/home1.zip"]},"2":{"name":"Home 2","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-2.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-2/home2.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-2.xml"},"3":{"name":"Home 3","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-3.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-3/home3.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-3.xml"},"4":{"name":"Home 4","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-4.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-4/home4.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-4.xml"},"5":{"name":"Home 5","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-5.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-5/home_5.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-5.xml"},"6":{"name":"Home 6","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-6.jpg","xml":"http://source.wpopal.com/auros/dummy_data/auros/home-6.xml"},"7":{"name":"Home 7","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-7.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-7/home7.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-7.xml"},"8":{"name":"Home 8","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-8.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-8/home8.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-8.xml"},"9":{"name":"Home 9","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-9.jpg","xml":"http://source.wpopal.com/auros/dummy_data/auros/home-9.xml"},"10":{"name":"Home 10","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-10.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-10/home_10.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-10.xml"},"11":{"name":"Home 11","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-11.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-11/home_11_slider.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-11.xml"},"12":{"name":"Home 12","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-12.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-12/home-12.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-12.xml"},"13":{"name":"Home 13","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-13.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-13/home13.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-13.xml"},"14":{"name":"Home 14","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-14.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-14/home14.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-14.xml"},"15":{"name":"Home 15","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-15.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-15/home15.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-15.xml"},"16":{"name":"Home 16","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-16.jpg","xml":"http://source.wpopal.com/auros/dummy_data/auros/home-16.xml"},"17":{"name":"Home 17","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-17.jpg","xml":"http://source.wpopal.com/auros/dummy_data/auros/home-17.xml"},"18":{"name":"Home 18","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-18.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-18/home-18.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-18.xml"},"19":{"name":"Home 19","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-19.jpg","xml":"http://source.wpopal.com/auros/dummy_data/auros/home-19.xml"},"20":{"name":"Home  20","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-20.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-20/slider-home20.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-20.xml"},"21":{"name":"Home 21","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-21.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-21/slider-home21.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-21.xml"},"22":{"name":"Home 22","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-22.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-22/slider_home22.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-22.xml"},"23":{"name":"Home 23","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-23.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-23/slider_home22.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-23.xml"},"24":{"name":"Home 24","screenshot":"http://source.wpopal.com/auros/dummy_data/auros/home-24.jpg","rev_sliders":["http://source.wpopal.com/auros/dummy_data/revsliders/home-24/home-24.zip"],"xml":"http://source.wpopal.com/auros/dummy_data/auros/home-24.xml"}}',true);
    }

    private function get_data_elementor(){
        return json_decode('{"footer-01":[{"id":"ccce7da","elType":"section","settings":{"gap":"no","structure":"40","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false}},"elements":[{"id":"4cd3170","elType":"column","settings":{"_column_size":25,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":50,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"eac5df6","elType":"widget","settings":{"align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"},{"id":"86eca5e","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska Badalas <br \/>United State<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"acee6ae","elType":"widget","settings":{"editor":"<p>(+91)7-723-4608<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"67e042c","elType":"widget","settings":{"text":"Aurosfurniture@domain.vn","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":""},"button_text_color":"#222222","background_color":"rgba(0,0,0,0)","hover_color":"#eb7025","button_hover_border_color":"#eb7025","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"f3bc02a","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"d343675","elType":"widget","settings":{"title":"Our Products","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"55","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_font_weight":"600"},"elements":[],"widgetType":"heading"},{"id":"ac45543","elType":"widget","settings":{"menu":"acount","layout":"vertical","align_items":"left","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#666666","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":20},"align_items_mobile":"center","menu-toggle-title":"Menu","menu_space_between_mobile":{"unit":"px","size":10}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"0c3aff9","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"5cfe51c","elType":"widget","settings":{"title":"Useful Links","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"55","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"7d6a447","elType":"widget","settings":{"menu":"company","layout":"vertical","align_items":"left","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#666666","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":20},"align_items_mobile":"center","menu-toggle-title":"Menu","menu_space_between_mobile":{"unit":"px","size":10}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"c67eff6","elType":"column","settings":{"_column_size":25,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"9e5db64","elType":"widget","settings":{"title":"Newsletter","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_tablet":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"0e024ed","elType":"widget","settings":{"editor":"<p>Stay Updated on all that\'s new add noteworthy<\/p>","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_tablet":"center"},"elements":[],"widgetType":"text-editor"},{"id":"e18645f","elType":"widget","settings":{"hide_icon":"none","spacing_icon":{"unit":"px","size":0},"width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"input_bacground":"rgba(255,255,255,0.01)","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"button_bacground":"rgba(0,0,0,0)","button_color":"#222222","border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_button_color":"#dddddd","button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"button_margin":{"unit":"%","top":"0","right":"0","bottom":"0","left":"2","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"align_input_mobile":"center","input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_color_hover":"#eb7025","button_border_hover":"#eb7025","button_color_focus":"#eb7025","button_border_focus":"#eb7025","button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"27","left":"0","isLinked":false},"placeholder_color":"#666666"},"elements":[],"widgetType":"opal-mailchmip"},{"id":"eb8f6cb","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"d3bc26e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"4c628cc","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"0100f2f"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"fcab8b4"}],"shape":"square","align":"left","align_tablet":"center","align_mobile":"center","icon_color":"custom","icon_primary_color":"rgba(136,136,136,0)","icon_secondary_color":"#888888","icon_size":{"unit":"px","size":16},"icon_padding":{"unit":"em","size":0},"icon_spacing":{"unit":"px","size":12},"hover_primary_color":"rgba(0,0,0,0)","hover_secondary_color":"#eb7025","hover_animation":"pulse"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"9983033","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false}},"elements":[{"id":"04e2ab1","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"def8a90","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<a href=\"#\"><span style=\"color: #222222;\"><strong>Auros<\/strong><\/span><\/a>. All rights reserved.<\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"3f60676","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"69ea588","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/09\/paypal.png","id":1470},"image_size":"full","align":"right","align_mobile":"center"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"product-tab":[{"id":"642565d9","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"65","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"176ffb47","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"4e44ebf1","elType":"widget","settings":{"title":"New Design","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-40","left":"0","isLinked":false},"align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_padding":{"unit":"%","top":"0","right":"50","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"3d2ee6b5","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"ac6196c","tab_template":"2184"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"08344e0","tab_template":"1983"},{"tab_title":"Chairs          ","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"3169eda","tab_template":"2100"},{"tab_title":"Lighting","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"6c7f10b","tab_template":"2130"},{"tab_title":"Decor","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"98378fe","tab_template":"2141"}],"align_items":"flex-end","title_color":"#777777","title_active_color":"#777777","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"6","isLinked":false},"tab_title_margin":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"title_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_box_shadow_box_shadow_position":"inset","title_hover_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_hover_box_shadow_box_shadow_position":"inset","title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_active_box_shadow_box_shadow_position":"inset","align_items_tablet":"center","title_hover_box_shadow_box_shadow_type":"yes","padding_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false}],"home-1":[{"id":"2c2d7640","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"30da2bf1","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"_inline_size":null},"elements":[{"id":"26bec359","elType":"widget","settings":{"rev_alias":"home1"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"22187151","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_width":{"unit":"px","size":1710},"padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"20","bottom":"40","left":"20","isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"abd03f6","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"40","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"5d7a8a51","elType":"widget","settings":{"categories":"stools","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_cate1.jpg","id":1414},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"0","right":"0","bottom":"42","left":"50","isLinked":false},"button_text":"View Collection","_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"6f72fd26","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"40","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"71ad0312","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_cate2.jpg","id":1415},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"0","right":"0","bottom":"42","left":"50","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"69c704f7","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"130","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"5e6fb058","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"3855ae64","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"1bf86667","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom"},"elements":[],"widgetType":"text-editor"},{"id":"48276ec2","elType":"widget","settings":{"limit":4,"column":"4","categories":["stools"],"_padding":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"59efafd5","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop","is_external":"on","nofollow":""},"align":"center","typography_letter_spacing":{"unit":"px","size":0.5},"_background_background":"classic","_padding":{"unit":"px","top":"22","right":"0","bottom":"72","left":"0","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"},{"id":"65d16493","elType":"widget","settings":{"color":"#eeeeee","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"6d3f4efb","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"65","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"3f238e1e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"190cf01d","elType":"widget","settings":{"title":"New Design","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-40","left":"0","isLinked":false},"align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_padding":{"unit":"%","top":"0","right":"50","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"299f3da1","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"ac6196c","tab_template":"2184"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"08344e0","tab_template":"1983"},{"tab_title":"Chairs          ","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"3169eda","tab_template":"2100"},{"tab_title":"Lighting","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"6c7f10b","tab_template":"2130"},{"tab_title":"Decor","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"98378fe","tab_template":"2141"}],"align_items":"flex-end","title_color":"#777777","title_active_color":"#777777","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"6","isLinked":false},"tab_title_margin":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"title_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_box_shadow_box_shadow_position":"inset","title_hover_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_hover_box_shadow_box_shadow_position":"inset","title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_active_box_shadow_box_shadow_position":"inset","align_items_tablet":"center","title_hover_box_shadow_box_shadow_type":"yes","padding_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false},{"id":"4f0aa8fe","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_width":{"unit":"px","size":1710},"margin":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"643f7000","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"3eaf0397","elType":"widget","settings":{"rev_alias":"home1_slider2"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"7debd9c5","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"19527c5f","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"7e69f00d","elType":"widget","settings":{"title":"Our Blogs","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"7e54678e","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"53fd1fb","elType":"widget","settings":{"pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","posts_per_page":3},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"39b0d88d","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"content_position":"middle","padding":{"unit":"px","top":"60","right":"40","bottom":"15","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"77f263a1","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"38075d5e","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""}},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"footer-4":[{"id":"4c6ab9cb","elType":"section","settings":{"gap":"no","structure":"40","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"40","bottom":"60","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"020","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"589ae182","elType":"column","settings":{"_column_size":25,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":50,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"28024e08","elType":"widget","settings":{"align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"},{"id":"25535290","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska Badalas <br \/>United State<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"a31bcd3","elType":"widget","settings":{"editor":"<p>(+91)7-723-4608<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"651f2550","elType":"widget","settings":{"text":"Aurosfurniture@domain.vn","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":""},"button_text_color":"#222222","background_color":"rgba(0,0,0,0)","hover_color":"#eb7025","button_hover_border_color":"#eb7025","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"64840db4","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"4837af4d","elType":"widget","settings":{"title":"Our Products","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"55","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_font_weight":"600"},"elements":[],"widgetType":"heading"},{"id":"677a5c30","elType":"widget","settings":{"menu":"acount","layout":"vertical","align_items":"left","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#666666","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":20},"align_items_mobile":"center","menu-toggle-title":"Menu","menu_space_between_mobile":{"unit":"px","size":10},"content_delay_time":"0.50"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"b16397f","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"472263fb","elType":"widget","settings":{"title":"Useful Links","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"55","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"298088ac","elType":"widget","settings":{"menu":"company","layout":"vertical","align_items":"left","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#666666","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":20},"align_items_mobile":"center","menu-toggle-title":"Menu","menu_space_between_mobile":{"unit":"px","size":10},"content_delay_time":"0.50"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"60984904","elType":"column","settings":{"_column_size":25,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"4e8ad035","elType":"widget","settings":{"title":"Newsletter","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_tablet":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"23a722bb","elType":"widget","settings":{"editor":"<p>Stay Updated on all that\'s new add noteworthy<\/p>","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_tablet":"center"},"elements":[],"widgetType":"text-editor"},{"id":"28328ac4","elType":"widget","settings":{"hide_icon":"none","spacing_icon":{"unit":"px","size":0},"width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"input_bacground":"rgba(255,255,255,0.01)","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"button_bacground":"rgba(0,0,0,0)","button_color":"#222222","border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_button_color":"#dddddd","button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"button_margin":{"unit":"%","top":"0","right":"0","bottom":"0","left":"2","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"align_input_mobile":"center","input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_color_hover":"#eb7025","button_border_hover":"#eb7025","button_color_focus":"#eb7025","button_border_focus":"#eb7025","button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"27","left":"0","isLinked":false},"placeholder_color":"#666666"},"elements":[],"widgetType":"opal-mailchmip"},{"id":"64e35605","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"d3bc26e","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-twitter","_id":"4c628cc","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"0100f2f","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"fcab8b4","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""}],"shape":"square","align":"left","align_tablet":"center","align_mobile":"center","icon_color":"custom","icon_primary_color":"rgba(136,136,136,0)","icon_secondary_color":"#888888","icon_size":{"unit":"px","size":16},"icon_padding":{"unit":"em","size":0},"icon_spacing":{"unit":"px","size":12},"hover_primary_color":"rgba(0,0,0,0)","hover_secondary_color":"#eb7025","hover_animation":"pulse"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"11a17815","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#f5f5f5","padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"1059e9ab","elType":"column","settings":{"_column_size":100},"elements":[{"id":"549246c","elType":"widget","settings":{"color":"#e5e5e5","gap":{"unit":"px","size":""},"text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"65d4676d","elType":"section","settings":{"gap":"no","content_position":"middle","padding":{"unit":"px","top":"35","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","padding_mobile":{"unit":"px","top":"30","right":"20","bottom":"35","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"35","right":"40","bottom":"35","left":"40","isLinked":false},"structure":"20","content_delay_time":"0.50"},"elements":[{"id":"267ec1f4","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"609b3188","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<a href=\"#\"><span style=\"color: #222222;\"><strong>Auros<\/strong><\/span><\/a>. All rights reserved.<\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"22ccc640","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"7a12bb41","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/09\/paypal.png","id":1470},"image_size":"full","align":"right","align_mobile":"center"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"section-6":[{"id":"d725dbd","elType":"section","settings":{"content_width":{"unit":"px","size":1000},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"20","bottom":"0","left":"20","isLinked":false},"height":"full","column_position":"bottom","padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"34d7d195","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"4ca9654e","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":90},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"0","bottom":"6","left":"15","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search","_margin":{"unit":"px","top":"0","right":"0","bottom":"250","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-search-form"},{"id":"52de15b2","elType":"section","settings":{"structure":"40","gap":"no","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"rgba(255,255,255,0.1)","content_delay_time":"0.50"},"elements":[{"id":"445fd947","elType":"column","settings":{"_column_size":25,"_inline_size":19.6700000000000017053025658242404460906982421875,"margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"7ba63e64","elType":"widget","settings":{"align":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"align_mobile":"center"},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"34417a84","elType":"column","settings":{"_column_size":25,"_inline_size":31.3299999999999982946974341757595539093017578125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3b8baf1b","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br \/>United State<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"13b44808","elType":"column","settings":{"_column_size":25,"_inline_size":26,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"1766006f","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"70a44855","elType":"column","settings":{"_column_size":25,"_inline_size":23,"_inline_size_tablet":50,"space_between_widgets":0},"elements":[{"id":"2d55bd5f","elType":"widget","settings":{"form_name":"Newsletter","sub_title":"Stay Updated on all that\u2019s new add noteworthy","text":"+ JOIN OUR NEWSLETTER","background_color":"rgba(255,216,212,0)","border_width":{"unit":"px","top":"0","right":"0","bottom":"9","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"spacing_icon":{"unit":"px","size":0},"title_spacing":{"unit":"px","size":10},"heading_color":"#000000","width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"heading_typography_font_size":{"unit":"px","size":24},"background_color_form":"#ffffff","width_form":{"unit":"px","size":500},"padding_form":{"unit":"px","size":30,"top":"40","right":"40","bottom":"50","left":"40"},"form_align":"center","hide_icon":"none","placeholder_color":"#666666","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_mailchip_button_typography":"custom","typography_mailchip_button_font_size":{"unit":"px","size":14},"typography_mailchip_button_font_weight":"600","typography_mailchip_button_text_transform":"uppercase","typography_mailchip_button_letter_spacing":{"unit":"px","size":1},"mailchip_button_color":"#222222","mailchip_button_color_hover":"#eb7025","mailchip_button_border_hover":"#eb7025","mailchip_button_color_focus":"#eb7025","mailchip_button_border_focus":"#eb7025","border_mailchip_button_border":"solid","border_mailchip_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_mailchip_button_color":"#dddddd","mailchip_button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"mailchip_button_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"8","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"heading_typography_typography":"custom","width_form_mobile":{"unit":"px","size":320},"align_input_mobile":"center","mailchip_button_bacground":"rgba(0,0,0,0)","mailchip_button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"subtitle_spacing":{"unit":"px","size":5},"subtitle_color":"#666666","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":14},"subtitle_typography_font_weight":"400","input_bacground":"rgba(0,0,0,0)","hover_animation":"grow"},"elements":[],"widgetType":"opal-button-mailchimp"}],"isInner":false}],"isInner":false},{"id":"37a17d00","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#202020","margin_mobile":{"unit":"%","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"45","left":"020","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"797279fa","elType":"column","settings":{"_column_size":100},"elements":[{"id":"4caeca1d","elType":"widget","settings":{"color":"rgba(255,255,255,0.1)","gap":{"unit":"px","size":""},"_background_background":"classic","_background_color":"#202020","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"a6161fb","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"35","left":"20","isLinked":false},"structure":"20","content_delay_time":"0.50"},"elements":[{"id":"6eaee9e7","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"622e0ecc","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2018 <span style=\"color: #ffffff;\"><strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong><\/span> All rights reserved.<\/p>","text_color":"#bbbbbb","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"7b7722fb","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"461d5b25","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""}],"align":"right","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"rgba(255,255,255,0.5)","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"isInner":false}],"isInner":false}],"footer-3-2":[{"id":"75b08154","elType":"section","settings":{"structure":"40","gap":"no","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"rgba(255,255,255,0.1)","content_delay_time":"0.50"},"elements":[{"id":"4ddfea94","elType":"column","settings":{"_column_size":25,"_inline_size":19.6700000000000017053025658242404460906982421875,"margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"2432f1c8","elType":"widget","settings":{"align":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"align_mobile":"center","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"36bc0491","elType":"column","settings":{"_column_size":25,"_inline_size":31.3299999999999982946974341757595539093017578125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"581f0578","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br \/>United State<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"6353cf6b","elType":"column","settings":{"_column_size":25,"_inline_size":26,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"6c3ba998","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"4f3bd5ab","elType":"column","settings":{"_column_size":25,"_inline_size":23,"_inline_size_tablet":50,"space_between_widgets":0},"elements":[{"id":"6a33c06","elType":"widget","settings":{"form_name":"Newsletter","sub_title":"Stay Updated on all that\u2019s new add noteworthy","text":"+ JOIN OUR NEWSLETTER","background_color":"rgba(255,216,212,0)","border_width":{"unit":"px","top":"0","right":"0","bottom":"9","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"spacing_icon":{"unit":"px","size":0},"title_spacing":{"unit":"px","size":10},"heading_color":"#000000","width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"heading_typography_font_size":{"unit":"px","size":24},"background_color_form":"#ffffff","width_form":{"unit":"px","size":500},"padding_form":{"unit":"px","size":30,"top":"40","right":"40","bottom":"50","left":"40"},"form_align":"center","hide_icon":"none","placeholder_color":"#666666","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_mailchip_button_typography":"custom","typography_mailchip_button_font_size":{"unit":"px","size":14},"typography_mailchip_button_font_weight":"600","typography_mailchip_button_text_transform":"uppercase","typography_mailchip_button_letter_spacing":{"unit":"px","size":1},"mailchip_button_color":"#222222","mailchip_button_color_hover":"#eb7025","mailchip_button_border_hover":"#eb7025","mailchip_button_color_focus":"#eb7025","mailchip_button_border_focus":"#eb7025","border_mailchip_button_border":"solid","border_mailchip_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_mailchip_button_color":"#dddddd","mailchip_button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"mailchip_button_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"8","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"heading_typography_typography":"custom","width_form_mobile":{"unit":"px","size":320},"align_input_mobile":"center","mailchip_button_bacground":"rgba(0,0,0,0)","mailchip_button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"subtitle_spacing":{"unit":"px","size":5},"subtitle_color":"#666666","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":14},"subtitle_typography_font_weight":"400","input_bacground":"rgba(0,0,0,0)","hover_animation":"grow"},"elements":[],"widgetType":"opal-button-mailchimp"}],"isInner":false}],"isInner":false},{"id":"628144da","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#202020","margin_mobile":{"unit":"%","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"45","left":"020","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"1ef97090","elType":"column","settings":{"_column_size":100},"elements":[{"id":"317a0977","elType":"widget","settings":{"color":"rgba(255,255,255,0.1)","gap":{"unit":"px","size":""},"_background_background":"classic","_background_color":"#202020","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"65055760","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"35","left":"20","isLinked":false},"structure":"20","content_delay_time":"0.50"},"elements":[{"id":"2f6379b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"5944aec3","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<span style=\"color: #ffffff;\"><strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong><\/span> All rights reserved.<\/p>","text_color":"#bbbbbb","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"3c717a06","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"3987279b","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""}],"align":"right","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"rgba(255,255,255,0.5)","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"home-6-2":[{"id":"61f06e69","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img.jpg","id":1263},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","background_hover_background":"classic","background_overlay_background":"classic","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"6f18b25c","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"74d2326","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"slideInDown"},"elements":[],"widgetType":"text-editor"},{"id":"6863f94c","elType":"widget","settings":{"title":"Awsome trending","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_line_height_mobile":{"unit":"px","size":""},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"zoomIn"},"elements":[],"widgetType":"heading"},{"id":"2b1aeb1b","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.8000000000000000444089209850062616169452667236328125},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"slideInUp"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"3502066","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img2.jpg","id":1297},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","background_hover_background":"classic","background_hover_position":"top left","background_hover_repeat":"no-repeat","background_hover_size":"cover","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"2a8f458b","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"29cbd5d8","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInLeft","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"72f898b9","elType":"widget","settings":{"title":"New Design 2018","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"fadeInLeft","_animation_delay":600},"elements":[],"widgetType":"heading"},{"id":"3da91cfe","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.5},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"fadeInLeft","_animation_delay":700},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"52ab2aed","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img3.jpg","id":1301},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"208e4138","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"10bbee2f","elType":"widget","settings":{"editor":"<p>#Kitchen<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInRight","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"53ecc7c1","elType":"widget","settings":{"title":"Ceramic Handmade","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"fadeInRight","_animation_delay":600},"elements":[],"widgetType":"heading"},{"id":"3dd09469","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.5},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"fadeInRight","_animation_delay":700},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"240756bd","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img4.jpg","id":1309},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"42b980b0","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"5987250f","elType":"widget","settings":{"editor":"<p>#outdoor<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInLeft"},"elements":[],"widgetType":"text-editor"},{"id":"6c6a093e","elType":"widget","settings":{"title":"Creative chair","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"zoomIn"},"elements":[],"widgetType":"heading"},{"id":"3193052e","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.5},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"fadeInRight"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"2929b020","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img5.jpg","id":1310},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"195936d2","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"49e823b5","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInUp"},"elements":[],"widgetType":"text-editor"},{"id":"3aeb4730","elType":"widget","settings":{"title":"Lighting Decor","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"fadeInUp","animation_duration":"slow"},"elements":[],"widgetType":"heading"}],"isInner":false}],"isInner":false},{"id":"4fd5fafd","elType":"section","settings":{"content_width":{"unit":"px","size":1000},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"20","bottom":"0","left":"20","isLinked":false},"height":"full","column_position":"bottom","padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"41eabc3b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"6d6318bb","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":90},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"0","bottom":"6","left":"15","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search","_margin":{"unit":"px","top":"0","right":"0","bottom":"250","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-search-form"},{"id":"43ad20bf","elType":"section","settings":{"structure":"40","gap":"no","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"rgba(255,255,255,0.1)","content_delay_time":"0.50"},"elements":[{"id":"39fbb010","elType":"column","settings":{"_column_size":25,"_inline_size":19.6700000000000017053025658242404460906982421875,"margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"1dff4b22","elType":"widget","settings":{"align":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"align_mobile":"center"},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"74cb434","elType":"column","settings":{"_column_size":25,"_inline_size":31.3299999999999982946974341757595539093017578125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"255e1b8","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br \/>United State<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"59f76315","elType":"column","settings":{"_column_size":25,"_inline_size":26,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"244a9f0c","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"4ddbe5c0","elType":"column","settings":{"_column_size":25,"_inline_size":23,"_inline_size_tablet":50,"space_between_widgets":0},"elements":[{"id":"4c8fdfec","elType":"widget","settings":{"form_name":"Newsletter","sub_title":"Stay Updated on all that\u2019s new add noteworthy","text":"+ JOIN OUR NEWSLETTER","background_color":"rgba(255,216,212,0)","border_width":{"unit":"px","top":"0","right":"0","bottom":"9","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"spacing_icon":{"unit":"px","size":0},"title_spacing":{"unit":"px","size":10},"heading_color":"#000000","width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"heading_typography_font_size":{"unit":"px","size":24},"background_color_form":"#ffffff","width_form":{"unit":"px","size":500},"padding_form":{"unit":"px","size":30,"top":"40","right":"40","bottom":"50","left":"40"},"form_align":"center","hide_icon":"none","placeholder_color":"#666666","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_mailchip_button_typography":"custom","typography_mailchip_button_font_size":{"unit":"px","size":14},"typography_mailchip_button_font_weight":"600","typography_mailchip_button_text_transform":"uppercase","typography_mailchip_button_letter_spacing":{"unit":"px","size":1},"mailchip_button_color":"#222222","mailchip_button_color_hover":"#eb7025","mailchip_button_border_hover":"#eb7025","mailchip_button_color_focus":"#eb7025","mailchip_button_border_focus":"#eb7025","border_mailchip_button_border":"solid","border_mailchip_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_mailchip_button_color":"#dddddd","mailchip_button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"mailchip_button_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"8","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"heading_typography_typography":"custom","width_form_mobile":{"unit":"px","size":320},"align_input_mobile":"center","mailchip_button_bacground":"rgba(0,0,0,0)","mailchip_button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"subtitle_spacing":{"unit":"px","size":5},"subtitle_color":"#666666","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":14},"subtitle_typography_font_weight":"400","input_bacground":"rgba(0,0,0,0)","hover_animation":"grow"},"elements":[],"widgetType":"opal-button-mailchimp"}],"isInner":false}],"isInner":false},{"id":"51d61f26","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#202020","margin_mobile":{"unit":"%","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"45","left":"020","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"3d056189","elType":"column","settings":{"_column_size":100},"elements":[{"id":"6aad2b99","elType":"widget","settings":{"color":"rgba(255,255,255,0.1)","gap":{"unit":"px","size":""},"_background_background":"classic","_background_color":"#202020","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"47c45c98","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"35","left":"20","isLinked":false},"structure":"20","content_delay_time":"0.50"},"elements":[{"id":"7ddffe3b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"741301ec","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2018 <span style=\"color: #ffffff;\"><strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong><\/span> All rights reserved.<\/p>","text_color":"#bbbbbb","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"546a269a","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"162ab6ae","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""},"social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f","social_icon":{"value":"fab fa-wordpress","library":"fa-brands"},"item_icon_color":"default","item_icon_primary_color":"","item_icon_secondary_color":""}],"align":"right","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"rgba(255,255,255,0.5)","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"isInner":false}],"isInner":false}],"default-kit":null,"header-24":[{"id":"3e79070","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"content_width":{"unit":"px","size":1710},"background_background":"classic","content_delay_time":"0.50"},"elements":[{"id":"82204cd","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"2fbc772","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"74e2d7b","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":80,"_inline_size_mobile":50},"elements":[{"id":"6102867","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","toggle_align":"right","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":30},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"canvas","align_items":"center","align_items_tablet":"left","_padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"ca5f71b","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":20,"_inline_size_mobile":100},"elements":[{"id":"8a2f784","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"home-24":[{"id":"93cafca","elType":"section","settings":{"content_delay_time":"0.50","stretch_section":"section-stretched","layout":"full_width","gap":"no"},"elements":[{"id":"c57e182","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"0ac5b43","elType":"widget","settings":{"rev_alias":"home-24"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"1529dc3","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"a4f6295","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"6820c9b","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"4dcdb30","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"7a481ab","elType":"widget","settings":{"_animation_delay":100,"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"30c32e0","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"40","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","_background_background":"classic","hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"d9b0063","elType":"section","settings":{"gap":"no","structure":"20","stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false}},"elements":[{"id":"f5d5219","elType":"column","settings":{"_column_size":50,"_inline_size":60.66199999999999903366187936626374721527099609375,"space_between_widgets":0,"background_background":"classic","background_color":"#f3f3f3","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"22c8621","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h9_ct01-1.png","id":1512},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":25},"category_name_typography_font_weight":"700","item_typography_typography":"custom","text_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"50","isLinked":false},"button_text":"View Collection","_animation":"opal-move-right","category_name_color_hover":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"3336f5c","elType":"column","settings":{"_column_size":50,"_inline_size":39.33800000000000096633812063373625278472900390625,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"35cf064","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"7b0868f","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#d8eef4"},"elements":[{"id":"488df60","elType":"widget","settings":{"categories":"lighting","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h9_ct02.jpg","id":1550},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":25},"category_name_typography_font_weight":"700","text_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"50","isLinked":false},"button_text":"View Collection","_animation":"opal-move-left","category_name_color_hover":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true},{"id":"d64457c","elType":"section","settings":{"gap":"no","background_background":"classic","content_delay_time":"0.50"},"elements":[{"id":"f06aeed","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"background_background":"classic"},"elements":[{"id":"37eea82","elType":"widget","settings":{"categories":"decor","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h9_ct03.jpg","id":1555},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":25},"category_name_typography_font_weight":"700","text_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"50","isLinked":false},"button_text":"View Collection","_animation":"opal-move-left","category_name_color_hover":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"4ba6bb1","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50","margin_tablet":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"e29111a","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d2a02cf","elType":"widget","settings":{"skin":"cover","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img2.jpg","id":1297},"bg_image_size":"full","title":"#Furnitures","description":"New Design 2018","button":"Shop Now","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"min-height":{"unit":"px","size":645},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"title_typography_font_weight":"400","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":22},"title_typography_letter_spacing":{"unit":"px","size":1},"title_spacing":{"unit":"px","size":20},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":60},"description_typography_font_weight":"700","description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":50},"description_typography_letter_spacing":{"unit":"px","size":2},"description_spacing":{"unit":"px","size":50},"title_color":"#ffffff","description_color":"#ffffff","button_color":"#ffffff","button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":15},"button_typography_font_weight":"600","button_typography_line_height":{"unit":"px","size":24},"button_typography_letter_spacing":{"unit":"px","size":0.5},"button_text_color":"#ffffff","button_background_color":"rgba(0,0,0,0)","button_border_color":"#ffffff","button_hover_background_color":"#eb7025","button_hover_border_color":"#eb7025","button_border_width":{"unit":"px","size":1},"button_border_radius":{"unit":"px","size":0},"content_animation_duration":{"unit":"px","size":1500},"sequenced_animation":"elementor-cta--sequenced-animation","transformation":"move-up","min-height_mobile":{"unit":"px","size":500},"description_typography_font_size_mobile":{"unit":"px","size":40},"button_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"min-height_tablet":{"unit":"px","size":550,"sizes":[]},"description_typography_font_size_tablet":{"unit":"px","size":50,"sizes":[]}},"elements":[],"widgetType":"call-to-action"}],"isInner":false}],"isInner":false}],"home-21":[{"id":"1ee4d27","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50"},"elements":[{"id":"c4f121a","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f771ba5","elType":"widget","settings":{"rev_alias":"slider-home21"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"83d4969","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","content_delay_time":"0.50","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"303657c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"2938993","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"3c492a4","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"9be0071","elType":"widget","settings":{"_animation_delay":100,"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"4da401d","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"50","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","_background_background":"classic","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"e9ea927","elType":"section","settings":{"structure":"20","gap":"no","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1440,"sizes":[]},"margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"e85f3e9","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner6_h20.jpg","id":4616},"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_delay":100},"elements":[{"id":"48b34a9","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_tablet":{"unit":"px","top":"120","right":"0","bottom":"120","left":"45","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"21380f0","elType":"column","settings":{"_column_size":50,"_inline_size":35,"text_align":"left","_inline_size_tablet":60,"space_between_widgets":0},"elements":[{"id":"41fbea5","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"3f8750b","elType":"widget","settings":{"title":"Overear Headphone","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"2b6246a","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"a0a3c96","elType":"column","settings":{"_column_size":50,"_inline_size":65,"text_align":"left","_inline_size_tablet":100,"hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"6f0027c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner7_h20.jpg","id":4617},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":200,"animation_duration":"fast","space_between_widgets":0},"elements":[{"id":"042faf9","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"e05c311","elType":"column","settings":{"_column_size":50,"_inline_size":35,"text_align":"left","space_between_widgets":0,"_inline_size_tablet":70},"elements":[{"id":"a78c208","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"172ea2a","elType":"widget","settings":{"title":"Woody <br>for Paper Clips","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"8c150e7","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"7e1b9dc","elType":"column","settings":{"_column_size":50,"_inline_size":65,"text_align":"left","hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"30dc2c8","elType":"section","settings":{"gap":"no","content_position":"middle","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"stretch_section":"section-stretched","content_delay_time":"0.50","content_width":{"unit":"px","size":1440,"sizes":[]},"margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"d61d526","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"4bf5b35","elType":"widget","settings":{"title":"Newest Design","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"7a5ff7c","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":""},"_margin":{"unit":"px","top":"15","right":"0","bottom":"65","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_margin_mobile":{"unit":"px","top":"15","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"cf74d3f","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"8aaa967","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-right","animation_duration":"fast","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"c51c810","elType":"widget","settings":{"limit":4,"column":"2"},"elements":[],"widgetType":"opal-products"}],"isInner":true},{"id":"dc640b2","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#f5f5f5","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ac2d716","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img6.png","id":2434},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"yes","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"0c151ca"},{"layers_select":"text","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"#Furnitures","text_typo_typography":"custom","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":42},"text_typo_font_size_tablet":{"unit":"px","size":35},"text_typo_font_size_mobile":{"unit":"px","size":30},"text_typo_font_weight":"600","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#000000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"bea88ce"}],"img_layers_padding":{"unit":"px","top":"0","right":"0","bottom":"150","left":"0","isLinked":false},"img_layers_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"img_layers_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-images-layers"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"9dfadd7","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","content_position":"middle","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"content_delay_time":"0.50","margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"animation_mobile":"opal-move-up"},"elements":[{"id":"5291f0f","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic"},"elements":[{"id":"a6a4a0d","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"home-22":[{"id":"2c3416d","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_delay_time":"0.50"},"elements":[{"id":"339f9b0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"0173443","elType":"widget","settings":{"rev_alias":"slider_home22"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"136aa80","elType":"section","settings":{"structure":"30","gap":"no","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1440,"sizes":[]},"margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"60","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"4f8f3df","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/02\/h5_bg_1adsfds.jpg","id":4374},"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"background_position":"center right","background_repeat":"no-repeat","background_size":"cover","_inline_size_tablet":100,"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"40","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_delay":100},"elements":[{"id":"f490e75","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"reverse_order_tablet":"reverse-tablet","margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"687401a","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","_inline_size_tablet":100,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"3a06154","elType":"widget","settings":{"editor":"<p>#Living<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"cff7733","elType":"widget","settings":{"title":"The Funel\n& Sweepers","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"b5082e8","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"8a5123e","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","_inline_size_tablet":100},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"3ae2bc0","elType":"column","settings":{"_column_size":33,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_bgr_2.jpg","id":1279},"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"space_between_widgets":0,"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","_inline_size_tablet":50,"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":200,"animation_duration":"fast"},"elements":[{"id":"f6e0d28","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_tablet":{"unit":"px","top":"100","right":"0","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"3ed407e","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","space_between_widgets":0,"_inline_size_mobile":50,"_inline_size_tablet":60},"elements":[{"id":"a36734d","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"0628e13","elType":"widget","settings":{"title":"White\nCeramics","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"4168d3c","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"0457108","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"16e622a","elType":"column","settings":{"_column_size":33,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_bgr_3.jpg","id":1280},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_inline_size_tablet":50,"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":300,"animation_duration":"fast"},"elements":[{"id":"4eb922b","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"48a19a2","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","space_between_widgets":0,"_inline_size_mobile":50,"_inline_size_tablet":60},"elements":[{"id":"77b3c6e","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"8599a57","elType":"widget","settings":{"title":"Vega Table \nLamp\n","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"12f01dc","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"f5bed0c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"0e0bd8b","elType":"section","settings":{"gap":"no","content_position":"middle","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"stretch_section":"section-stretched","content_delay_time":"0.50","content_width":{"unit":"px","size":1440,"sizes":[]},"margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"103090a","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"1295f41","elType":"widget","settings":{"title":"Newest Design","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast","typography_font_size_mobile":{"unit":"px","size":32,"sizes":[]}},"elements":[],"widgetType":"heading"},{"id":"786fb0f","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":""},"_margin":{"unit":"px","top":"15","right":"0","bottom":"65","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_margin_mobile":{"unit":"px","top":"15","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"59ce026","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","content_delay_time":"0.50"},"elements":[{"id":"f96691b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-right","animation_duration":"fast","padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"d8297ef","elType":"widget","settings":{"limit":4,"column":"2"},"elements":[],"widgetType":"opal-products"}],"isInner":true},{"id":"5df0eaf","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#f5f5f5","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"1c94df3","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img6.png","id":2434},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"yes","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"0c151ca"},{"layers_select":"text","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"#Furnitures","text_typo_typography":"custom","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":42},"text_typo_font_size_tablet":{"unit":"px","size":35},"text_typo_font_size_mobile":{"unit":"px","size":30},"text_typo_font_weight":"600","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#000000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"bea88ce"}],"img_layers_padding":{"unit":"px","top":"0","right":"0","bottom":"150","left":"0","isLinked":false},"img_layers_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"img_layers_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-images-layers"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"26ccb75","elType":"section","settings":{"structure":"20","gap":"no","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1440,"sizes":[]},"margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"d2f7d3d","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner6_h20.jpg","id":4616},"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_delay":100},"elements":[{"id":"a7948ea","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_tablet":{"unit":"px","top":"120","right":"0","bottom":"120","left":"45","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"9a0dfbd","elType":"column","settings":{"_column_size":50,"_inline_size":35,"text_align":"left","_inline_size_tablet":60,"space_between_widgets":0},"elements":[{"id":"20cdbc3","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"7b48458","elType":"widget","settings":{"title":"Overear Headphone","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d2718d1","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"4d85a5c","elType":"column","settings":{"_column_size":50,"_inline_size":65,"text_align":"left","_inline_size_tablet":100,"hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"3a13868","elType":"column","settings":{"_column_size":50,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner7_h20.jpg","id":4617},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":200,"animation_duration":"fast","space_between_widgets":0},"elements":[{"id":"65cd513","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"efc2c76","elType":"column","settings":{"_column_size":50,"_inline_size":35,"text_align":"left","space_between_widgets":0,"_inline_size_tablet":70},"elements":[{"id":"495f518","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"c12dbcc","elType":"widget","settings":{"title":"Woody <br>for Paper Clips","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"30c8f57","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"b304da8","elType":"column","settings":{"_column_size":50,"_inline_size":65,"text_align":"left","hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"7b042ed","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","content_position":"middle","layout":"full_width","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"content_delay_time":"0.50","margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"animation_mobile":"opal-move-up"},"elements":[{"id":"b455381","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic"},"elements":[{"id":"84ab229","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"home-20":[{"id":"0b31886","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"0d5bf3f","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"_inline_size":null},"elements":[{"id":"bc5ca97","elType":"widget","settings":{"rev_alias":"slider-home20"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"732d950","elType":"section","settings":{"gap":"no","structure":"20","margin":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"82d90b5","elType":"column","settings":{"_column_size":50,"_inline_size":66.6666670000000038953658076934516429901123046875,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"14","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"87f0f5d","elType":"section","settings":{"gap":"no","structure":"20","content_delay_time":"0.50","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false}},"elements":[{"id":"0a43ede","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"cabd612","elType":"widget","settings":{"categories":"stools","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner1_h20.jpg","id":4611},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"35","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true},{"id":"56622bb","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"9a4f382","elType":"widget","settings":{"categories":"chairs","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner2_h20.jpg","id":4612},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"35","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true},{"id":"f544ab0","elType":"section","settings":{"gap":"no","content_delay_time":"0.50"},"elements":[{"id":"95592e8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"5527ce4","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner4_h20.jpg","id":4614},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"35","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"017c67e","elType":"column","settings":{"_column_size":50,"_inline_size":33.35000000000000142108547152020037174224853515625,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"27","isLinked":false},"_inline_size_tablet":100,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"873e32c","elType":"widget","settings":{"categories":"lighting","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner3_h20.jpg","id":4613},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"35","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-product-categories"},{"id":"a615cde","elType":"widget","settings":{"categories":"decor","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner5_h20.jpg","id":4615},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"35","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"f2b16b6","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"130","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"2604e82","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"eca6d07","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"e538565","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"26848c5","elType":"widget","settings":{"limit":8,"column":"4","categories":["decor","stools"],"_padding":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"c47a1a0","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop","is_external":"on","nofollow":""},"align":"center","typography_letter_spacing":{"unit":"px","size":0.5},"_background_background":"classic","_padding":{"unit":"px","top":"22","right":"0","bottom":"30","left":"0","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"201dd6c","elType":"section","settings":{"gap":"no","structure":"20","margin":{"unit":"px","top":"100","right":0,"bottom":"100","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"60","right":0,"bottom":"60","left":0,"isLinked":true},"content_delay_time":"0.50"},"elements":[{"id":"5e8c935","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner6_h20.jpg","id":4616},"background_position":"center left","background_repeat":"no-repeat","padding":{"unit":"px","top":"100","right":"55","bottom":"100","left":"55","isLinked":false},"_inline_size":null,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"background_overlay_background":"classic","background_overlay_opacity":{"unit":"px","size":1},"overlay_blend_mode":"overlay","background_overlay_hover_background":"classic","background_overlay_hover_opacity":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"1e1140c","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":2},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"aa94b9d","elType":"widget","settings":{"title":"Overear<br>\nHeadphone","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":31},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":39},"typography_letter_spacing":{"unit":"px","size":-1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"3f5e1b1","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"_animation_delay":400,"hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"20a9536","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner7_h20.jpg","id":4617},"background_position":"center left","background_repeat":"no-repeat","padding":{"unit":"px","top":"100","right":"55","bottom":"100","left":"55","isLinked":false},"_inline_size":null,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"background_overlay_hover_background":"classic","background_overlay_hover_opacity":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"a59d4d7","elType":"widget","settings":{"editor":"<p>#Other<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":2},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"736eafe","elType":"widget","settings":{"title":"Woody<br>\nfor Paper Clips","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":31},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":39},"typography_letter_spacing":{"unit":"px","size":-1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"a4b25ae","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"_animation_delay":400,"hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"78bba74","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"content_position":"middle","padding":{"unit":"px","top":"60","right":"40","bottom":"15","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"c0426f3","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"30c94b1","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""}},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"home-23":[{"id":"01df11d","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50"},"elements":[{"id":"4085ed0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d386973","elType":"widget","settings":{"rev_alias":"slider_home22","_title":"","_margin":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_margin_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_padding_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_padding_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_z_index":"","_element_id":"","_css_classes":"","_animation":"","_animation_tablet":"","_animation_mobile":"","animation_duration":"","_animation_delay":"","_background_background":"","_background_color":"","_background_color_stop":{"unit":"%","size":0,"sizes":[]},"_background_color_b":"#f2295b","_background_color_b_stop":{"unit":"%","size":100,"sizes":[]},"_background_gradient_type":"linear","_background_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"_background_gradient_position":"center center","_background_image":{"url":"","id":""},"_background_image_tablet":{"url":"","id":""},"_background_image_mobile":{"url":"","id":""},"_background_position":"","_background_position_tablet":"","_background_position_mobile":"","_background_xpos":{"unit":"px","size":0,"sizes":[]},"_background_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"_background_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"_background_ypos":{"unit":"px","size":0,"sizes":[]},"_background_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"_background_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"_background_attachment":"","_background_repeat":"","_background_repeat_tablet":"","_background_repeat_mobile":"","_background_size":"","_background_size_tablet":"","_background_size_mobile":"","_background_bg_width":{"unit":"%","size":100,"sizes":[]},"_background_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"_background_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"_background_video_link":"","_background_video_start":"","_background_video_end":"","_background_play_once":"","_background_play_on_mobile":"","_background_video_fallback":{"url":"","id":""},"_background_slideshow_gallery":[],"_background_slideshow_loop":"yes","_background_slideshow_slide_duration":5000,"_background_slideshow_slide_transition":"fade","_background_slideshow_transition_duration":500,"_background_slideshow_ken_burns":"","_background_slideshow_ken_burns_zoom_direction":"in","_background_hover_background":"","_background_hover_color":"","_background_hover_color_stop":{"unit":"%","size":0,"sizes":[]},"_background_hover_color_b":"#f2295b","_background_hover_color_b_stop":{"unit":"%","size":100,"sizes":[]},"_background_hover_gradient_type":"linear","_background_hover_gradient_angle":{"unit":"deg","size":180,"sizes":[]},"_background_hover_gradient_position":"center center","_background_hover_image":{"url":"","id":""},"_background_hover_image_tablet":{"url":"","id":""},"_background_hover_image_mobile":{"url":"","id":""},"_background_hover_position":"","_background_hover_position_tablet":"","_background_hover_position_mobile":"","_background_hover_xpos":{"unit":"px","size":0,"sizes":[]},"_background_hover_xpos_tablet":{"unit":"px","size":0,"sizes":[]},"_background_hover_xpos_mobile":{"unit":"px","size":0,"sizes":[]},"_background_hover_ypos":{"unit":"px","size":0,"sizes":[]},"_background_hover_ypos_tablet":{"unit":"px","size":0,"sizes":[]},"_background_hover_ypos_mobile":{"unit":"px","size":0,"sizes":[]},"_background_hover_attachment":"","_background_hover_repeat":"","_background_hover_repeat_tablet":"","_background_hover_repeat_mobile":"","_background_hover_size":"","_background_hover_size_tablet":"","_background_hover_size_mobile":"","_background_hover_bg_width":{"unit":"%","size":100,"sizes":[]},"_background_hover_bg_width_tablet":{"unit":"px","size":"","sizes":[]},"_background_hover_bg_width_mobile":{"unit":"px","size":"","sizes":[]},"_background_hover_video_link":"","_background_hover_video_start":"","_background_hover_video_end":"","_background_hover_play_once":"","_background_hover_play_on_mobile":"","_background_hover_video_fallback":{"url":"","id":""},"_background_hover_slideshow_gallery":[],"_background_hover_slideshow_loop":"yes","_background_hover_slideshow_slide_duration":5000,"_background_hover_slideshow_slide_transition":"fade","_background_hover_slideshow_transition_duration":500,"_background_hover_slideshow_ken_burns":"","_background_hover_slideshow_ken_burns_zoom_direction":"in","_background_hover_transition":{"unit":"px","size":"","sizes":[]},"_border_border":"","_border_width":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_width_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_width_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_color":"","_border_radius":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_radius_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_radius_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_box_shadow_box_shadow_type":"","_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_box_shadow_position":" ","_border_hover_border":"","_border_hover_width":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_hover_width_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_hover_width_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_hover_color":"","_border_radius_hover":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_radius_hover_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_border_radius_hover_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":true},"_box_shadow_hover_box_shadow_type":"","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":10,"spread":0,"color":"rgba(0,0,0,0.5)"},"_box_shadow_hover_box_shadow_position":" ","_border_hover_transition":{"unit":"px","size":"","sizes":[]},"_element_width":"","_element_width_tablet":"","_element_width_mobile":"","_element_custom_width":{"unit":"px","size":"","sizes":[]},"_element_custom_width_tablet":{"unit":"px","size":"","sizes":[]},"_element_custom_width_mobile":{"unit":"px","size":"","sizes":[]},"_element_vertical_align":"","_element_vertical_align_tablet":"","_element_vertical_align_mobile":"","_position":"","_offset_orientation_h":"start","_offset_x":{"unit":"px","size":"0","sizes":[]},"_offset_x_tablet":{"unit":"px","size":"","sizes":[]},"_offset_x_mobile":{"unit":"px","size":"","sizes":[]},"_offset_x_end":{"unit":"px","size":"0","sizes":[]},"_offset_x_end_tablet":{"unit":"px","size":"","sizes":[]},"_offset_x_end_mobile":{"unit":"px","size":"","sizes":[]},"_offset_orientation_v":"start","_offset_y":{"unit":"px","size":"0","sizes":[]},"_offset_y_tablet":{"unit":"px","size":"","sizes":[]},"_offset_y_mobile":{"unit":"px","size":"","sizes":[]},"_offset_y_end":{"unit":"px","size":"0","sizes":[]},"_offset_y_end_tablet":{"unit":"px","size":"","sizes":[]},"_offset_y_end_mobile":{"unit":"px","size":"","sizes":[]},"hide_desktop":"","hide_tablet":"","hide_mobile":""},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"3d65a07","elType":"section","settings":{"gap":"no","border_border":"solid","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"110","right":"0","bottom":"0","left":"0","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"5a7e569","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e51d570","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"b211cc1","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","_padding":{"unit":"px","top":"15","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"text-editor"},{"id":"7526a44","elType":"widget","settings":{"limit":8,"column":"4","_padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":400},"elements":[],"widgetType":"opal-products"},{"id":"1a8eefb","elType":"widget","settings":{"text":"+ See All Products","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":25},"button_text_color":"#000000","background_color":"rgba(249,212,189,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(241,192,162,0.67)"},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","_z_index":1,"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"on","nofollow":""},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":400},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"dedace7","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"3ee10f5","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d4e1f06","elType":"widget","settings":{"skin":"cover","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img2.jpg","id":1297},"bg_image_size":"full","title":"#Furnitures","description":"New Design 2018","button":"Shop Now","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"min-height":{"unit":"px","size":645},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"title_typography_font_weight":"400","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":22},"title_typography_letter_spacing":{"unit":"px","size":1},"title_spacing":{"unit":"px","size":20},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":60},"description_typography_font_weight":"700","description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":50},"description_typography_letter_spacing":{"unit":"px","size":2},"description_spacing":{"unit":"px","size":50},"title_color":"#ffffff","description_color":"#ffffff","button_color":"#ffffff","button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":15},"button_typography_font_weight":"600","button_typography_line_height":{"unit":"px","size":24},"button_typography_letter_spacing":{"unit":"px","size":0.5},"button_text_color":"#ffffff","button_background_color":"rgba(0,0,0,0)","button_border_color":"#ffffff","button_hover_background_color":"#eb7025","button_hover_border_color":"#eb7025","button_border_width":{"unit":"px","size":1},"button_border_radius":{"unit":"px","size":0},"content_animation_duration":{"unit":"px","size":1500},"sequenced_animation":"elementor-cta--sequenced-animation","transformation":"move-up","min-height_mobile":{"unit":"px","size":500},"description_typography_font_size_mobile":{"unit":"px","size":40},"button_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false}},"elements":[],"widgetType":"call-to-action"}],"isInner":false}],"isInner":false},{"id":"2aafdf5","elType":"section","settings":{"structure":"20","gap":"no","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"content_delay_time":"0.50","stretch_section":"section-stretched","content_width":{"unit":"px","size":1440,"sizes":[]},"margin_tablet":{"unit":"px","top":"90","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"ccab6f7","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner6_h20.jpg","id":4616},"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"animation":"opal-move-up","animation_duration":"fast","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_delay":100},"elements":[{"id":"329e97a","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_tablet":{"unit":"px","top":"120","right":"0","bottom":"120","left":"45","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"58962d4","elType":"column","settings":{"_column_size":50,"_inline_size":35,"text_align":"left","_inline_size_tablet":60,"space_between_widgets":0},"elements":[{"id":"9ed549e","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"9fc0eab","elType":"widget","settings":{"title":"Overear Headphone","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"256a284","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"473695f","elType":"column","settings":{"_column_size":50,"_inline_size":65,"text_align":"left","_inline_size_tablet":100,"hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"038efcc","elType":"column","settings":{"_column_size":50,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/08\/banner7_h20.jpg","id":4617},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":200,"animation_duration":"fast","space_between_widgets":0},"elements":[{"id":"b86eb7f","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"10","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"5c4175c","elType":"column","settings":{"_column_size":50,"_inline_size":35,"text_align":"left","space_between_widgets":0,"_inline_size_tablet":70},"elements":[{"id":"bc710cb","elType":"widget","settings":{"editor":"<p>#OTHER<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"4543e54","elType":"widget","settings":{"title":"Woody <br>for Paper Clips","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"1eede5c","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"4ccd982","elType":"column","settings":{"_column_size":50,"_inline_size":65,"text_align":"left","hide_mobile":"hidden-phone"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"912cf81","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"content_position":"middle","padding":{"unit":"px","top":"60","right":"40","bottom":"15","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"1d4703b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"d61b74b","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""}},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"footer-3":[{"id":"ffd6642","elType":"section","settings":{"structure":"40","gap":"no","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"rgba(255,255,255,0.1)"},"elements":[{"id":"d06c920","elType":"column","settings":{"_column_size":25,"_inline_size":19.6700000000000017053025658242404460906982421875,"margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"56ff3f8","elType":"widget","settings":{"align":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"align_mobile":"center"},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"c14e23d","elType":"column","settings":{"_column_size":25,"_inline_size":31.3299999999999982946974341757595539093017578125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"7c64295","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br \/>United State<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"16caefc","elType":"column","settings":{"_column_size":25,"_inline_size":26,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3844bbe","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"cd80589","elType":"column","settings":{"_column_size":25,"_inline_size":23,"_inline_size_tablet":50,"space_between_widgets":0},"elements":[{"id":"5ce7602","elType":"widget","settings":{"form_name":"Newsletter","sub_title":"Stay Updated on all that\u2019s new add noteworthy","text":"+ JOIN OUR NEWSLETTER","background_color":"rgba(255,216,212,0)","border_width":{"unit":"px","top":"0","right":"0","bottom":"9","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"spacing_icon":{"unit":"px","size":0},"title_spacing":{"unit":"px","size":10},"heading_color":"#000000","width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"heading_typography_font_size":{"unit":"px","size":24},"background_color_form":"#ffffff","width_form":{"unit":"px","size":500},"padding_form":{"unit":"px","size":30,"top":"40","right":"40","bottom":"50","left":"40"},"form_align":"center","hide_icon":"none","placeholder_color":"#666666","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_mailchip_button_typography":"custom","typography_mailchip_button_font_size":{"unit":"px","size":14},"typography_mailchip_button_font_weight":"600","typography_mailchip_button_text_transform":"uppercase","typography_mailchip_button_letter_spacing":{"unit":"px","size":1},"mailchip_button_color":"#222222","mailchip_button_color_hover":"#eb7025","mailchip_button_border_hover":"#eb7025","mailchip_button_color_focus":"#eb7025","mailchip_button_border_focus":"#eb7025","border_mailchip_button_border":"solid","border_mailchip_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_mailchip_button_color":"#dddddd","mailchip_button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"mailchip_button_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"8","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"heading_typography_typography":"custom","width_form_mobile":{"unit":"px","size":320},"align_input_mobile":"center","mailchip_button_bacground":"rgba(0,0,0,0)","mailchip_button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"subtitle_spacing":{"unit":"px","size":5},"subtitle_color":"#666666","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":14},"subtitle_typography_font_weight":"400","input_bacground":"rgba(0,0,0,0)","hover_animation":"grow"},"elements":[],"widgetType":"opal-button-mailchimp"}],"isInner":false}],"isInner":false},{"id":"466fc5a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#202020","margin_mobile":{"unit":"%","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"45","left":"020","isLinked":false}},"elements":[{"id":"02728c2","elType":"column","settings":{"_column_size":100},"elements":[{"id":"b96fbc0","elType":"widget","settings":{"color":"rgba(255,255,255,0.1)","gap":{"unit":"px","size":""},"_background_background":"classic","_background_color":"#202020"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"4c0d962","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"35","left":"20","isLinked":false},"structure":"20"},"elements":[{"id":"23d41a8","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0854de8","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2018 <span style=\"color: #ffffff;\"><strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong><\/span> All rights reserved.<\/p>","text_color":"#bbbbbb","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"5d771e2","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0157923","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f"}],"align":"right","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"rgba(255,255,255,0.5)","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"home-6":[{"id":"67fdaa8","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img.jpg","id":1263},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","background_hover_background":"classic","background_overlay_background":"classic","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false}},"elements":[{"id":"d8581d6","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"e986ba9","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"slideInDown"},"elements":[],"widgetType":"text-editor"},{"id":"8a9b5c9","elType":"widget","settings":{"title":"Awsome trending","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_line_height_mobile":{"unit":"px","size":""},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"zoomIn"},"elements":[],"widgetType":"heading"},{"id":"795d67d","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.8000000000000000444089209850062616169452667236328125},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"slideInUp"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"1cc1db0","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img2.jpg","id":1297},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","background_hover_background":"classic","background_hover_position":"top left","background_hover_repeat":"no-repeat","background_hover_size":"cover","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false}},"elements":[{"id":"07e52ac","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d76601d","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInLeft","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"6e5c900","elType":"widget","settings":{"title":"New Design 2018","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"fadeInLeft","_animation_delay":600},"elements":[],"widgetType":"heading"},{"id":"955fb50","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.5},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"fadeInLeft","_animation_delay":700},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"39c5036","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img3.jpg","id":1301},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false}},"elements":[{"id":"0a3441c","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"fef5fcf","elType":"widget","settings":{"editor":"<p>#Kitchen<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInRight","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"1eb462f","elType":"widget","settings":{"title":"Ceramic Handmade","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"fadeInRight","_animation_delay":600},"elements":[],"widgetType":"heading"},{"id":"94e9248","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.5},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"fadeInRight","_animation_delay":700},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"5b7f614","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img4.jpg","id":1309},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false}},"elements":[{"id":"4129647","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"c3991c4","elType":"widget","settings":{"editor":"<p>#outdoor<\/p>","align":"center","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInLeft"},"elements":[],"widgetType":"text-editor"},{"id":"76a49f1","elType":"widget","settings":{"title":"Creative chair","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"zoomIn"},"elements":[],"widgetType":"heading"},{"id":"a610fc1","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":24},"typography_letter_spacing":{"unit":"px","size":0.5},"background_color":"rgba(0,0,0,0)","button_background_hover_color":"#eb7025","button_hover_border_color":"#eb7025","hover_animation":"grow","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false},"_animation":"fadeInRight"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"d57c859","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","height":"full","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img5.jpg","id":1310},"background_repeat":"no-repeat","background_size":"cover","background_position":"center center","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"20","bottom":"130","left":"20","isLinked":false}},"elements":[{"id":"989bf32","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"bccca3f","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":22},"typography_letter_spacing":{"unit":"px","size":1.5},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInUp"},"elements":[],"widgetType":"text-editor"},{"id":"443429a","elType":"widget","settings":{"title":"Lighting Decor","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":50},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":50},"typography_line_height_tablet":{"unit":"px","size":60},"typography_letter_spacing":{"unit":"px","size":6},"typography_letter_spacing_mobile":{"unit":"px","size":0},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"fadeInUp","animation_duration":"slow"},"elements":[],"widgetType":"heading"}],"isInner":false}],"isInner":false},{"id":"8bde8af","elType":"section","settings":{"content_width":{"unit":"px","size":1000},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","stretch_section":"section-stretched","padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"20","bottom":"0","left":"20","isLinked":false},"height":"full","column_position":"bottom","padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false}},"elements":[{"id":"c3234f8","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"bab3dd0","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":90},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"0","bottom":"6","left":"15","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search","_margin":{"unit":"px","top":"0","right":"0","bottom":"250","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-search-form"},{"id":"2dc9d97","elType":"section","settings":{"structure":"40","gap":"no","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"rgba(255,255,255,0.1)"},"elements":[{"id":"130d937","elType":"column","settings":{"_column_size":25,"_inline_size":19.6700000000000017053025658242404460906982421875,"margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"58c4111","elType":"widget","settings":{"align":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"align_mobile":"center"},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"5888a03","elType":"column","settings":{"_column_size":25,"_inline_size":31.3299999999999982946974341757595539093017578125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"23a10a0","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br \/>United State<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"906f688","elType":"column","settings":{"_column_size":25,"_inline_size":26,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"c7f3613","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"23aaf91","elType":"column","settings":{"_column_size":25,"_inline_size":23,"_inline_size_tablet":50,"space_between_widgets":0},"elements":[{"id":"3b9a6bb","elType":"widget","settings":{"form_name":"Newsletter","sub_title":"Stay Updated on all that\u2019s new add noteworthy","text":"+ JOIN OUR NEWSLETTER","background_color":"rgba(255,216,212,0)","border_width":{"unit":"px","top":"0","right":"0","bottom":"9","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"spacing_icon":{"unit":"px","size":0},"title_spacing":{"unit":"px","size":10},"heading_color":"#000000","width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"heading_typography_font_size":{"unit":"px","size":24},"background_color_form":"#ffffff","width_form":{"unit":"px","size":500},"padding_form":{"unit":"px","size":30,"top":"40","right":"40","bottom":"50","left":"40"},"form_align":"center","hide_icon":"none","placeholder_color":"#666666","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_mailchip_button_typography":"custom","typography_mailchip_button_font_size":{"unit":"px","size":14},"typography_mailchip_button_font_weight":"600","typography_mailchip_button_text_transform":"uppercase","typography_mailchip_button_letter_spacing":{"unit":"px","size":1},"mailchip_button_color":"#222222","mailchip_button_color_hover":"#eb7025","mailchip_button_border_hover":"#eb7025","mailchip_button_color_focus":"#eb7025","mailchip_button_border_focus":"#eb7025","border_mailchip_button_border":"solid","border_mailchip_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_mailchip_button_color":"#dddddd","mailchip_button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"mailchip_button_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"8","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"heading_typography_typography":"custom","width_form_mobile":{"unit":"px","size":320},"align_input_mobile":"center","mailchip_button_bacground":"rgba(0,0,0,0)","mailchip_button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"subtitle_spacing":{"unit":"px","size":5},"subtitle_color":"#666666","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":14},"subtitle_typography_font_weight":"400","input_bacground":"rgba(0,0,0,0)","hover_animation":"grow"},"elements":[],"widgetType":"opal-button-mailchimp"}],"isInner":false}],"isInner":false},{"id":"d589e0c","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#202020","margin_mobile":{"unit":"%","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"45","left":"020","isLinked":false}},"elements":[{"id":"07a6996","elType":"column","settings":{"_column_size":100},"elements":[{"id":"7cae416","elType":"widget","settings":{"color":"rgba(255,255,255,0.1)","gap":{"unit":"px","size":""},"_background_background":"classic","_background_color":"#202020"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"ef1859a","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"35","left":"20","isLinked":false},"structure":"20"},"elements":[{"id":"87ef2da","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f0de253","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2018 <span style=\"color: #ffffff;\"><strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong><\/span> All rights reserved.<\/p>","text_color":"#bbbbbb","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"d23680a","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f9e93c0","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f"}],"align":"right","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"rgba(255,255,255,0.5)","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"isInner":false}],"isInner":false}],"blog-modern":[{"id":"53eb046","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"gap":"no","margin":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"801a1c1","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"2be8773","elType":"widget","settings":{"posts_per_page":2,"column":"2","style":"post-style-5","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"14f654f","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"2a93a4e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee"},"elements":[{"id":"4e289fe","elType":"section","settings":{"layout":"full_width","gap":"no","content_position":"middle","structure":"30"},"elements":[{"id":"c27978f","elType":"column","settings":{"_column_size":33,"_inline_size":39.71399999999999863575794734060764312744140625,"_inline_size_tablet":30,"space_between_widgets":20},"elements":[{"id":"8fb3202","elType":"widget","settings":{"color":"#eeeeee","align":"left","gap":{"unit":"px","size":10}},"elements":[],"widgetType":"divider"}],"isInner":true},{"id":"e971130","elType":"column","settings":{"_column_size":33,"_inline_size":19.952000000000001733724275254644453525543212890625,"_inline_size_tablet":40,"space_between_widgets":0},"elements":[{"id":"422d78d","elType":"widget","settings":{"title":"Recommend Articles","align":"center","title_color":"#777777","location_color":{"unit":"%","size":52},"location_secondary":{"unit":"%","size":37},"angle_gradian":{"unit":"deg","size":170},"typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":3},"_background_background":"classic","typography_line_height_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"e773595","elType":"column","settings":{"_column_size":33,"_inline_size":40,"_inline_size_tablet":30,"space_between_widgets":20},"elements":[{"id":"d8e3436","elType":"widget","settings":{"color":"#eeeeee","align":"right","gap":{"unit":"px","size":10}},"elements":[],"widgetType":"divider"}],"isInner":true}],"isInner":true},{"id":"fb1777a","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-4","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_margin":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"023941e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","margin":{"unit":"px","top":"80","right":0,"bottom":"50","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"256a6fa","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e9c2f68","elType":"widget","settings":{"style":"post-style-6","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false}],"header-11":[{"id":"2fc3599","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"50","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"10","right":"40","bottom":"0","left":"40","isLinked":false},"content_width":{"unit":"px","size":1720}},"elements":[{"id":"1ebedbc","elType":"column","settings":{"_column_size":20,"_inline_size":8,"space_between_widgets":0,"_inline_size_tablet":10,"_inline_size_mobile":50,"padding_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false}},"elements":[{"id":"b4d5c60","elType":"widget","settings":{"placeholder":"Search product or anything...","button_text":"Search","input_typography_typography":"custom","input_typography_font_weight":"normal","input_background_color_background":"classic","input_background_color_color":"#f5f5f5","button_text_color":"#222222","button_background_color_background":"classic","button_background_color_color":"#f5f5f5","icon_size":{"unit":"px","size":18},"_margin_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"hide_mobile":"hidden-phone","button_background_color":"rgba(0,0,0,0)","button_text_color_hover":"#eb7025","skin":"full_screen","toggle_align":"flex-start","toggle_background_color":"rgba(0,0,0,0)","input_text_color":"#ffffff","input_border_border":"solid","input_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"input_border_color":"#ffffff","toggle_color":"#222222","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_z_index":1},"elements":[],"widgetType":"opal-search-form"}],"isInner":false},{"id":"4356e44","elType":"column","settings":{"_column_size":20,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50,"margin_tablet":{"unit":"px","top":"0","right":"50","bottom":"0","left":"50","isLinked":false}},"elements":[{"id":"1f3d44a","elType":"widget","settings":{"menu":"menu-01-home11","align_items":"right","indicator":"angle","dropdown":"mobile","full_width":"stretch","width_dropdown_mobile":{"unit":"px","size":290},"toggle_align_mobile":"left","menu-toggle-title":"Menu","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","pointer_color_menu_item_hover":"rgba(53,225,219,0)","color_menu_item_active":"#222222","pointer_color_menu_item_active":"rgba(53,225,219,0)","pointer_width":{"unit":"px","size":3},"padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu_space_between":{"unit":"px","size":15},"color_dropdown_item":"#494c4f","color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":10},"toggle_background_color":"rgba(197,156,108,0)","toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"toggle_color":"#000000","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","subMenusMinWidth":{"unit":"px","size":270},"_margin_mobile":{"unit":"px","top":"-42","right":"0","bottom":"0","left":"0","isLinked":false},"menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","dropdown_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"e24cbf4","elType":"column","settings":{"_column_size":20,"_inline_size":18,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":100,"margin_tablet":{"unit":"px","top":"-34","right":"70","bottom":"0","left":"70","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"50","isLinked":false}},"elements":[{"id":"a5da475","elType":"widget","settings":{"align":"center","align_tablet":"center","_margin_tablet":{"unit":"px","top":"-7","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"right","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_z_index":2,"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"7f42fa5","elType":"column","settings":{"_column_size":20,"_inline_size":32.9969999999999998863131622783839702606201171875,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"6eaeee1","elType":"widget","settings":{"menu":"menu-02-home11","align_items":"left","indicator":"angle","dropdown":"mobile","full_width":"stretch","width_dropdown_mobile":{"unit":"px","size":290},"toggle_align_mobile":"left","menu-toggle-title":"Menu","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","pointer_color_menu_item_hover":"rgba(53,225,219,0)","color_menu_item_active":"#222222","pointer_color_menu_item_active":"rgba(53,225,219,0)","pointer_width":{"unit":"px","size":3},"padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu_space_between":{"unit":"px","size":15},"color_dropdown_item":"#494c4f","color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":10},"toggle_background_color":"rgba(197,156,108,0)","toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"toggle_color":"#000000","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone","subMenusMinWidth":{"unit":"px","size":270},"subMenusMinWidth_tablet":{"unit":"px","size":270},"subMenusMaxWidth_tablet":{"unit":"px","size":500},"_margin_mobile":{"unit":"px","top":"-42","right":"0","bottom":"0","left":"0","isLinked":false},"menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","dropdown_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"eb60d8b","elType":"column","settings":{"_column_size":20,"_inline_size":8,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":100,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"73db3c8","elType":"widget","settings":{"show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone","_margin_tablet":{"unit":"px","top":"-35","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"3417f40","elType":"section","settings":{"gap":"no","padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"5","left":"20","isLinked":false},"content_position":"middle"},"elements":[{"id":"a98619b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"418f960","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","toggle_align_mobile":"left","dropdown_layout":"canvas","align_items":"center","hide_desktop":"hidden-desktop","_margin_mobile":{"unit":"px","top":"-42","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false}],"header-empty":null,"home-12-accessories":[{"id":"2c56878","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"6701f46","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"5f79aaa","elType":"section","settings":{"content_width":{"unit":"px","size":100},"gap":"no"},"elements":[{"id":"b87a5f8","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"ab46126","elType":"widget","settings":{"editor":"Best<br>\nDesign<br>\n2018","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"b760a3a","elType":"widget","settings":{"title":"#Accessories","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":35}},"elements":[],"widgetType":"heading"},{"id":"2d04eac","elType":"widget","settings":{"color":"#222222","width":{"unit":"px","size":80},"align":"center","gap":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"gap_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"divider"},{"id":"d769d13","elType":"widget","settings":{"limit":3,"column":"1","categories":["all"],"product_ajax":"yes","product_style":"style-4","product_ajax_scroll":"false"},"elements":[],"widgetType":"opal-products"}],"isInner":false},{"id":"8b0d86c","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"6e46b88","elType":"widget","settings":{"limit":3,"column":"1","categories":["stools"],"product_ajax":"yes","product_style":"style-4","product_ajax_scroll":"false"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"coming-soon":[{"id":"eb87ad5","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":680},"gap":"no","content_position":"middle","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/09-Coming-soon.jpg","id":3722},"background_repeat":"no-repeat","padding":{"unit":"px","top":"80","right":"15","bottom":"80","left":"15","isLinked":false},"margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":true}},"elements":[{"id":"3cb0938","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"415d007","elType":"widget","settings":{"_margin":{"unit":"px","top":"0","right":"0","bottom":"120","left":"0","isLinked":false},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"},{"id":"f80b8d4","elType":"widget","settings":{"title":"We are coming soon!","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"47a87b2","elType":"widget","settings":{"editor":"<p>Condimentum ipsum a adipiscing hac dolor set consectetur.<\/p>","align":"center","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":18},"typography_font_size_mobile":{"unit":"px","size":14},"_margin":{"unit":"px","top":"20","right":"0","bottom":"55","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"2d2be86","elType":"widget","settings":{"label_days":"Days","label_hours":"Hours","label_minutes":"Minutes","label_seconds":"Seconds","container_width":{"unit":"px","size":""},"box_background_color":"rgba(34,34,34,0)","box_border_border":"solid","box_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"box_border_color":"#eeeeee","box_spacing":{"unit":"px","size":30},"box_spacing_mobile":{"unit":"px","size":10},"digits_color":"#222222","digits_typography_typography":"custom","digits_typography_font_size":{"unit":"px","size":40},"digits_typography_font_weight":"600","label_color":"#777777","label_typography_typography":"custom","label_typography_font_size":{"unit":"px","size":10},"label_typography_font_weight":"600","label_typography_text_transform":"uppercase","label_typography_letter_spacing":{"unit":"px","size":3},"border_digits_border":"solid","border_digits_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_digits_color":"#eeeeee","digits_padding":{"unit":"px","top":"32","right":"0","bottom":"32","left":"0","isLinked":false},"_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-countdown"},{"id":"c6dbaa5","elType":"widget","settings":{"title":"Notify Me","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","_margin":{"unit":"px","top":"120","right":"0","bottom":"15","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"0a1ddc2","elType":"widget","settings":{"editor":"<p>Stay Updated on all that\'s new add noteworthy<\/p>","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_tablet":"center","align":"center","typography_font_size_mobile":{"unit":"px","size":14},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"a4a47f0","elType":"widget","settings":{"hide_icon":"none","spacing_icon":{"unit":"px","size":0},"width_input":{"unit":"%","size":78},"width_button":{"unit":"%","size":20},"input_bacground":"rgba(255,255,255,0.01)","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"button_bacground":"rgba(0,0,0,0)","button_color":"#222222","border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_button_color":"rgba(235,112,37,0.38)","button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"button_margin":{"unit":"%","top":"0","right":"0","bottom":"0","left":"2","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"align_input_mobile":"center","input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_color_hover":"#eb7025","button_border_hover":"#eb7025","button_color_focus":"#eb7025","button_border_focus":"#eb7025","button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"30","right":"0","bottom":"25","left":"0","isLinked":false},"placeholder_color":"#666666","setting_align":"center","align_input":"left","_padding":{"unit":"px","top":"0","right":"80","bottom":"0","left":"80","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"},{"id":"f72c776","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"d3bc26e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"4c628cc","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"0100f2f"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"fcab8b4"}],"shape":"square","align_tablet":"center","align_mobile":"center","icon_color":"custom","icon_primary_color":"rgba(136,136,136,0)","icon_secondary_color":"#888888","icon_size":{"unit":"px","size":16},"icon_padding":{"unit":"em","size":0},"icon_spacing":{"unit":"px","size":12},"hover_primary_color":"rgba(0,0,0,0)","hover_secondary_color":"#eb7025","hover_animation":"pulse","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"social-icons"},{"id":"51aa9ac","elType":"widget","settings":{"editor":"<p>(+91)7-723-4608 \/ <a href=\"mailto:Aurosfurniture@domain.vn\">Aurosfurniture@domain.vn<\/a><\/p>","align":"center","text_color":"#777777","typography_typography":"custom","typography_font_size_mobile":{"unit":"px","size":14},"_margin":{"unit":"px","top":"15","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"home-12-decor":[{"id":"c13d687","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"9b74eac","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"be1edbc","elType":"section","settings":{"content_width":{"unit":"px","size":100},"gap":"no"},"elements":[{"id":"2dae1ff","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"9f74a8e","elType":"widget","settings":{"editor":"Best<br>\nDesign<br>\n2018","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"cfe6f6b","elType":"widget","settings":{"title":"#Decor","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":35}},"elements":[],"widgetType":"heading"},{"id":"9103693","elType":"widget","settings":{"color":"#222222","width":{"unit":"px","size":80},"align":"center","gap":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"gap_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"divider"},{"id":"7cac2a7","elType":"widget","settings":{"limit":3,"column":"1","categories":["decor"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false},{"id":"6c69d10","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"bcb9c0a","elType":"widget","settings":{"limit":3,"column":"1","categories":["furnitures"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home-12-lighting":[{"id":"484a56d","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"dbf6cd0","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"297009b","elType":"section","settings":{"content_width":{"unit":"px","size":100},"gap":"no"},"elements":[{"id":"7a8cbc4","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"dd15af1","elType":"widget","settings":{"editor":"Best<br>\nDesign<br>\n2018","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"f75f872","elType":"widget","settings":{"title":"#Lighting","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":35}},"elements":[],"widgetType":"heading"},{"id":"ea29d42","elType":"widget","settings":{"color":"#222222","width":{"unit":"px","size":80},"align":"center","gap":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"gap_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"divider"},{"id":"807cb51","elType":"widget","settings":{"limit":3,"column":"1","categories":["lighting"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false},{"id":"0b091d2","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3098469","elType":"widget","settings":{"limit":3,"column":"1","categories":["furnitures","sofas"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home-12-chairs":[{"id":"19a425f","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"733713b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"b545eb4","elType":"section","settings":{"content_width":{"unit":"px","size":100},"gap":"no"},"elements":[{"id":"7b85da7","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"3457bd2","elType":"widget","settings":{"editor":"Best<br>\nDesign<br>\n2018","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"82ffdb6","elType":"widget","settings":{"title":"#Chairs","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":35}},"elements":[],"widgetType":"heading"},{"id":"6ba6494","elType":"widget","settings":{"color":"#222222","width":{"unit":"px","size":80},"align":"center","gap":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"gap_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"divider"},{"id":"4709213","elType":"widget","settings":{"limit":3,"column":"1","categories":["chairs"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false},{"id":"54e816f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"50cf908","elType":"widget","settings":{"limit":3,"column":"1","categories":["decor"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home-12-furnitures":[{"id":"51c43a5","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"e466a93","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"32738e00","elType":"section","settings":{"content_width":{"unit":"px","size":100},"gap":"no"},"elements":[{"id":"2dc7b227","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"421f9525","elType":"widget","settings":{"editor":"Best<br>\nDesign<br>\n2018","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"5979d408","elType":"widget","settings":{"title":"#Furnitures","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":35}},"elements":[],"widgetType":"heading"},{"id":"2d353754","elType":"widget","settings":{"color":"#222222","width":{"unit":"px","size":80},"align":"center","gap":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"gap_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"divider"},{"id":"4c11829","elType":"widget","settings":{"limit":3,"column":"1","categories":["sofas"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false},{"id":"23ba53d9","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"73f6fefe","elType":"widget","settings":{"limit":3,"column":"1","categories":["furnitures"],"product_ajax":"yes","product_style":"style-4"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home-12-tabs-all":[{"id":"3e0872a","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"0430087","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"245c651","elType":"section","settings":{"content_width":{"unit":"px","size":100},"gap":"no"},"elements":[{"id":"141a01e","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0270348","elType":"widget","settings":{"editor":"<p>Best<br \/>Design<br \/>2018<\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"ac5da27","elType":"widget","settings":{"title":"#All","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":60},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":35},"animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"heading"},{"id":"d772d1b","elType":"widget","settings":{"color":"#222222","width":{"unit":"px","size":80},"align":"center","gap":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"gap_mobile":{"unit":"px","size":20},"animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"divider"},{"id":"fcfc342","elType":"widget","settings":{"limit":3,"column":"1","categories":["all"],"product_ajax":"yes","product_style":"style-4","animation_duration":"fast","_animation_delay":400},"elements":[],"widgetType":"opal-products"}],"isInner":false},{"id":"6d5f1a8","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"60","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"8776ed0","elType":"widget","settings":{"limit":3,"column":"1","categories":["stools"],"product_ajax":"yes","product_style":"style-4","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home_13_tab_all":[{"id":"c1af178","elType":"section","settings":[],"elements":[{"id":"4d7987a","elType":"column","settings":{"_column_size":100},"elements":[{"id":"45d46c8","elType":"widget","settings":{"limit":12,"_animation":"fadeIn","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home_13_tab_decor":[{"id":"676eae4","elType":"section","settings":[],"elements":[{"id":"9e8768b","elType":"column","settings":{"_column_size":100},"elements":[{"id":"587d744","elType":"widget","settings":{"limit":12,"categories":["decor"],"_animation":"fadeIn","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home_13_tab_lighting":[{"id":"9172347","elType":"section","settings":[],"elements":[{"id":"9ff8515","elType":"column","settings":{"_column_size":100},"elements":[{"id":"2a4b03d","elType":"widget","settings":{"limit":12,"categories":["lighting"],"_animation":"fadeIn","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home_13_tab_chairs":[{"id":"28b82ed","elType":"section","settings":[],"elements":[{"id":"ec21b96","elType":"column","settings":{"_column_size":100},"elements":[{"id":"961063b","elType":"widget","settings":{"limit":12,"categories":["chairs"],"_animation":"fadeIn","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home_13_tab_furnitures":[{"id":"6d36321","elType":"section","settings":[],"elements":[{"id":"a7c6872","elType":"column","settings":{"_column_size":100},"elements":[{"id":"fa16438","elType":"widget","settings":{"limit":12,"_animation":"fadeIn","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"tab_contact-us":[{"id":"bafe3aa","elType":"section","settings":{"background_background":"classic"},"elements":[{"id":"d3455f4","elType":"column","settings":{"_column_size":100,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"65","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"space_between_widgets":0},"elements":[{"id":"6b69e9b","elType":"widget","settings":{"title":"Contact Us","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":36},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"align":"left"},"elements":[],"widgetType":"heading"},{"id":"ea4d066","elType":"widget","settings":{"space":{"unit":"px","size":1}},"elements":[],"widgetType":"spacer"},{"id":"b84d9e2","elType":"widget","settings":{"title":"Contact us:","title_color":"#222222","typography_typography":"custom","typography_font_weight":"600","typography_font_size":{"unit":"px","size":16},"_background_background":"classic","_background_position":"center left","_background_repeat":"no-repeat","dot_before_background_color":"#e43636","dot_before_width":{"unit":"px","size":10},"dot_before_height":{"unit":"px","size":10},"dot_before_border_radius":{"unit":"%","top":"50","right":"50","bottom":"50","left":"50","isLinked":false},"dot_before_border_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"65","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"1a13c25","elType":"widget","settings":{"icon_list":[{"text":"123 Sky Tower, West 21th Street, Suite 721, NY","icon":"fa fa-home","_id":"e5bf78e","link":{"url":"","is_external":"","nofollow":""}},{"text":"+844 123 456 789","icon":"fa fa-tablet","_id":"b790c4e","link":{"url":"","is_external":"","nofollow":""}},{"text":"+844 123 456 788","icon":"fa fa-fax","_id":"48a848f","link":{"url":"","is_external":"","nofollow":""}},{"text":"contact@company.com ","icon":"fa fa-envelope","_id":"72414eb","link":{"url":"contact@company.com ","is_external":"","nofollow":""}}],"space_between":{"unit":"px","size":12},"icon_align":"left","icon_color":"#666666","text_color":"#666666","icon_typography_typography":"custom","icon_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"65","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"7dc87e2","elType":"widget","settings":{"space":{"unit":"px","size":1}},"elements":[],"widgetType":"spacer"},{"id":"2ec6d25","elType":"widget","settings":{"title":"Opening time:","title_color":"#222222","typography_typography":"custom","typography_font_weight":"700","typography_font_size":{"unit":"px","size":16},"_background_background":"classic","_background_position":"center left","_background_repeat":"no-repeat","dot_before_background_color":"#e43636","dot_before_width":{"unit":"px","size":10},"dot_before_height":{"unit":"px","size":10},"dot_before_border_radius":{"unit":"%","top":"50","right":"50","bottom":"50","left":"50","isLinked":false},"dot_before_border_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"30","right":"0","bottom":"30","left":"65","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"0213809","elType":"widget","settings":{"editor":"<p>Monday - Friday: 8.00 AM - 7.00 PM<br \/>Saturday, Sunday: 9.00 AM - 8.00 PM<\/p>","text_color":"#999999","typography_typography":"custom","typography_line_height":{"unit":"px","size":30},"typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"65","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"tab_faqs":[{"id":"1402511","elType":"section","settings":{"gap":"no"},"elements":[{"id":"eb44003","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"043ea88","elType":"widget","settings":{"title":"FAQs","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":36},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"4222f5c","elType":"widget","settings":{"tabs":[{"tab_title":"How to shopping with Auros online?","tab_content":"<p><span style=\"font-size: 16px; font-weight: bold; color: #222222;\">Add items to your bag:<\/span><\/p><ol><li>Ensure you are on the website.<\/li><li>Browse the categories across the top navigation bar which includes New In, Clothing, Bags &amp; Accessories, Shoes, Collections, Stores, and Sale.<\/li><li>Once you have found an item to purchase, select your preferred colour, size (if applicable) and the quantity you wish to purchase then simply click \u2018ADD TO CART\u2019.<\/li><li>You can then continue shopping or click \u2018CHECKOUT\u2019 to review the items in your bag and to finalise your order.<\/li><\/ol><p><span style=\"font-size: 16px; font-weight: bold; color: #222222;\">Proceed to purchasing items:<\/span><\/p><ol><li>Once you have finished browsing and have added the items you wish to purchase to your bag, click<br \/>the \u2018CHECKOUT\u2019 button located at the top right of the website.<\/li><li>Within the checkout you can also amend the quantity selected for each item or delete unwanted<br \/>by simply clicking the \u2018EDIT\u2019 button that is located on the right hand side within the Order Overview<br \/>section of the checkout. Your amendments will be updated and allow you to proceed with the<br \/>checkout process.<\/li><\/ol>","_id":"fe61995"},{"tab_title":"Delivery Infomation","tab_content":"<p>A wonderful serenity has taken possession of my entire soul, like these sweet mornings of spring which I enjoy with my whole heart. I am alone, and feel the charm of existence in this spot, which was created for the bliss of souls like mine. I am so happy, my dear friend, so absorbed in the exquisite sense of mere tranquil existence, that I neglect my talents. I should be incapable of drawing a single stroke at the present moment; and yet I feel that I never was a greater artist than now.<\/p>","_id":"ca3499d"}],"border_color":"rgba(0,0,0,0)","title_background":"#222222","title_color":"#ffffff","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":16},"content_color":"#666666","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":14},"content_padding":{"unit":"px","top":"30","right":"65","bottom":"30","left":"65","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":false}],"isInner":false}],"home8_tab_decor":[{"id":"f687759","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20"},"elements":[{"id":"a096f84","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"53f63fb","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate5.jpg","id":2193},"image_size":"full","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875}},"elements":[],"widgetType":"image"},{"id":"0911a40","elType":"widget","settings":{"editor":"<p>#Decor<\/p>","align":"center","align_tablet":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_tablet":{"unit":"px","size":35},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","_margin":{"unit":"px","top":"-70","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a994b58","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4d1e7c9","elType":"widget","settings":{"limit":4,"column":"2","categories":["decor"],"product_style":"style-1"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home8_tab_lighting":[{"id":"f687759","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20"},"elements":[{"id":"a096f84","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"f549e75","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate3.jpg","id":2138},"image_size":"full","align":"left","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875}},"elements":[],"widgetType":"image"},{"id":"7dcae8b","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","align":"center","align_tablet":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_tablet":{"unit":"px","size":35},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","_margin":{"unit":"px","top":"-70","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a994b58","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4d1e7c9","elType":"widget","settings":{"limit":4,"column":"2","categories":["lighting"],"product_style":"style-1"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home8_tab_chairs":[{"id":"f687759","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20"},"elements":[{"id":"a096f84","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"bf39c49","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate2.jpg","id":2127},"image_size":"full","align":"left","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875}},"elements":[],"widgetType":"image"},{"id":"bebf858","elType":"widget","settings":{"editor":"<p>#Chairs<\/p>","align":"center","align_tablet":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_tablet":{"unit":"px","size":35},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","_margin":{"unit":"px","top":"-70","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a994b58","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4d1e7c9","elType":"widget","settings":{"limit":4,"column":"2","categories":["chairs"],"product_style":"style-1"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home8_tab_furnitures":[{"id":"f687759","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"a096f84","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"5f861a5","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h8-img3.jpg","id":2557},"image_size":"full","align":"left","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875}},"elements":[],"widgetType":"image"},{"id":"f601184","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","align_tablet":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_tablet":{"unit":"px","size":35},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","_margin":{"unit":"px","top":"-70","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a994b58","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4d1e7c9","elType":"widget","settings":{"limit":4,"column":"2","categories":["furnitures"],"product_style":"style-1"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home8_tab_all":[{"id":"f687759","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20"},"elements":[{"id":"a096f84","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ace715b","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h8-img3.jpg","id":2557},"image_size":"full","opacity_hover":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"css_filters_hover_css_filter":"custom","background_hover_transition":{"unit":"px","size":0.90000000000000002220446049250313080847263336181640625}},"elements":[],"widgetType":"image"},{"id":"2a6c089","elType":"widget","settings":{"editor":"<p>#All<\/p>","align":"center","align_tablet":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_tablet":{"unit":"px","size":35},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","_margin":{"unit":"px","top":"-70","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a994b58","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4d1e7c9","elType":"widget","settings":{"limit":4,"column":"2","categories":["sofas"],"product_style":"style-1"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"header-19":[{"id":"4c392cc","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"11","right":"40","bottom":"11","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","hide_mobile":"hidden-phone","padding_mobile":{"unit":"px","top":"11","right":"20","bottom":"11","left":"20","isLinked":false}},"elements":[{"id":"73e3d4e","elType":"column","settings":{"_column_size":33,"_inline_size":20,"space_between_widgets":0},"elements":[{"id":"7ffa33a","elType":"widget","settings":{"editor":"<p>Call: (+880) 123 4567<\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_line_height":{"unit":"px","size":""},"typography_letter_spacing":{"unit":"px","size":0.200000000000000011102230246251565404236316680908203125}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a0b4e0c","elType":"column","settings":{"_column_size":33,"_inline_size":60,"space_between_widgets":0},"elements":[{"id":"b1fd54e","elType":"widget","settings":{"editor":"<p>Summer sale discount off 50%! <span style=\"text-decoration: underline;\"><a href=\"#\">Shop Now<\/a><\/span><\/p>","align":"center","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_line_height":{"unit":"px","size":""},"typography_letter_spacing":{"unit":"px","size":0.200000000000000011102230246251565404236316680908203125}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"e4dbee9","elType":"column","settings":{"_column_size":33,"_inline_size":19.332999999999998408384271897375583648681640625,"space_between_widgets":0},"elements":[{"id":"f4776b7","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"9af799e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"89a81c3","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"50c89ba"}],"align":"right","align_mobile":"center","icon_color":"custom","icon_primary_color":"rgba(255,255,255,0)","icon_secondary_color":"#666666","icon_size":{"unit":"px","size":13},"icon_padding":{"unit":"em","size":0},"icon_spacing":{"unit":"px","size":8},"hover_primary_color":"rgba(255,255,255,0)","hover_secondary_color":"#eb7025","hover_animation":"shrink"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"06bf844","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"60","right":"40","bottom":"60","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false}},"elements":[{"id":"3254afc","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"64caa28","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","dropdown_layout":"canvas","toggle_align_mobile":"left","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":20},"dropdown_typography_font_size_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"bf0a031","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"e31919f","elType":"widget","settings":{"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"right","width":{"unit":"px","size":140}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"85bca93","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":100},"elements":[{"id":"fcb93eb","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"header-13":[{"id":"b939b60","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"content_width":{"unit":"px","size":1710},"background_background":"classic"},"elements":[{"id":"e49d7e5","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"0210c47","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"60ea499","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":80,"_inline_size_mobile":50},"elements":[{"id":"89cc129","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","toggle_align":"right","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"canvas"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"0c0d78a","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":20,"_inline_size_mobile":100},"elements":[{"id":"14bf6f1","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"header-17":[{"id":"5940429","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"40","padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"0","left":"40","isLinked":false},"layout":"full_width","background_background":"classic","background_color":"#f5f5f5","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#e5e5e5","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"5779ddd","elType":"column","settings":{"_column_size":25,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":70,"_inline_size_mobile":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"30","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"52989aa","elType":"widget","settings":{"align":"left","align_tablet":"left","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","_z_index":1,"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"2340d82","elType":"column","settings":{"_column_size":25,"_inline_size":20,"space_between_widgets":0,"_inline_size_tablet":30,"_inline_size_mobile":50,"margin_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"159b676","elType":"widget","settings":{"placeholder":"Search product or anything...","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":12},"input_typography_font_weight":"normal","input_text_color":"#888888","input_background_color_background":"classic","input_background_color_color":"#f5f5f5","button_text_color":"#222222","button_background_color_background":"classic","button_background_color_color":"#f5f5f5","icon_size":{"unit":"px","size":18},"_margin_tablet":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"hide_mobile":"hidden-phone","button_background_color":"rgba(0,0,0,0)","button_text_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-search-form"}],"isInner":false},{"id":"d44dda3","elType":"column","settings":{"_column_size":25,"_inline_size":54,"space_between_widgets":0,"_inline_size_tablet":75,"_inline_size_mobile":100,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"140","bottom":"0","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"9ef1493","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","toggle_align":"right","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":13},"menu_typography_font_weight":"normal","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":5},"menu_space_between":{"unit":"px","size":40},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":20},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","toggle_align_mobile":"right","align_items":"right","align_items_tablet":"left","menu_typography_letter_spacing":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"padding_horizontal_menu_item_tablet":{"unit":"px","size":0},"menu_space_between_tablet":{"unit":"px","size":25},"_margin_mobile":{"unit":"px","top":"-23","right":"0","bottom":"0","left":"0","isLinked":false},"dropdown_layout":"canvas","_margin_tablet":{"unit":"px","top":"-10","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"05e0497","elType":"column","settings":{"_column_size":25,"_inline_size":12,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":100,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"85783a4","elType":"widget","settings":{"show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone","config_account_border_border":"solid","config_account_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"config_account_border_color":"#e5e5e5","config_account_padding":{"unit":"px","top":"25","right":"60","bottom":"25","left":"60","isLinked":false},"config_account_padding_tablet":{"unit":"px","top":"10","right":"10","bottom":"25","left":"30","isLinked":false},"config_cart_border_border":"solid","config_cart_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"config_cart_border_color":"#e5e5e5","config_cart_padding":{"unit":"px","top":"25","right":"20","bottom":"25","left":"60","isLinked":false},"config_cart_padding_tablet":{"unit":"px","top":"10","right":"0","bottom":"25","left":"10","isLinked":false},"count_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"count_border_color":"#e5e5e5","show_amount":"yes","cart_amount_typography_typography":"custom","cart_amount_typography_font_size":{"unit":"px","size":13},"amount_color":"#222222","config_account_border_width_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"config_cart_border_width_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"header-12":[{"id":"f92df68","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"content_width":{"unit":"px","size":1710}},"elements":[{"id":"24161a6","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"bd7d7c3","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"a0108df","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":80,"_inline_size_mobile":50},"elements":[{"id":"46eb1ea","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","toggle_align":"right","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","toggle_align_mobile":"right","align_items":"center","align_items_tablet":"left","dropdown_layout":"canvas"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"3e6b5fa","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":20,"_inline_size_mobile":100},"elements":[{"id":"c32eeb6","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"footer-empty":null,"header-10":[{"id":"da0bf3a","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"60","bottom":"40","left":"60","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"23","right":"20","bottom":"10","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"30","right":"40","bottom":"30","left":"40","isLinked":false},"layout":"full_width"},"elements":[{"id":"7fc8574","elType":"column","settings":{"_column_size":33,"_inline_size":65,"space_between_widgets":0,"_inline_size_tablet":63,"_inline_size_mobile":100,"margin_mobile":{"unit":"px","top":"0","right":"70","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"13f5212","elType":"widget","settings":{"align":"left","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"align_mobile":"left","_z_index":1,"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"167d165","elType":"column","settings":{"_column_size":33,"_inline_size":30.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":28,"_inline_size_mobile":100},"elements":[{"id":"d10ee60","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false},{"id":"87dc91d","elType":"column","settings":{"_column_size":33,"_inline_size":4,"space_between_widgets":0,"_inline_size_tablet":9,"_inline_size_mobile":100},"elements":[{"id":"b3280b8","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#ffffff","toggle_background_color":"#222222","toggle_color_hover":"#ffffff","toggle_size":{"unit":"px","size":11},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"%","size":50},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","full_width":"stretch","toggle_align_mobile":"right","toggle_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"toggle_align":"right","toggle_background_color_hover":"#eb7025","toggle_width":{"unit":"px","size":36},"toggle_height":{"unit":"px","size":36},"dropdown_layout":"popup","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":14},"dropdown_typography_font_size_mobile":{"unit":"px","size":20},"toggle_spacing":{"unit":"px","size":0},"title_tongle_typography_typography":"custom","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","_margin_mobile":{"unit":"px","top":"-48","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false}],"header-14":[{"id":"f56cbb7","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","padding":{"unit":"px","top":"30","right":"40","bottom":"30","left":"40","isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"30","right":"40","bottom":"30","left":"40","isLinked":false}},"elements":[{"id":"d040e42","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"d1fb400","elType":"widget","settings":{"align":"left","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"c90747b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"15bf323","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","toggle_align_mobile":"right","toggle_align":"right","dropdown_layout":"popup","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":14},"dropdown_typography_font_size_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false}],"header-09":[{"id":"d22151c","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false}},"elements":[{"id":"02fc7d3","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"5f240da","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","dropdown_layout":"canvas"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"df308af","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"dab3b2d","elType":"widget","settings":{"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"right","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"75e446b","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":100},"elements":[{"id":"4a53bc5","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"0d499ca","elType":"section","settings":{"gap":"no","content_position":"middle","padding":{"unit":"px","top":"10","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","padding_tablet":{"unit":"px","top":"10","right":"40","bottom":"15","left":"40","isLinked":false},"hide_mobile":"hidden-phone","padding_mobile":{"unit":"px","top":"10","right":"20","bottom":"15","left":"20","isLinked":false}},"elements":[{"id":"97810ce","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"56bf356","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":16},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","align_items":"center"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false}],"header-08":[{"id":"4b1deaf","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"11","right":"40","bottom":"11","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","hide_mobile":"hidden-phone","padding_mobile":{"unit":"px","top":"11","right":"20","bottom":"11","left":"20","isLinked":false}},"elements":[{"id":"378bc66","elType":"column","settings":{"_column_size":33,"_inline_size":20,"space_between_widgets":0},"elements":[{"id":"7ec893e","elType":"widget","settings":{"editor":"<p>Call: (+880) 123 4567<\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_line_height":{"unit":"px","size":""},"typography_letter_spacing":{"unit":"px","size":0.200000000000000011102230246251565404236316680908203125}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"50c375f","elType":"column","settings":{"_column_size":33,"_inline_size":60,"space_between_widgets":0},"elements":[{"id":"9eac1f8","elType":"widget","settings":{"editor":"<p>Summer sale discount off 50%! <span style=\"text-decoration: underline;\"><a href=\"#\">Shop Now<\/a><\/span><\/p>","align":"center","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_line_height":{"unit":"px","size":""},"typography_letter_spacing":{"unit":"px","size":0.200000000000000011102230246251565404236316680908203125}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"bcbaee0","elType":"column","settings":{"_column_size":33,"_inline_size":19.332999999999998408384271897375583648681640625,"space_between_widgets":0},"elements":[{"id":"3372373","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"9af799e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"89a81c3","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"50c89ba"}],"align":"right","align_mobile":"center","icon_color":"custom","icon_primary_color":"rgba(255,255,255,0)","icon_secondary_color":"#666666","icon_size":{"unit":"px","size":13},"icon_padding":{"unit":"em","size":0},"icon_spacing":{"unit":"px","size":8},"hover_primary_color":"rgba(255,255,255,0)","hover_secondary_color":"#eb7025","hover_animation":"shrink"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"d6f3ef9","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false}},"elements":[{"id":"f94f26b","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"8d10452","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","dropdown_layout":"canvas"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"f4f6a8c","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"7f8dedb","elType":"widget","settings":{"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"right","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"47837a8","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":100},"elements":[{"id":"77516d6","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false},{"id":"4cce228","elType":"section","settings":{"gap":"no","content_position":"middle","padding":{"unit":"px","top":"10","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","padding_tablet":{"unit":"px","top":"10","right":"40","bottom":"15","left":"40","isLinked":false},"hide_mobile":"hidden-phone","padding_mobile":{"unit":"px","top":"10","right":"20","bottom":"15","left":"20","isLinked":false}},"elements":[{"id":"e86e40d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f6ee05f","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","align_items":"center","toggle_spacing":{"unit":"px","size":15}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false}],"header-07":[{"id":"75f3f70","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"30","right":"40","bottom":"30","left":"40","isLinked":false}},"elements":[{"id":"94b345a","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":50},"elements":[{"id":"eb3c00b","elType":"widget","settings":{"align":"left","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"dbcc490","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":50,"_inline_size_mobile":50},"elements":[{"id":"4f5dc2c","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#ffffff","toggle_background_color":"rgba(255,255,255,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#ffffff","title_tongle_color_hover":"#eb7025","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"popup","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":14},"dropdown_typography_font_size_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"e9ebc31","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":100},"elements":[{"id":"e6fe7d3","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#ffffff","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#ffffff","name_text_hover_color":"#eb7025","icon_color":"#ffffff","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#ffffff","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"home-8":[{"id":"d0d1d5c","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no"},"elements":[{"id":"7398996","elType":"column","settings":{"_column_size":100},"elements":[{"id":"5b7cb82","elType":"widget","settings":{"rev_alias":"home8"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"3ec1bae","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"20","margin":{"unit":"px","top":"85","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"60","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"30","right":0,"bottom":"0","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"2e4bc21","elType":"column","settings":{"_column_size":50,"_inline_size":68.5859999999999985220711096189916133880615234375,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[{"id":"b24cea5","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h8-img1.jpg","id":2549},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":28},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-right","animation_duration":"fast","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"11bc96e","elType":"column","settings":{"_column_size":50,"_inline_size":31.4140000000000014779288903810083866119384765625,"space_between_widgets":0},"elements":[{"id":"ba068b4","elType":"widget","settings":{"categories":"chairs","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h8-img2.jpg","id":2547},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":28},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","_animation":"opal-move-left","animation_duration":"fast","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"697e84a","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"135","right":"0","bottom":"135","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[{"id":"55df028","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"812d3c2","elType":"widget","settings":{"title":"Trending This Week","align":"left","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-30","left":"0","isLinked":false},"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":30},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"35b0529","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"ac6196c","tab_template":"2626"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"08344e0","tab_template":"2631"},{"tab_title":"Chairs          ","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"3169eda","tab_template":"2636"},{"tab_title":"Lighting","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"6c7f10b","tab_template":"2641"},{"tab_title":"Decor","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"98378fe","tab_template":"2644"}],"align_items":"flex-end","tab_typography_typography":"custom","title_color":"#777777","title_hover_color":"#000000","title_active_color":"#777777","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"6","isLinked":false},"tab_title_margin":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"align_items_tablet":"center","padding_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","title_box_shadow_box_shadow_type":"yes","title_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(0,0,0,0.5)"},"title_box_shadow_box_shadow_position":"inset","content_typography_typography":"custom","padding_tablet":{"unit":"px","top":"35","right":"0","bottom":"0","left":"0","isLinked":false},"title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(241,192,162,0.65)"},"title_active_box_shadow_box_shadow_position":"inset"},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false},{"id":"75450e1","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","background_background":"classic","content_width":{"unit":"px","size":1710}},"elements":[{"id":"62548b7","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_position":"center center","background_attachment":"fixed","background_repeat":"no-repeat"},"elements":[{"id":"dce1cf8","elType":"section","settings":{"structure":"20","padding":{"unit":"px","top":"80","right":"0","bottom":"60","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"gap":"no","content_position":"middle","background_background":"classic","background_color":"#5a6b85"},"elements":[{"id":"4158806","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"c0f079d","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/11\/h8-img2.png","id":4300},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"b145d57"},{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/11\/h8-img1.png","id":4301},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"absolute","img_layers_hor_position":{"unit":"%","size":15},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":-5},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"e696958"}]},"elements":[],"widgetType":"opal-images-layers"}],"isInner":true},{"id":"e5a672f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"200","isLinked":false},"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"7a16046","elType":"widget","settings":{"editor":"<p>#handmade<\/p>","align":"left","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2},"typography_line_height":{"unit":"px","size":13}},"elements":[],"widgetType":"text-editor"},{"id":"6acef0c","elType":"widget","settings":{"id_product":"992","show_rating":"none","show_description":"none","show_quantity":"none","general_color":"#ffffff","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":32},"title_typography_font_weight":"600","title_typography_line_height":{"unit":"px","size":32},"title_color":"#ffffff","title_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"price_typography_typography":"custom","price_typography_font_size":{"unit":"px","size":20},"price_typography_font_weight":"600","price_color":"#eb7025","typography_typography":"custom","price_typography_line_height":{"unit":"px","size":20},"typography_font_weight":"600","background_color_background":"classic","background_color_color":"rgba(255,255,255,0)","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#ffffff","hover_color":"#000000","background_color_hover_background":"classic","background_color_hover_color":"#ffffff","border_hover_border":"solid","border_hover_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"text_padding":{"unit":"px","top":"12","right":"40","bottom":"12","left":"40","isLinked":false}},"elements":[],"widgetType":"opal-single-product"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"101ae3e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"140","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"3c1edf1","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false}},"elements":[{"id":"5e566e3","elType":"section","settings":{"gap":"no","structure":"40","padding":{"unit":"px","top":"0","right":"80","bottom":"0","left":"80","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"248aeef","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"d43e03e","elType":"widget","settings":{"icon":"opal-icon-ship","title_text":"Free shipping","description_text":"on all orders over $49.00","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"icon_size":{"unit":"px","size":60},"_animation":"opal-move-right","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"d100e2a","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"b209eb7","elType":"widget","settings":{"icon":"opal-icon-return","title_text":"15 days returns","description_text":"moneyback guarantee","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"icon_size":{"unit":"px","size":40},"_animation":"opal-move-right","animation_duration":"fast"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"7589a54","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"164275e","elType":"widget","settings":{"icon":"opal-icon-checkout","title_text":"Secure checkout","description_text":"100% protected by Paypal","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"icon_size":{"unit":"px","size":45},"_animation":"opal-move-left","animation_duration":"fast"},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"8e8bd15","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[{"id":"e6d138b","elType":"widget","settings":{"icon":"opal-icon-coupon","title_text":"100% free warranty ","description_text":"moneyback guarantee","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"icon_size":{"unit":"px","size":45},"_animation":"opal-move-left","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"5d505e1","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false}},"elements":[{"id":"5cae108","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"57e66ac","elType":"widget","settings":{"username":"ifurnholic","number":5,"per_row":"5","size":"large","show_username":"yes","username_align":"center","username_typography_typography":"custom","username_typography_font_size":{"unit":"px","size":15},"username_typography_font_weight":"400","username_typography_line_height":{"unit":"px","size":24},"username_typography_letter_spacing":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625},"username_text_color":"#222222","image_spacing":{"unit":"px","size":0},"per_row_mobile":"4","target":"_self","style":"insite","show_like":"yes","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-instagram"}],"isInner":false}],"isInner":false},{"id":"9742fd8","elType":"section","settings":{"content_width":{"unit":"px","size":920},"margin":{"unit":"px","top":"110","right":0,"bottom":"110","left":0,"isLinked":true},"margin_tablet":{"unit":"px","top":"50","right":0,"bottom":"50","left":0,"isLinked":true},"gap":"no"},"elements":[{"id":"5733fab","elType":"column","settings":{"_column_size":100},"elements":[{"id":"2c06eac","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":150},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-search-form"}],"isInner":false}],"isInner":false},{"id":"acf1686","elType":"section","settings":[],"elements":[{"id":"3310275","elType":"column","settings":{"_column_size":100},"elements":[],"isInner":false}],"isInner":false}],"home-18":[{"id":"861b280","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"gap":"no"},"elements":[{"id":"e97e2e0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"27f59d0","elType":"widget","settings":{"rev_alias":"home-18"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"185548b","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","structure":"40","margin":{"unit":"px","top":"40","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1750},"margin_mobile":{"unit":"px","top":"20","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"c44e770","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"20","bottom":"20","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"3cb419a","elType":"widget","settings":{"categories":"chairs","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img1.jpg","id":2390},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":28},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"b42d582","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"20","bottom":"20","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"aa1a4f3","elType":"widget","settings":{"categories":"decor","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img2.jpg","id":2391},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":28},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"9849c57","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"fb3bc13","elType":"widget","settings":{"categories":"furnitures","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img3.jpg","id":2392},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":28},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"16b7efd","elType":"column","settings":{"_column_size":25,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"e0964d2","elType":"widget","settings":{"categories":"lighting","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img4.jpg","id":2393},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":28},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"b12ef1a","elType":"section","settings":{"gap":"no","content_position":"middle","margin":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"135","right":"40","bottom":"135","left":"40","isLinked":false},"padding_tablet":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"stretch_section":"section-stretched"},"elements":[{"id":"1e60353","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"464b2d9","elType":"widget","settings":{"title":"Newest Design","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"b27bfd3","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":""},"_margin":{"unit":"px","top":"15","right":"0","bottom":"65","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"d8c0198","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20"},"elements":[{"id":"de48112","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"71df435","elType":"widget","settings":{"limit":4,"column":"2"},"elements":[],"widgetType":"opal-products"}],"isInner":true},{"id":"fb2d2b8","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#f5f5f5","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"a6d41f5","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-img6.png","id":2434},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"yes","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"0c151ca"},{"layers_select":"text","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/plugins\/elementor\/assets\/images\/placeholder.png","id":""},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"#Furnitures","text_typo_typography":"custom","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":42},"text_typo_font_size_tablet":{"unit":"px","size":35},"text_typo_font_size_mobile":{"unit":"px","size":30},"text_typo_font_weight":"600","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#000000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"bea88ce"}],"img_layers_padding":{"unit":"px","top":"0","right":"0","bottom":"150","left":"0","isLinked":false},"img_layers_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"100","left":"0","isLinked":false},"img_layers_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-images-layers"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"2862867","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_position":"middle","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h18-bg.jpg","id":2480},"background_position":"center center","background_attachment":"fixed","background_repeat":"no-repeat","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"230","right":"0","bottom":"280","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"20","bottom":"100","left":"20","isLinked":false},"content_width":{"unit":"px","size":1710}},"elements":[{"id":"2d1682c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"eb47ad2","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"7a2630f","elType":"widget","settings":{"title":"New Design 2018","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":54},"typography_font_weight":"700","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":4},"typography_font_size_tablet":{"unit":"px","size":45},"typography_font_size_mobile":{"unit":"px","size":35},"_margin":{"unit":"px","top":"15","right":"0","bottom":"45","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"a4e42f0","elType":"widget","settings":{"text":"Shop now","align":"center","typography_typography":"custom","typography_font_weight":"600","typography_line_height":{"unit":"px","size":15},"button_text_color":"#222222","background_color":"rgba(255,255,255,0)","button_background_hover_color":"rgba(0,0,0,0.13)","button_hover_border_color":"rgba(0,0,0,0.02)","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#222222","text_padding":{"unit":"px","top":"18","right":"60","bottom":"18","left":"60","isLinked":false},"text_padding_mobile":{"unit":"px","top":"10","right":"20","bottom":"010","left":"20","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"107c342","elType":"section","settings":{"gap":"no","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"110","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"100","right":"0","bottom":"100","left":"0","isLinked":false}},"elements":[{"id":"6ca15d0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"1c9e787","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"typography_font_size_tablet":{"unit":"px","size":30},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"2bee36f","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","_padding":{"unit":"px","top":"15","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"6559ad2","elType":"widget","settings":{"limit":4,"column":"4","_padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"6ff4776","elType":"widget","settings":{"text":"+ See All Products","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":25},"button_text_color":"#000000","background_color":"rgba(249,212,189,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(241,192,162,0.65)"},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","_z_index":1,"button_box_shadow_box_shadow_position":"inset","button_background_hover_color":"#f1c0a2","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"ccc79d3","elType":"section","settings":{"gap":"no","border_border":"solid","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"110","right":"0","bottom":"140","left":"0","isLinked":false}},"elements":[{"id":"2617b7e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"ddfc695","elType":"widget","settings":{"title":"Our Blogs","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"typography_font_size_tablet":{"unit":"px","size":30},"_animation":"opal-move-up"},"elements":[],"widgetType":"heading"},{"id":"95c6c1c","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","_margin":{"unit":"px","top":"15","right":"0","bottom":"65","left":"0","isLinked":false},"_animation":"opal-move-up"},"elements":[],"widgetType":"text-editor"},{"id":"865f0c4","elType":"widget","settings":{"posts_per_page":3,"order":"asc","categories":["healthy","uncategorized"],"style":"post-style-2","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-post-grid"},{"id":"d7fe9b8","elType":"widget","settings":{"text":"+ Read all blogs","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":25},"button_text_color":"#000000","background_color":"rgba(249,212,189,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(241,192,162,0.66)"},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","_z_index":1,"button_box_shadow_box_shadow_position":"inset","link":{"url":"","is_external":"","nofollow":""},"typography_text_transform":"uppercase","button_background_hover_color":"#f1c0a2","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"db1d464","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"content_position":"middle","padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"025d67c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"6bc8cb4","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""},"_animation":"opal-flip","animation_duration":"fast"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"home-16":[{"id":"86ae2d3","elType":"section","settings":{"gap":"no","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-5.png","id":2453},"background_position":"center center","background_repeat":"no-repeat","padding":{"unit":"px","top":"170","right":"40","bottom":"170","left":"40","isLinked":false},"padding_tablet":{"unit":"px","top":"150","right":"0","bottom":"150","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"stretch_section":"section-stretched"},"elements":[{"id":"2f853ce","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"69780f8","elType":"widget","settings":{"title":"Welcome to Auros!","header_size":"h3","align":"center","title_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":3},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"fadeInUp","_animation_delay":100},"elements":[],"widgetType":"heading"},{"id":"f60aaa7","elType":"widget","settings":{"editor":"<p><strong><span style=\"color: #eb7025;\">Auros\u00ae<\/span><\/strong> is a curation of minimalist styles<br \/>that inspire us.<\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":46},"typography_font_size_mobile":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":56},"typography_line_height_mobile":{"unit":"px","size":46},"_animation":"fadeInUp","_animation_delay":200,"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"f6e6219","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/Ico_Long-down.svg","id":3632},"image_size":"full","width":{"unit":"px","size":14},"hover_animation":"sink","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"image"},{"id":"8d279a8","elType":"widget","settings":{"text":"Scroll","link":{"url":"#scroll","is_external":"","nofollow":""},"align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_letter_spacing":{"unit":"px","size":0.59999999999999997779553950749686919152736663818359375},"button_text_color":"#777777","background_color":"rgba(0,0,0,0)","hover_color":"#ffffff","hover_animation":"grow","button_background_hover_color":"rgba(235,112,37,0.8)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"text_padding":{"unit":"px","top":"10","right":"20","bottom":"10","left":"20","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":10,"spread":0,"color":""},"button_box_shadow_box_shadow_position":"inset"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"9c75c4d","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","layout":"full_width","_element_id":"scroll"},"elements":[{"id":"137d9a4","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"df8af9d","elType":"widget","settings":{"limit":8,"column":"2","product_style":"style-5","product_gutter":{"unit":"px","size":40},"_animation":"opal-move-up","_animation_delay":200},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false},{"id":"14bdfc7","elType":"section","settings":{"content_width":{"unit":"px","size":1000},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","stretch_section":"section-stretched","content_position":"middle","padding":{"unit":"px","top":"100","right":"40","bottom":"120","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false}},"elements":[{"id":"de88bec","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"2ae8aec","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":100},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"0","bottom":"6","left":"12","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-search-form"}],"isInner":false}],"isInner":false}],"home-15":[{"id":"601c2d1","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","layout":"full_width"},"elements":[{"id":"7c91999","elType":"column","settings":{"_column_size":100},"elements":[{"id":"d9c0247","elType":"widget","settings":{"rev_alias":"home15"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"5353c0f","elType":"section","settings":{"margin":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false},"gap":"no","stretch_section":"section-stretched","content_width":{"unit":"px","size":1400},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false}},"elements":[{"id":"667bdd5","elType":"column","settings":{"_column_size":100},"elements":[{"id":"6894905","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_size_tablet":{"unit":"px","size":26},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"d549015","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"53a6cb3","elType":"widget","settings":{"limit":8,"column":"4","_padding":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"a72c2db","elType":"widget","settings":{"text":"+ See All Products","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_animation":"opal-move-up","hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"8fba5b4","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","margin":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false}},"elements":[{"id":"775feda","elType":"column","settings":{"_column_size":100,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"db0d4c8","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/banner15-1.jpg","id":2619},"category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":60},"category_name_typography_font_weight":"600","item_color":"rgba(255,255,255,0.7)","category_name_color":"#ffffff","category_name_typography_font_size_tablet":{"unit":"px","size":26},"button_text":"View Collection","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"bb77daf","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","structure":"20","padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"0","left":"30","isLinked":false}},"elements":[{"id":"65d0613","elType":"column","settings":{"_column_size":50,"_inline_size":null,"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"3b76501","elType":"widget","settings":{"categories":"lighting","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/banner15-2.jpg","id":2620},"category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":60},"category_name_typography_font_weight":"600","item_color":"rgba(255,255,255,0.7)","category_name_color":"#ffffff","category_name_typography_font_size_tablet":{"unit":"px","size":26},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_text":"View Collection","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"acfa46d","elType":"column","settings":{"_column_size":50,"_inline_size":null,"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"f0fc479","elType":"widget","settings":{"categories":"chairs","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/banner15-3.jpg","id":2621},"category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":60},"category_name_typography_font_weight":"600","item_color":"rgba(255,255,255,0.7)","category_name_color":"#ffffff","category_name_typography_font_size_tablet":{"unit":"px","size":26},"button_text":"View Collection","_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"7e5cc5a","elType":"section","settings":{"margin":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false},"gap":"no","stretch_section":"section-stretched","content_width":{"unit":"px","size":1400},"padding_tablet":{"unit":"px","top":"0","right":"30","bottom":"0","left":"30","isLinked":false}},"elements":[{"id":"52b99c7","elType":"column","settings":{"_column_size":100},"elements":[{"id":"4b4f0ee","elType":"widget","settings":{"title":"Popular Items","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_size_tablet":{"unit":"px","size":26},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"493e569","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"1c40523","elType":"widget","settings":{"limit":3,"column":"3","_padding":{"unit":"px","top":"20","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":true},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"78334bb","elType":"widget","settings":{"color":"#eeeeee","_padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"644bd79","elType":"section","settings":{"margin":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false},"gap":"no"},"elements":[{"id":"e74a1cd","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"padding":{"unit":"%","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size":null},"elements":[{"id":"c731869","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30"},"elements":[{"id":"3a45393","elType":"column","settings":{"_column_size":33,"_inline_size":40.118999999999999772626324556767940521240234375,"space_between_widgets":0},"elements":[{"id":"1786b98","elType":"widget","settings":{"title":"The Auros","align":"right","title_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":11},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2},"_animation":"opal-move-right","align_mobile":"center","animation_duration":"fast"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"659a08c","elType":"column","settings":{"_column_size":33,"_inline_size":15.23799999999999954525264911353588104248046875,"space_between_widgets":0},"elements":[{"id":"b789e4c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home11_icon.png","id":2340},"hover_animation":"grow","_animation":"zoomIn","_padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"ba79391","elType":"column","settings":{"_column_size":33,"_inline_size":44.64200000000000301270119962282478809356689453125,"space_between_widgets":0},"elements":[{"id":"e991761","elType":"widget","settings":{"title":"Furnitures","align":"left","title_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":11},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2},"_animation":"opal-move-left","align_mobile":"center","animation_duration":"fast"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true},{"id":"417f1e1","elType":"widget","settings":{"editor":"<p>Since 1991, Auros Furniture has been a purveyor of quality modern furniture in Ohi. With 20 international brands and counting in 2 shops along Jalan Maarof, Bangsar, Auros has a plethora of choices for design connoisseurs. Offering designer sofas, designer chairs, designer dining tables, designer outdoor furniture, upholstery fabric and more, we\u2019re proud to be the best furniture shop in Bangsar dosui amet.<\/p>","align":"center","_padding":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"bd68212","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home11_sig.png","id":2334},"image_size":"full","_padding":{"unit":"px","top":"40","right":"0","bottom":"70","left":"0","isLinked":false},"_animation":"opal-move-up","_padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"78795a1","elType":"widget","settings":{"text":"+ Join our mailing list","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","align":"center","_animation":"opal-move-up","_animation_delay":400,"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":0.5},"_background_background":"classic","hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"a74b4df","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":680},"gap":"no","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h2_bg_1.jpg","id":1835},"background_position":"center center","background_attachment":"fixed","padding":{"unit":"px","top":"200","right":"20","bottom":"200","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"10","bottom":"60","left":"10","isLinked":false},"margin":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"11885ee","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"59c86dd","elType":"widget","settings":{"title":"Newsletter","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","_animation_delay":100,"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"97e0dc5","elType":"widget","settings":{"editor":"<p>It only takes a second to be the first to find out about our latest news and promotions...<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"d7faf72","elType":"widget","settings":{"hide_icon":"none","width_input":{"unit":"%","size":70},"width_input_mobile":{"unit":"%","size":100},"width_button":{"unit":"%","size":30},"width_button_mobile":{"unit":"%","size":100},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_bacground":"#222222","button_bacground_hover":"#eb7025","button_color_hover":"#ffffff","button_border_hover":"#eb7025","border_button_border":"solid","border_button_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_button_color":"#222222","_animation":"opal-move-up","_animation_delay":300,"button_bacground_focus":"#eb7025","button_color_focus":"#ffffff","button_border_focus":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":false}],"isInner":false}],"header-06":[{"id":"e672a83","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"background_color":"rgba(0,0,0,0.5)"},"elements":[{"id":"ac4c3f5","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"5655023","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#ffffff","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#ffffff","title_tongle_color_hover":"#eb7025","full_width":"stretch","dropdown_layout":"canvas"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"8fe41bd","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"a7c671f","elType":"widget","settings":{"_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"right","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"ce2d6af","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"_inline_size_mobile":100},"elements":[{"id":"29576b7","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#ffffff","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#ffffff","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#ffffff","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"footer-05":[{"id":"9eb9648","elType":"section","settings":{"gap":"no","content_position":"middle","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"45","right":"40","bottom":"45","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","structure":"20","padding_mobile":{"unit":"px","top":"45","right":"20","bottom":"45","left":"20","isLinked":false}},"elements":[{"id":"c394b75","elType":"column","settings":{"_column_size":50,"_inline_size":75,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_inline_size_tablet":50},"elements":[{"id":"1af3850","elType":"widget","settings":{"align":"left","align_mobile":"center","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"9c8a25e","elType":"column","settings":{"_column_size":50,"_inline_size":25,"_inline_size_tablet":50},"elements":[{"id":"b564102","elType":"widget","settings":{"menu":"company","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#777777","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":5},"menu_space_between":{"unit":"px","size":35},"color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","menu-toggle-title":"Menu","align_items_mobile":"justify"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false},{"id":"bf33fbd","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#f5f5f5","padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"490ab13","elType":"column","settings":{"_column_size":100},"elements":[{"id":"f9605a1","elType":"widget","settings":{"color":"#eeeeee","gap":{"unit":"px","size":0}},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"674a82f","elType":"section","settings":{"structure":"30","gap":"no","padding":{"unit":"px","top":"35","right":"40","bottom":"60","left":"40","isLinked":false},"padding_tablet":{"unit":"px","top":"35","right":"40","bottom":"0","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","padding_mobile":{"unit":"px","top":"35","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"5fcc390","elType":"column","settings":{"_column_size":33,"_inline_size":42,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"d422c55","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br>United State<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"a6b1085","elType":"column","settings":{"_column_size":33,"_inline_size":32.66599999999999681676854379475116729736328125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"fe4eb61","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"f621c6b","elType":"column","settings":{"_column_size":33,"_inline_size":25},"elements":[{"id":"b9f88c8","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f"}],"align":"left","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"#888888","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-10","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"87d8969","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"45","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","padding_mobile":{"unit":"px","top":"45","right":"20","bottom":"45","left":"20","isLinked":false}},"elements":[{"id":"7b05ba4","elType":"column","settings":{"_column_size":100},"elements":[{"id":"dd4a505","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong> All rights reserved.<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"header-05":[{"id":"195cd4c","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"30","right":"40","bottom":"30","left":"40","isLinked":false}},"elements":[{"id":"7c055a3","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":50},"elements":[{"id":"9b43416","elType":"widget","settings":{"align":"left","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"d5c4687","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":50,"_inline_size_mobile":50},"elements":[{"id":"8b6d566","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"popup","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":14},"dropdown_typography_font_size_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"4370b09","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":100},"elements":[{"id":"c21241e","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"home1_tab_-all":[{"id":"6c3d3e8","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"de98d3b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"5edc612","elType":"widget","settings":{"categories":"all","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h8-img3.jpg","id":2557},"text_align_v":"flex-end","button_text":"View Collection","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":40},"category_name_typography_font_weight":"600","category_name_typography_line_height":{"unit":"px","size":48},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"2d91c87a","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"2ff9ec55","elType":"widget","settings":{"limit":4,"column":"2","categories":["sofas"]},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home1_tab_-decor":[{"id":"2c0dd8b","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"1dd0f9b0","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"d1bd994","elType":"widget","settings":{"categories":"decor","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate4.jpg","id":2155},"text_align_v":"flex-end","button_text":"View Collection","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":42},"category_name_typography_font_weight":"600","category_name_typography_line_height":{"unit":"px","size":60},"category_name_color_hover":"#eb7025","category_name_color":"#222222"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"1ee82905","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100},"elements":[{"id":"7b473d6c","elType":"widget","settings":{"limit":4,"column":"2","categories":["decor"]},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"header-04":[{"id":"bcb1c6d","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"30","bottom":"40","left":"30","isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding_mobile":{"unit":"px","top":"20","right":"15","bottom":"20","left":"15","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":false}},"elements":[{"id":"fe2b62a","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"bf86630","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"dcdf6cc","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":80,"_inline_size_mobile":50},"elements":[{"id":"e4ba16e","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","toggle_align":"right","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":13},"menu_typography_font_weight":"600","menu_typography_text_transform":"uppercase","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#ffffff","color_menu_item_hover":"#ffffff","color_menu_item_active":"#ffffff","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(255,255,255,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#ffffff","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.5)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.5)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","align_items":"center","align_items_tablet":"left","menu_typography_letter_spacing":{"unit":"px","size":0.5},"dropdown_layout":"canvas","menu_space_between_tablet":{"unit":"px","size":8}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"a27b58b","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":20,"_inline_size_mobile":100},"elements":[{"id":"af513bd","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#ffffff","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#ffffff","name_text_hover_color":"#eb7025","icon_color":"#ffffff","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#ffffff","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"home1_tab_-lighting":[{"id":"2ba7fc0d","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"75dcf53d","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[{"id":"7eb7abe","elType":"widget","settings":{"categories":"lighting","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate3.jpg","id":2138},"text_align_v":"flex-end","button_text":"View Collection","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":42},"category_name_typography_font_weight":"600","category_name_typography_line_height":{"unit":"px","size":60},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"4328c959","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"52394c79","elType":"widget","settings":{"limit":4,"column":"2","categories":["lighting"]},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home1_tab_-chairs":[{"id":"8b1b10e","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"2d874033","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[{"id":"f6900ae","elType":"widget","settings":{"categories":"chairs","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate2.jpg","id":2127},"text_align_v":"flex-end","button_text":"View Collection","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":42},"category_name_typography_font_weight":"600","category_name_typography_line_height":{"unit":"px","size":60},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"26c53107","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"2e0728fb","elType":"widget","settings":{"limit":4,"column":"2","categories":["chairs"]},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home-19":[{"id":"334f438","elType":"section","settings":{"gap":"no","custom_height":{"unit":"px","size":440},"structure":"22","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1440}},"elements":[{"id":"4832ead","elType":"column","settings":{"_column_size":66,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#fcf2ed","background_position":"top right","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_position":"top right","background_hover_repeat":"no-repeat","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-1.png","id":2398},"background_hover_color":"#f9f7ea","background_hover_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-1.png","id":2398},"background_hover_transition":{"unit":"px","size":0.5},"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"css_classes":"overflow-hidden","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding":{"unit":"px","top":"50","right":"50","bottom":"350","left":"50","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"880de34","elType":"widget","settings":{"title":"Box Vinta","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"a0ad2b8","elType":"widget","settings":{"editor":"<p>Lighting<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"bf2da3e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#f5f5f5","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-2-1.png","id":2429},"background_position":"top right","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#e8e8e8","background_hover_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-2-1.png","id":2429},"background_hover_position":"top right","background_hover_repeat":"no-repeat","background_hover_transition":{"unit":"px","size":0.5},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"50","right":"50","bottom":"350","left":"50","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"7b19f99","elType":"widget","settings":{"title":"Jasper Sofa","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"ed28257","elType":"widget","settings":{"editor":"<p>FUNITURE<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"64b6c17","elType":"section","settings":{"gap":"no","structure":"21","stretch_section":"section-stretched"},"elements":[{"id":"178745e","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#e6f4f7","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-3.png","id":2437},"background_position":"bottom right","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#d9f0f7","background_hover_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-3.png","id":2437},"background_hover_position":"bottom right","background_hover_repeat":"no-repeat","margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding":{"unit":"px","top":"50","right":"50","bottom":"350","left":"50","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":350},"elements":[{"id":"cacc735","elType":"widget","settings":{"title":"Skype Ceramic","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"2900b7b","elType":"widget","settings":{"editor":"<p>Ceramic<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"be097ff","elType":"column","settings":{"_column_size":66,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#f5f5f5","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-4.png","id":2438},"background_position":"bottom right","background_repeat":"no-repeat","background_hover_background":"classic","background_hover_color":"#f4ebeb","background_hover_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-4.png","id":2438},"background_hover_position":"bottom right","background_hover_repeat":"no-repeat","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":450},"elements":[{"id":"773e6a5","elType":"widget","settings":{"title":"Atony Side","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":30},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"09de996","elType":"widget","settings":{"editor":"<p>Sideboards<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"16a7f31","elType":"widget","settings":{"space":{"unit":"px","size":300}},"elements":[],"widgetType":"spacer"},{"id":"0e85392","elType":"widget","settings":{"text":"+ VIEW DETAIL","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"_animation_delay":400,"hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"f72546e","elType":"section","settings":{"gap":"no","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-5.png","id":2453},"background_position":"center center","background_repeat":"no-repeat","padding":{"unit":"px","top":"300","right":"0","bottom":"300","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"150","right":"0","bottom":"150","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"stretch_section":"section-stretched"},"elements":[{"id":"8b0a9aa","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"5cf4405","elType":"widget","settings":{"title":"Welcome to Auros!","header_size":"h3","align":"center","title_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":3},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"d4c547c","elType":"widget","settings":{"editor":"<p><strong><span style=\"color: #eb7025;\">Auros\u00ae<\/span><\/strong> is a curation of minimalist styles<br \/>that inspire us.<\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":46},"typography_font_size_mobile":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":56},"typography_line_height_mobile":{"unit":"px","size":46},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"44943c1","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"stretch_section":"section-stretched"},"elements":[{"id":"564cfb4","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"2a44391","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"ac6196c","tab_template":"2184"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"08344e0","tab_template":"1983"},{"tab_title":"Chairs          ","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"3169eda","tab_template":"2100"},{"tab_title":"Lighting","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"6c7f10b","tab_template":"2130"},{"tab_title":"Decor","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"98378fe","tab_template":"2141"}],"align_items":"center","tab_typography_typography":"custom","title_color":"#777777","title_active_color":"#777777","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"6","isLinked":false},"tab_title_margin":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"title_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_box_shadow_box_shadow_position":"inset","title_hover_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_hover_box_shadow_box_shadow_position":"inset","title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_active_box_shadow_box_shadow_position":"inset","align_items_tablet":"center","title_hover_box_shadow_box_shadow_type":"yes","padding_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-tabs"},{"id":"8d0b94c","elType":"widget","settings":{"text":"+ See all products","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"_animation":"opal-move-up","align":"center","hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"2cc88bf","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"gap":"no","background_background":"classic","background_position":"center center","background_attachment":"fixed","background_repeat":"no-repeat"},"elements":[{"id":"a9edd1c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"72af280","elType":"section","settings":{"gap":"no","structure":"20","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h19-img-6.jpg","id":3602},"background_position":"center center","background_attachment":"fixed","background_repeat":"no-repeat","background_size":"cover","padding":{"unit":"px","top":"215","right":"0","bottom":"215","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"0","bottom":"100","left":"0","isLinked":false}},"elements":[{"id":"cfb9315","elType":"column","settings":{"_column_size":50,"_inline_size":40.21399999999999863575794734060764312744140625,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[{"id":"65f1c98","elType":"widget","settings":{"title":"White Brush DS","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":50},"typography_font_size_mobile":{"unit":"px","size":40},"typography_font_weight":"700","typography_text_transform":"uppercase","typography_line_height_mobile":{"unit":"px","size":50},"typography_letter_spacing":{"unit":"px","size":2},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"cf8cbfc","elType":"widget","settings":{"editor":"<p>designed by <strong>Nicolash<\/strong><\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_letter_spacing":{"unit":"px","size":1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"ce08fc0","elType":"widget","settings":{"color":"#eb7025","width":{"unit":"px","size":40},"align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"divider"},{"id":"717550e","elType":"widget","settings":{"id_product":"992","show_title":"none","show_rating":"none","show_description":"none","show_quantity":"none","align":"center","_animation":"opal-move-up","price_typography_typography":"custom","price_typography_font_weight":"600","price_color":"#000000","typography_typography":"custom","typography_font_weight":"600","button_text_color":"#000000","background_color_background":"classic","background_color_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#000000","hover_color":"#ffffff","background_color_hover_background":"classic","background_color_hover_color":"#eb7025","border_hover_border":"solid","border_hover_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_hover_color":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-single-product"}],"isInner":true},{"id":"f778333","elType":"column","settings":{"_column_size":50,"_inline_size":59.78600000000000136424205265939235687255859375,"_inline_size_tablet":100,"space_between_widgets":0},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"9da075a","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"130","right":"0","bottom":"130","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"stretch_section":"section-stretched"},"elements":[{"id":"1f02dc3","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"ddc989a","elType":"widget","settings":{"title":"Our Blogs","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"a1d93dc","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"049fa18","elType":"widget","settings":{"posts_per_page":2,"categories":["healthy"],"column":"2","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","style":"post-style-3","column_tablet":"1","column_mobile":"1","animation_duration":"fast"},"elements":[],"widgetType":"opal-post-grid"},{"id":"c977e94","elType":"widget","settings":{"text":"+ Read All Blogs","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"50","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/blog-list\/","is_external":"","nofollow":""},"align":"center","hover_color":"#eb7025","_animation":"opal-move-up","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"fce96e2","elType":"section","settings":{"gap":"no","structure":"40","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","margin":{"unit":"px","top":"0","right":0,"bottom":"120","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false}},"elements":[{"id":"b175f4d","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"a33e9e8","elType":"widget","settings":{"title_text":"Free shipping","description_text":"on all orders over $49.00","icon":"opal-icon-ship","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"icon_size":{"unit":"px","size":60}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"299626a","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"8cdc0d5","elType":"widget","settings":{"title_text":"15 days returns","description_text":"moneyback guarantee","icon":"opal-icon-return","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"icon_size":{"unit":"px","size":40}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"007628b","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ddcc970","elType":"widget","settings":{"title_text":"Secure checkout","description_text":"100% protected by Paypal","icon":"opal-icon-checkout","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"icon_size":{"unit":"px","size":45}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"b9ee5d8","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"067ce93","elType":"widget","settings":{"title_text":"100% free warranty ","description_text":"moneyback guarantee","icon":"opal-icon-coupon","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"icon_size":{"unit":"px","size":45}},"elements":[],"widgetType":"icon-box"}],"isInner":false}],"isInner":false},{"id":"b0a886e","elType":"section","settings":{"content_width":{"unit":"px","size":1014},"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"120","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"87735fe","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d251269","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_text":"Search","size":{"unit":"px","size":80},"input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_text_color":"#666666","input_background_color_background":"classic","input_background_color_color":"#ffffff","input_border_border":"solid","input_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"input_border_color":"#eeeeee","button_text_color":"#000000","button_background_color_background":"classic","button_background_color_color":"#ffffff","button_border_border":"solid","button_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"0","isLinked":false},"button_border_color":"#eeeeee","icon_size":{"unit":"px","size":20},"button_width":{"unit":"px","size":2.29999999999999982236431605997495353221893310546875},"button_width_mobile":{"unit":"px","size":1},"input_padding":{"unit":"px","top":"20","right":"30","bottom":"20","left":"30","isLinked":false},"button_background_color":"rgba(0,0,0,0)","button_text_color_hover":"#ffffff","button_background_color_hover":"#eb7025","button_border_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"0","isLinked":false},"border_button_search_color":"#eeeeee","button_search_padding":{"unit":"px","top":"20","right":"60","bottom":"20","left":"60","isLinked":false},"button_search_padding_mobile":{"unit":"px","top":"10","right":"20","bottom":"10","left":"20","isLinked":false}},"elements":[],"widgetType":"opal-search-form"}],"isInner":false}],"isInner":false}],"home-17":[{"id":"2ec62079","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","layout":"full_width","background_background":"classic","background_color":"#f5f5f5","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"7ec29b16","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"padding_mobile":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"75541474","elType":"widget","settings":{"limit":13,"column":"4","product_gutter":{"unit":"px","size":0},"product_style":"style-3","product_ajax":"yes"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"header-03":[{"id":"77c45c7","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"40","stretch_section":"section-stretched","content_width":{"unit":"px","size":1000},"background_background":"classic","layout":"full_width","background_color":"#f1f1f1","margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"6ccaf35","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50,"background_background":"classic","background_color":"#ffffff","padding":{"unit":"px","top":"25","right":"0","bottom":"25","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[{"id":"9d27d0c","elType":"widget","settings":{"align":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"3788261","elType":"column","settings":{"_column_size":25,"_inline_size":57,"space_between_widgets":0,"_inline_size_tablet":70,"_inline_size_mobile":50,"padding":{"unit":"px","top":"25","right":"0","bottom":"25","left":"40","isLinked":false},"padding_tablet":{"unit":"px","top":"15","right":"0","bottom":"15","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"15","right":"20","bottom":"15","left":"0","isLinked":false}},"elements":[{"id":"894cfba","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"popup","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":14},"dropdown_typography_font_size_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"42022d4","elType":"column","settings":{"_column_size":25,"_inline_size":20,"space_between_widgets":0,"_inline_size_tablet":30,"_inline_size_mobile":100,"padding":{"unit":"px","top":"25","right":"0","bottom":"25","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"15","right":"40","bottom":"15","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"3cb1e3c","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false},{"id":"863d9e6","elType":"column","settings":{"_column_size":25,"_inline_size":6,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":100,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"22be5d1","elType":"widget","settings":{"space":{"unit":"px","size":25},"hide_tablet":"hidden-tablet","hide_mobile":"hidden-phone"},"elements":[],"widgetType":"spacer"}],"isInner":false}],"isInner":false}],"footer-04":[{"id":"9c9200b","elType":"section","settings":{"gap":"no","structure":"40","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"40","bottom":"60","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"020","isLinked":false}},"elements":[{"id":"99878f0","elType":"column","settings":{"_column_size":25,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":50,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"15","bottom":"40","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"ce1be6d","elType":"widget","settings":{"align":"left","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"},{"id":"f7c08f8","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska Badalas <br \/>United State<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"cdc2104","elType":"widget","settings":{"editor":"<p>(+91)7-723-4608<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"5","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"},{"id":"122dd57","elType":"widget","settings":{"text":"Aurosfurniture@domain.vn","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":""},"button_text_color":"#222222","background_color":"rgba(0,0,0,0)","hover_color":"#eb7025","button_hover_border_color":"#eb7025","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"align_mobile":"center"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"da14116","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"e7d4054","elType":"widget","settings":{"title":"Our Products","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"55","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_font_weight":"600"},"elements":[],"widgetType":"heading"},{"id":"48b0498","elType":"widget","settings":{"menu":"acount","layout":"vertical","align_items":"left","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#666666","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":20},"align_items_mobile":"center","menu-toggle-title":"Menu","menu_space_between_mobile":{"unit":"px","size":10}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"5c91140","elType":"column","settings":{"_column_size":25,"_inline_size":17,"space_between_widgets":0,"_inline_size_tablet":25,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"f3437bb","elType":"widget","settings":{"title":"Useful Links","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"55","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"df699b8","elType":"widget","settings":{"menu":"company","layout":"vertical","align_items":"left","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#666666","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":20},"align_items_mobile":"center","menu-toggle-title":"Menu","menu_space_between_mobile":{"unit":"px","size":10}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"35552f6","elType":"column","settings":{"_column_size":25,"_inline_size":33,"space_between_widgets":0,"_inline_size_tablet":100},"elements":[{"id":"4c7d501","elType":"widget","settings":{"title":"Newsletter","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_margin":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"align_tablet":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"cdb78ff","elType":"widget","settings":{"editor":"<p>Stay Updated on all that\'s new add noteworthy<\/p>","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align_tablet":"center"},"elements":[],"widgetType":"text-editor"},{"id":"a3c4b0c","elType":"widget","settings":{"hide_icon":"none","spacing_icon":{"unit":"px","size":0},"width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"input_bacground":"rgba(255,255,255,0.01)","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1},"button_bacground":"rgba(0,0,0,0)","button_color":"#222222","border_button_border":"solid","border_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_button_color":"#dddddd","button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"button_margin":{"unit":"%","top":"0","right":"0","bottom":"0","left":"2","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"align_input_mobile":"center","input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_color_hover":"#eb7025","button_border_hover":"#eb7025","button_color_focus":"#eb7025","button_border_focus":"#eb7025","button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"27","left":"0","isLinked":false},"placeholder_color":"#666666"},"elements":[],"widgetType":"opal-mailchmip"},{"id":"a6a6956","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"d3bc26e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"4c628cc","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"0100f2f"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"fcab8b4"}],"shape":"square","align":"left","align_tablet":"center","align_mobile":"center","icon_color":"custom","icon_primary_color":"rgba(136,136,136,0)","icon_secondary_color":"#888888","icon_size":{"unit":"px","size":16},"icon_padding":{"unit":"em","size":0},"icon_spacing":{"unit":"px","size":12},"hover_primary_color":"rgba(0,0,0,0)","hover_secondary_color":"#eb7025","hover_animation":"pulse"},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"0556b6f","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#f5f5f5","padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"51a0ecf","elType":"column","settings":{"_column_size":100},"elements":[{"id":"caded4f","elType":"widget","settings":{"color":"#e5e5e5","gap":{"unit":"px","size":""}},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"c480f8a","elType":"section","settings":{"gap":"no","content_position":"middle","padding":{"unit":"px","top":"35","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#f5f5f5","padding_mobile":{"unit":"px","top":"30","right":"20","bottom":"35","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"35","right":"40","bottom":"35","left":"40","isLinked":false},"structure":"20"},"elements":[{"id":"ae0d122","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"0949d5b","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<a href=\"#\"><span style=\"color: #222222;\"><strong>Auros<\/strong><\/span><\/a>. All rights reserved.<\/p>","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"67e0a48","elType":"column","settings":{"_column_size":50,"_inline_size":null},"elements":[{"id":"f944d7e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/09\/paypal.png","id":1470},"image_size":"full","align":"right","align_mobile":"center"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"home1_tab_product":[{"id":"ba97dfc","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"56ca9c0","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[{"id":"cb1fd05","elType":"widget","settings":{"categories":"furnitures","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_images_cate.jpg","id":2087},"text_align_v":"flex-end","button_text":"View Collection","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":42},"category_name_typography_font_weight":"600","category_name_typography_line_height":{"unit":"px","size":60},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"63fba97","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"7192dac","elType":"widget","settings":{"limit":4,"column":"2","categories":["furnitures"]},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false}],"home-11":[{"id":"a5890f1","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_delay_time":"0.50"},"elements":[{"id":"65d0f00","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"30f0ba2","elType":"widget","settings":{"rev_alias":"home_11_slider"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"a5abc0d","elType":"section","settings":{"gap":"no","structure":"60","background_background":"classic","background_color":"#ffffff","box_shadow_box_shadow_type":"yes","box_shadow_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.05)"},"margin":{"unit":"px","top":"-85","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50","z_index":2},"elements":[{"id":"c6125f6","elType":"column","settings":{"_column_size":16,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d246ec7","elType":"widget","settings":{"icon":"opal-icon-stool","title_text":"Stool","description_text":"","hover_animation_wrapper":"grow","icon_margin":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"icon_size":{"unit":"px","size":40},"hover_primary_color":"#eb7025","title_color":"#777777","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"1","bottom":"0","left":"0","isLinked":false},"_border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"1cbee19","elType":"column","settings":{"_column_size":16,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f97aa78","elType":"widget","settings":{"icon":"opal-icon-table","title_text":"Table","description_text":"","hover_animation_wrapper":"grow","icon_margin":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"icon_size":{"unit":"px","size":40},"hover_primary_color":"#eb7025","title_color":"#777777","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"1","bottom":"0","left":"0","isLinked":false},"_border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"5e3a0bc","elType":"column","settings":{"_column_size":16,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"bd66b56","elType":"widget","settings":{"icon":"opal-icon-drawer","title_text":"Drawer","description_text":"","hover_animation_wrapper":"grow","icon_margin":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"icon_size":{"unit":"px","size":40},"hover_primary_color":"#eb7025","title_color":"#777777","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"1","bottom":"0","left":"0","isLinked":false},"_border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"fcfda7f","elType":"column","settings":{"_column_size":16,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"19cfedb","elType":"widget","settings":{"icon":"opal-icon-sofa","title_text":"Sofas","description_text":"","hover_animation_wrapper":"grow","icon_margin":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"icon_size":{"unit":"px","size":40},"hover_primary_color":"#eb7025","title_color":"#777777","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"1","bottom":"0","left":"0","isLinked":false},"_border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"ca23932","elType":"column","settings":{"_column_size":16,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"3b566be","elType":"widget","settings":{"icon":"opal-icon-armchair","title_text":"Armchair","description_text":"","hover_animation_wrapper":"grow","icon_margin":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"icon_size":{"unit":"px","size":40},"hover_primary_color":"#eb7025","title_color":"#777777","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"1","bottom":"0","left":"0","isLinked":false},"_border_width_mobile":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"614b5af","elType":"column","settings":{"_column_size":16,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"4753304","elType":"widget","settings":{"icon":"opal-icon-lamp","title_text":"Lamp","description_text":"","hover_animation_wrapper":"grow","icon_margin":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"icon_size":{"unit":"px","size":40},"hover_primary_color":"#eb7025","title_color":"#777777","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"35","right":"0","bottom":"35","left":"0","isLinked":false},"_background_hover_background":"classic","_background_hover_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"0","right":"1","bottom":"0","left":"0","isLinked":false},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":3,"blur":10,"spread":0,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":false}],"isInner":false},{"id":"9218e80","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"140","right":"0","bottom":"0","left":"0","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"45690b6","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"padding":{"unit":"%","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"547302d","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","content_delay_time":"0.50"},"elements":[{"id":"89b72b1","elType":"column","settings":{"_column_size":33,"_inline_size":40.118999999999999772626324556767940521240234375,"space_between_widgets":0,"_inline_size_mobile":33},"elements":[{"id":"800a322","elType":"widget","settings":{"title":"The Auros","align":"right","title_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":11},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2},"align_mobile":"center"},"elements":[],"widgetType":"heading"}],"isInner":true},{"id":"9b3afd4","elType":"column","settings":{"_column_size":33,"_inline_size":15.23799999999999954525264911353588104248046875,"space_between_widgets":0,"_inline_size_mobile":33},"elements":[{"id":"9cbb257","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home11_icon.png","id":2340},"hover_animation":"grow"},"elements":[],"widgetType":"image"}],"isInner":true},{"id":"1ad2b04","elType":"column","settings":{"_column_size":33,"_inline_size":44.64200000000000301270119962282478809356689453125,"space_between_widgets":0,"_inline_size_mobile":33},"elements":[{"id":"f25e3be","elType":"widget","settings":{"title":"Furnitures","align":"left","title_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":11},"typography_font_weight":"400","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2},"align_mobile":"center"},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true},{"id":"bd8058e","elType":"widget","settings":{"editor":"<p>Since 1991, Auros Furniture has been a purveyor of quality modern furniture in Ohi. With 20 international brands and counting in 2 shops along Jalan Maarof, Bangsar, Auros has a plethora of choices for design connoisseurs. Offering designer sofas, designer chairs, designer dining tables, designer outdoor furniture, upholstery fabric and more, we\u2019re proud to be the best furniture shop in Bangsar dosui amet.<\/p>","align":"center","_padding":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"1e3ff56","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home11_sig.png","id":2334},"image_size":"full","_padding":{"unit":"px","top":"40","right":"0","bottom":"70","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image"},{"id":"bc0f43f","elType":"widget","settings":{"text":"+ Join our mailing list","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","align":"center","_animation_delay":400,"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":0.5},"_background_background":"classic","hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"a434eea","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"140","right":"0","bottom":"0","left":"0","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"49dc644","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"ad505b9","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"89c97c2","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom"},"elements":[],"widgetType":"text-editor"},{"id":"2c97eed","elType":"widget","settings":{"limit":8,"column":"4","_padding":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"e37a982","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop","is_external":"on","nofollow":""},"align":"center","_animation_delay":400,"typography_letter_spacing":{"unit":"px","size":0.5},"_background_background":"classic","hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"62325f3","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","margin":{"unit":"px","top":"140","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"960bbeb","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"57f4528","elType":"widget","settings":{"skin":"cover","bg_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h6-img2.jpg","id":1297},"bg_image_size":"full","title":"#Furnitures","description":"New Design 2018","button":"Shop Now","link":{"url":"#","is_external":"","nofollow":""},"min-height":{"unit":"px","size":645},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":15},"title_typography_font_weight":"400","title_typography_text_transform":"uppercase","title_typography_line_height":{"unit":"px","size":22},"title_typography_letter_spacing":{"unit":"px","size":1},"title_spacing":{"unit":"px","size":20},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":60},"description_typography_font_weight":"700","description_typography_text_transform":"uppercase","description_typography_line_height":{"unit":"px","size":50},"description_typography_letter_spacing":{"unit":"px","size":2},"description_spacing":{"unit":"px","size":50},"title_color":"#ffffff","description_color":"#ffffff","button_color":"#ffffff","button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":15},"button_typography_font_weight":"600","button_typography_line_height":{"unit":"px","size":24},"button_typography_letter_spacing":{"unit":"px","size":0.5},"button_text_color":"#ffffff","button_background_color":"rgba(0,0,0,0)","button_border_color":"#ffffff","button_hover_background_color":"#eb7025","button_hover_border_color":"#eb7025","button_border_width":{"unit":"px","size":1},"button_border_radius":{"unit":"px","size":0},"content_animation_duration":{"unit":"px","size":1500},"sequenced_animation":"elementor-cta--sequenced-animation","transformation":"move-up","min-height_mobile":{"unit":"px","size":500},"description_typography_font_size_mobile":{"unit":"px","size":40},"button_padding":{"unit":"px","top":"12","right":"60","bottom":"12","left":"60","isLinked":false}},"elements":[],"widgetType":"call-to-action"}],"isInner":false}],"isInner":false},{"id":"fa04cc3","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"130","right":"0","bottom":"50","left":"0","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"aabd38c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"82baef6","elType":"widget","settings":{"title":"Our Blogs","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"7672fcc","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"0bb8706","elType":"widget","settings":{"posts_per_page":2,"column":"2","style":"post-style-3","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false}],"home-10":[{"id":"dac63cc","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","html_tag":"div","column_position":"stretch","custom_height":{"unit":"px","size":""}},"elements":[{"id":"9312dcc","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"45edba0","elType":"widget","settings":{"rev_alias":"home_10"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false}],"footer-03":[{"id":"ffd6642","elType":"section","settings":{"structure":"40","gap":"no","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"border_color":"rgba(255,255,255,0.1)"},"elements":[{"id":"d06c920","elType":"column","settings":{"_column_size":25,"_inline_size":19.6700000000000017053025658242404460906982421875,"margin_mobile":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"56ff3f8","elType":"widget","settings":{"align":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/logo_footer_home_3.png","id":1963},"align_mobile":"center","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"c14e23d","elType":"column","settings":{"_column_size":25,"_inline_size":31.3299999999999982946974341757595539093017578125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"_inline_size_tablet":50,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"7c64295","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br \/>United State<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"16caefc","elType":"column","settings":{"_column_size":25,"_inline_size":26,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"3844bbe","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"cd80589","elType":"column","settings":{"_column_size":25,"_inline_size":23,"_inline_size_tablet":50,"space_between_widgets":0},"elements":[{"id":"5ce7602","elType":"widget","settings":{"form_name":"Newsletter","sub_title":"Stay Updated on all that\u2019s new add noteworthy","text":"+ JOIN OUR NEWSLETTER","background_color":"rgba(255,216,212,0)","border_width":{"unit":"px","top":"0","right":"0","bottom":"9","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","align_mobile":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"spacing_icon":{"unit":"px","size":0},"title_spacing":{"unit":"px","size":10},"heading_color":"#000000","width_input":{"unit":"%","size":73},"width_button":{"unit":"%","size":25},"heading_typography_font_size":{"unit":"px","size":24},"background_color_form":"#ffffff","width_form":{"unit":"px","size":500},"padding_form":{"unit":"px","size":30,"top":"40","right":"40","bottom":"50","left":"40"},"form_align":"center","hide_icon":"none","placeholder_color":"#666666","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_input_color":"#dddddd","input_padding":{"unit":"px","top":"7","right":"0","bottom":"7","left":"0","isLinked":false},"typography_mailchip_button_typography":"custom","typography_mailchip_button_font_size":{"unit":"px","size":14},"typography_mailchip_button_font_weight":"600","typography_mailchip_button_text_transform":"uppercase","typography_mailchip_button_letter_spacing":{"unit":"px","size":1},"mailchip_button_color":"#222222","mailchip_button_color_hover":"#eb7025","mailchip_button_border_hover":"#eb7025","mailchip_button_color_focus":"#eb7025","mailchip_button_border_focus":"#eb7025","border_mailchip_button_border":"solid","border_mailchip_button_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_mailchip_button_color":"#dddddd","mailchip_button_padding":{"unit":"px","top":"7","right":"10","bottom":"7","left":"10","isLinked":false},"mailchip_button_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"8","isLinked":false},"width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"heading_typography_typography":"custom","width_form_mobile":{"unit":"px","size":320},"align_input_mobile":"center","mailchip_button_bacground":"rgba(0,0,0,0)","mailchip_button_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"subtitle_spacing":{"unit":"px","size":5},"subtitle_color":"#666666","subtitle_typography_typography":"custom","subtitle_typography_font_size":{"unit":"px","size":14},"subtitle_typography_font_weight":"400","input_bacground":"rgba(0,0,0,0)","hover_animation":"grow"},"elements":[],"widgetType":"opal-button-mailchimp"}],"isInner":false}],"isInner":false},{"id":"466fc5a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#202020","margin_mobile":{"unit":"%","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"45","left":"020","isLinked":false}},"elements":[{"id":"02728c2","elType":"column","settings":{"_column_size":100},"elements":[{"id":"b96fbc0","elType":"widget","settings":{"color":"rgba(255,255,255,0.1)","gap":{"unit":"px","size":""},"_background_background":"classic","_background_color":"#202020"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"4c0d962","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"40","bottom":"35","left":"40","isLinked":false},"stretch_section":"section-stretched","background_background":"classic","background_color":"#202020","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"35","left":"20","isLinked":false},"structure":"20"},"elements":[{"id":"23d41a8","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0854de8","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<span style=\"color: #ffffff;\"><strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong><\/span> All rights reserved.<\/p>","text_color":"#bbbbbb","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"5d771e2","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"0157923","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f"}],"align":"right","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"rgba(255,255,255,0.5)","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"-5","bottom":"0","left":"0","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false}],"home-12":[{"id":"08fd6e9","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_width":{"unit":"px","size":1710},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"cbdd915","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"8bf8fd9","elType":"widget","settings":{"rev_alias":"home-12"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"6354bc6","elType":"section","settings":{"gap":"no","structure":"40","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"80","right":"40","bottom":"80","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[{"id":"108d225","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"49e56d3","elType":"widget","settings":{"icon":"opal-icon-ship","title_text":"Free shipping","description_text":"on all orders over $49.00","position":"left","icon_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"5c974f5","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"d1c7116","elType":"widget","settings":{"icon":"opal-icon-return","title_text":"15 days returns","description_text":"moneyback guarantee","position":"left","icon_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"9f4bc43","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"07ec4a2","elType":"widget","settings":{"icon":"opal-icon-checkout","title_text":"Secure checkout","description_text":"100% protected by Paypal","position":"left","icon_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"57aea6c","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"8d0992a","elType":"widget","settings":{"icon":"opal-icon-coupon","title_text":"moneyback guarantee","description_text":"on all orders over $49.00","position":"left","icon_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-box"}],"isInner":false}],"isInner":false},{"id":"d8e007a","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"ca4e903","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d9b6ef5","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"ac6196c","tab_template":"3660"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"08344e0","tab_template":"3676"},{"tab_title":"Chairs          ","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"3169eda","tab_template":"3689"},{"tab_title":"Lighting","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"6c7f10b","tab_template":"3693"},{"tab_title":"Decor","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"98378fe","tab_template":"3705"},{"tab_title":"Accessories","source":"template","tab_html":"<p>Tab Content<\/p>","tab_template":"3739","_id":"1bcde39"}],"align_items":"center","title_color":"#777777","title_active_color":"#777777","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"6","isLinked":false},"tab_title_margin":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"title_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_box_shadow_box_shadow_position":"inset","title_hover_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_hover_box_shadow_box_shadow_position":"inset","title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_active_box_shadow_box_shadow_position":"inset","align_items_tablet":"center","title_hover_box_shadow_box_shadow_type":"yes","padding_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false},"tab_typography_typography":"custom","tab_typography_font_size":{"unit":"px","size":22},"tab_typography_font_weight":"600","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false},{"id":"333f0ab","elType":"section","settings":{"gap":"no","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false},"content_width":{"unit":"px","size":555},"border_border":"solid"},"elements":[{"id":"5cbf69d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"6c92c06","elType":"widget","settings":{"editor":"<p>Get <span style=\"color: #eb7025;\">25%<\/span> discount<\/p>","align":"center","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"a536378","elType":"widget","settings":{"editor":"<p>Get fresh Auros trends and unique gift ideas delivered right to your inbox.<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"20eee8b","elType":"widget","settings":{"hide_icon":"none","width_input":{"unit":"%","size":68},"width_button":{"unit":"%","size":28},"border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"border_input_color":"#eeeeee","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_bacground":"rgba(0,0,0,0)","button_color":"#222222","border_button_border":"solid","border_button_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_button_color":"#222","width_input_mobile":{"unit":"%","size":100},"width_button_mobile":{"unit":"%","size":100},"input_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","button_bacground_hover":"#eb7025","button_color_hover":"#ffffff","button_border_hover":"#eb7025","button_bacground_focus":"#eb7025","button_color_focus":"#ffffff","button_border_focus":"#eb7025","input_bacground":"rgba(0,0,0,0)","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":false}],"isInner":false}],"payment-method":[{"id":"0130abb","elType":"section","settings":{"gap":"no","structure":"20","padding":{"unit":"px","top":"70","right":"0","bottom":"55","left":"0","isLinked":false},"content_width":{"unit":"px","size":1160}},"elements":[{"id":"12f6ce6","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"62d9243","elType":"widget","settings":{"icon_list":[{"text":"What payment methods do you accept?","icon":"fa fa-question-circle-o","_id":"5ebd635","link":{"url":"","is_external":"","nofollow":""}}],"icon_color":"#000000","icon_size":{"unit":"px","size":24},"text_color":"#000000","text_indent":{"unit":"px","size":10},"icon_typography_typography":"custom","icon_typography_font_size":{"unit":"px","size":24},"icon_typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"6957491","elType":"widget","settings":{"editor":"<p>We accept the following payment options:<\/p>"},"elements":[],"widgetType":"text-editor"},{"id":"1285617","elType":"widget","settings":{"icon_list":[{"text":"Visa","icon":"fa fa-check-circle","_id":"581956a","link":{"url":"","is_external":"","nofollow":""}},{"text":"Visa Debit","icon":"fa fa-check-circle","_id":"85abde6","link":{"url":"","is_external":"","nofollow":""}},{"text":"Mastercard","icon":"fa fa-check-circle","_id":"0416744","link":{"url":"","is_external":"","nofollow":""}},{"text":"PayPal","icon":"fa fa-check-circle","_id":"38e3e8e","link":{"url":"","is_external":"","nofollow":""}},{"text":"Apple Pay","icon":"fa fa-check-circle","_id":"18a758c","link":{"url":"","is_external":"","nofollow":""}}],"space_between":{"unit":"px","size":3},"icon_color":"#000000","icon_size":{"unit":"px","size":16},"text_color":"#000000","text_indent":{"unit":"px","size":10},"icon_typography_typography":"custom","icon_typography_font_weight":"600","_padding":{"unit":"px","top":"035","right":"0","bottom":"35","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"a37c1f7","elType":"widget","settings":{"editor":"<p>All credit and debit card holders are subject to validation and<br \/>authorisation by both Auros and the card issuer, to maintain<br \/>security and prevent fraud.<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"216a9b4","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"c81fafd","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/payment_images.png","id":1751},"align":"left","_padding_mobile":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"224884f","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"gap":"no","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"a15f425","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e5f4bac","elType":"widget","settings":{"color":"#eeeeee"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"ad58d66","elType":"section","settings":{"gap":"no","border_width":{"unit":"px","top":"1","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"55","right":"0","bottom":"55","left":"0","isLinked":false},"content_width":{"unit":"px","size":1160}},"elements":[{"id":"fbc120e","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"0910f2e","elType":"section","settings":{"gap":"no"},"elements":[{"id":"201d420","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"459ee9c","elType":"widget","settings":{"icon_list":[{"text":"When will payment be taken?","icon":"fa fa-question-circle-o","_id":"5ebd635","link":{"url":"","is_external":"","nofollow":""}}],"icon_color":"#000000","icon_size":{"unit":"px","size":24},"text_color":"#000000","text_indent":{"unit":"px","size":10},"icon_typography_typography":"custom","icon_typography_font_size":{"unit":"px","size":24},"icon_typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"}],"isInner":true}],"isInner":true},{"id":"f655261","elType":"section","settings":{"gap":"no","structure":"20"},"elements":[{"id":"a54fa3f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"110","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ba290fc","elType":"widget","settings":{"editor":"<p>If your card is authorised, we\u2019ll send you an email confirming your order has been successful.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"c87d1c5","elType":"widget","settings":{"editor":"<p>Payment will then be taken upon dispatch.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"1e9b89c","elType":"widget","settings":{"editor":"<p>If your card is not authorised, payment will not be taken and we\u2019ll email you to let you know that your bank or card issuer wouldn\u2019t authorise the payment.<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"7087a29","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"110","bottom":"0","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"4ce7c70","elType":"widget","settings":{"editor":"<p>Please take great care to enter all your details accurately during checkout, as often incorrect or incomplete information can result in your bank or card issuer declining payment.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"35","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"e90b9d6","elType":"widget","settings":{"editor":"<p>If you\u2019re unsure why your payment is declined, please contact your card issuer or bank.<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"617a0bf","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"gap":"no","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"dd4d334","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"9f339a3","elType":"widget","settings":{"color":"#eeeeee"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"0a64068","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"55","right":"0","bottom":"55","left":"0","isLinked":false},"padding_tablet":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"content_width":{"unit":"px","size":1160}},"elements":[{"id":"11714c6","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"353cef9","elType":"section","settings":{"gap":"no"},"elements":[{"id":"7be0b72","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a6106f5","elType":"widget","settings":{"icon_list":[{"text":"What currencies do you accept?","icon":"fa fa-question-circle-o","_id":"5ebd635","link":{"url":"","is_external":"","nofollow":""}}],"icon_color":"#000000","icon_size":{"unit":"px","size":24},"text_color":"#000000","text_indent":{"unit":"px","size":10},"icon_typography_typography":"custom","icon_typography_font_size":{"unit":"px","size":24},"icon_typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"icon-list"},{"id":"b7ac5e2","elType":"widget","settings":{"editor":"<p>We only accept payment in pounds sterling.<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"d71c97f","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1440},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin":{"unit":"px","top":"60","right":0,"bottom":"120","left":0,"isLinked":false}},"elements":[{"id":"7faaed0","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"4b10a1c","elType":"widget","settings":{"title":"Need a Support?","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":62},"_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"7c2bd29","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"40","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"5cfa2cd","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"d747e5e","elType":"widget","settings":{"icon":"opal-icon-chat-support","title_text":"Chat Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"21390b5","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"09f75bf","elType":"widget","settings":{"icon":"opal-icon-tweet-support","title_text":"Tweet Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"e278959","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"4bf0d34","elType":"widget","settings":{"icon":"opal-icon-phone-support","title_text":"Phone Consultant","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"3709f13","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"0a8f6ae","elType":"widget","settings":{"icon":"opal-icon-forum","title_text":"Visit Our Forum","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"shipping-method":[{"id":"c9ca4ff","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"120","right":"0","bottom":"60","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"content_width":{"unit":"px","size":1160}},"elements":[{"id":"d0f17bb","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"feb9526","elType":"section","settings":{"gap":"no"},"elements":[{"id":"4a5ae86","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"1b6a792","elType":"widget","settings":{"title":"UK Delivery","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"c36b67a","elType":"widget","settings":{"editor":"<p>We offer a UK standard and UK next day service.<\/p>","_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"3c4c8ee","elType":"widget","settings":{"table_head_repeater":[{"table_text":"Delivery Option ","_id":"3fe4e16","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":""},{"table_text":"Time","_id":"f2ba561","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":""},{"table_text":"Cost","_id":"90ba222","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":""}],"table_body_repeater":[{"table_elem_type":"row","_id":"c82d63b","table_cell_type":"td","table_text":"","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"UK Standard Delivery","_id":"b8595c1","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"3-5 working days","_id":"42d59f6","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"FREE","_id":"16dee8e","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"row","_id":"5efd791","table_cell_type":"td","table_text":"","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"UK Next Working Day Delivery","_id":"4c168ff","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"UK Next Working Day Delivery","_id":"c4f4262","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"\u00a34.95 - Free over \u00a3100","_id":"251f39b","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"row","_id":"c915309","table_cell_type":"td","table_text":"","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"UK Next Working Day By Noon Delivery","_id":"e34ee9c","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"Next working day by noon","_id":"7a88cc7","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"\u00a37.95","_id":"81289bc","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"row","_id":"00ae3a7","table_cell_type":"td","table_text":"","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"UK Saturday Delivery","_id":"96b5daa","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"Next Saturday","_id":"ddf99cf","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}},{"table_elem_type":"cell","table_text":"\u00a310.95","_id":"ed3a488","table_cell_type":"td","table_icon_selector":"font-awesome-icon","table_cell_icon":"","table_cell_icon_img":{"url":"","id":""},"table_cell_icon_align":"before","table_cell_icon_spacing":{"unit":"px","size":""},"table_cell_row_span":1,"table_cell_span":1,"table_cell_align":"left","table_cell_align_tablet":"","table_cell_align_mobile":"","table_cell_top_align":"left","table_cell_top_align_tablet":"","table_cell_top_align_mobile":"","table_link_switcher":"","table_link_selection":"url","table_link":{"url":"#","is_external":"","nofollow":""}}],"table_width":{"unit":"%","size":100},"table_align":"flex-start","table_odd_head_color":"#000000","table_odd_head_typo_typography":"custom","table_odd_head_typo_font_size":{"unit":"px","size":16},"table_odd_head_typo_font_weight":"600","table_odd_row_background_background":"classic","table_even_row_background_background":"classic","table_even_row_background_color":"#f5f5f5","table_odd_col_background_background":"classic","_padding":{"unit":"px","top":"35","right":"0","bottom":"0","left":"0","isLinked":false},"table_odd_head_background_popover":"yes","table_odd_head_background_background":"classic","table_odd_head_background_color":"#f5f5f5","table_even_head_background_popover":"yes","table_even_head_background_background":"classic","table_even_head_background_color":"#f5f5f5","table_head_rows_border_border":"solid","table_head_rows_border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"1","isLinked":false},"table_head_rows_border_color":"#e5e5e5","table_head_padding":{"unit":"px","top":"10","right":"30","bottom":"10","left":"30","isLinked":false},"table_odd_row_color":"#222222","table_odd_row_background_popover":"yes","table_even_row_color":"#222222","table_even_row_background_popover":"yes","table_row_border_border":"solid","table_row_border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"1","isLinked":false},"table_row_border_color":"#e5e5e5","table_odd_row_padding":{"unit":"px","top":"10","right":"30","bottom":"10","left":"30","isLinked":false},"table_border_border":"solid","table_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"table_border_color":"#e5e5e5","table_odd_row_background_color":"#ffffff"},"elements":[],"widgetType":"opal-table"},{"id":"6601a1f","elType":"widget","settings":{"editor":"<p>Please note all orders will be despatched from Perry Ellis Europe Ltd.<\/p>","_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"_padding_tablet":{"unit":"px","top":"10","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"d13296b","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"34b8752","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"2ec3319","elType":"widget","settings":{"title":"UK Standard Delivery","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"f435c5d","elType":"widget","settings":{"editor":"<p>Standard UK orders are delivered FREE<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"91a3024","elType":"widget","settings":{"editor":"<p>Deliveries are made by the DPD from Monday to Saturday, and someone will need to be in to sign for your delivery.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"572f6eb","elType":"widget","settings":{"editor":"<p>You can track the progress of your delivery using the link that\u2019s provided in your order confirmation email.<\/p>","_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"8a725b2","elType":"widget","settings":{"editor":"<p>Please note; it may take up to two working days for the first status to become available on the order tracking system.<\/p>","_padding":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"f906046","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ceea2a0","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"d49a97f","elType":"widget","settings":{"title":"UK Next Working Day Delivery","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"5d499ed","elType":"widget","settings":{"editor":""},"elements":[],"widgetType":"text-editor"},{"id":"0104b4a","elType":"widget","settings":{"editor":"<p>Our next working day delivery service costs \u00a34.95 per order.<br \/>You must place your order before 12.00pm for it to be delivered the next working day.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"bf26f56","elType":"widget","settings":{"editor":"<p>Your order will be delivered by our courier, DPD, between 9am and 5pm, Monday to Friday, and someone will need\u00a0to be in to sign for your delivery.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"3b06ea0","elType":"widget","settings":{"editor":"<p>To avoid waiting around, you will receive an email notification of the estimated one-hour delivery window that your<br \/>order will arrive. You can also track the progress of your delivery using the link that\u2019s in the \'order history\' area of your<br \/>\'my account\' . Please note that it can take up to 12 hours for your order to appear on the DPD system.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"17c4dd9","elType":"widget","settings":{"editor":"<p>Next Working Day delivery is NOT available to the Isle of Man, Scilly Isles, Channel Islands Northern Ireland, <br \/>and Scottish Highlands &amp; Islands<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"568fc03","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1440},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin":{"unit":"px","top":"60","right":0,"bottom":"120","left":0,"isLinked":false}},"elements":[{"id":"7dec5ea","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"672e5e9","elType":"widget","settings":{"title":"Need a Support?","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":62},"_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d4cb899","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"40","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"98741e5","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"0c274a8","elType":"widget","settings":{"icon":"opal-icon-chat-support","title_text":"Chat Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"0348632","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"495d228","elType":"widget","settings":{"icon":"opal-icon-tweet-support","title_text":"Tweet Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"ca345f0","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"a7b1c24","elType":"widget","settings":{"icon":"opal-icon-phone-support","title_text":"Phone Consultant","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"3d867ea","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"8be26a2","elType":"widget","settings":{"icon":"opal-icon-forum","title_text":"Visit Our Forum","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"order-tracking":[{"id":"f3720af","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"50","right":0,"bottom":"100","left":0,"isLinked":false}},"elements":[{"id":"246d230","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"3269dd9","elType":"widget","settings":{"shortcode":"[woocommerce_order_tracking]"},"elements":[],"widgetType":"shortcode"}],"isInner":false}],"isInner":false}],"privacy-policy":[{"id":"6629ce6","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"120","right":"0","bottom":"85","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"content_width":{"unit":"px","size":920}},"elements":[{"id":"162bb20","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"7e158c6","elType":"section","settings":{"gap":"no"},"elements":[{"id":"b1188d7","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"cb5f2f4","elType":"widget","settings":{"title":"Privacy Policy","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"f00193a","elType":"widget","settings":{"editor":"<p>This Privacy Policy governs the manner in which Auros collects, uses, maintains and discloses information collected from users (each, a \"User\") of the http:\/\/store.Auros.com website (\"Site\"). This privacy policy applies to the Site and all products and services offered by Auros.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"f0281bb","elType":"section","settings":{"gap":"no"},"elements":[{"id":"56b378d","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a60bdc8","elType":"widget","settings":{"title":"Personal identification information","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"9b04548","elType":"widget","settings":{"editor":"<p>We may collect personal identification information from Users in a variety of ways, including, but not limited to, when Users visit our site, place an order, subscribe to the newsletter, and in connection with other activities, services, features or resources we make available on our Site. Users may be asked for, as appropriate, name, email address, mailing address, phone number, credit card information. Users may, however, visit our Site anonymously. We will collect personal identification information from Users only if they voluntarily submit such information to us. Users can always refuse to supply personally identification information, except that it may prevent them from engaging in certain Site related activities.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"d986340","elType":"section","settings":{"gap":"no"},"elements":[{"id":"26caf80","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d0c6d8f","elType":"widget","settings":{"title":"Non-personal identification information","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"7258cda","elType":"widget","settings":{"editor":"<p>We may collect non-personal identification information about Users whenever they interact with our Site. Non-personal identification information may include the browser name, the type of computer and technical information about Users means of connection to our Site, such as the operating system and the Internet service providers utilized and other similar information.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"2d3e56a","elType":"section","settings":{"gap":"no"},"elements":[{"id":"62584ac","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"70078a9","elType":"widget","settings":{"title":"Web browser cookies","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_animation":"opal-move-up"},"elements":[],"widgetType":"heading"},{"id":"4a71849","elType":"widget","settings":{"editor":"<p>Orders cancelled after 24 hours may be subject to a minimum 25% or maximum 50% cancellation and restocking fee in addition to any shipping charges incurred.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"43381c5","elType":"widget","settings":{"editor":"<p>Orders cancelled after 24 hours may be subject to a minimum 25% or maximum 50% cancellation and restocking fee in addition to any shipping charges incurred.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"b97fe58","elType":"widget","settings":{"editor":"<p>Auros reserves the right to modify or change the terms of use of this site with or without notification.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"e21c537","elType":"section","settings":{"gap":"no"},"elements":[{"id":"a347001","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"13b353d","elType":"widget","settings":{"title":"How we use collected information","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"880df64","elType":"widget","settings":{"editor":"<p>Auros may collect and use Users personal information for the following purposes:<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"33e43e1","elType":"widget","settings":{"editor":"<p>- To improve customer service<br \/>Information you provide helps us respond to your customer service requests and support needs more efficiently.<\/p>","_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true}},"elements":[],"widgetType":"text-editor"},{"id":"71123a6","elType":"widget","settings":{"editor":"<p>- To personalize user experience<br \/>We may use information in the aggregate to understand how our Users as a group use the services and resources provided on our Site.<\/p>","_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true}},"elements":[],"widgetType":"text-editor"},{"id":"d7c9d18","elType":"widget","settings":{"editor":"<p>- To process payments<br \/>We may use the information Users provide about themselves when placing an order only to provide service to that order. We do not share this information with outside parties except to the extent necessary to provide the service.<\/p>","_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true}},"elements":[],"widgetType":"text-editor"},{"id":"0519add","elType":"widget","settings":{"editor":"<p>- To run a promotion, contest, survey or other Site feature<\/p>","_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"a00a8ee","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1440},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin":{"unit":"px","top":"60","right":0,"bottom":"120","left":0,"isLinked":false}},"elements":[{"id":"10d235c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"9a1fe85","elType":"widget","settings":{"title":"Need a Support?","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":62},"_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"561573b","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"40","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"aaf14cc","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"110979d","elType":"widget","settings":{"icon":"opal-icon-chat-support","title_text":"Chat Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"7916b58","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"2e16588","elType":"widget","settings":{"icon":"opal-icon-tweet-support","title_text":"Tweet Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"0fc590b","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"c992a9d","elType":"widget","settings":{"icon":"opal-icon-phone-support","title_text":"Phone Consultant","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"e556f64","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"8ca2794","elType":"widget","settings":{"icon":"opal-icon-forum","title_text":"Visit Our Forum","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"home-14":[{"id":"baaa5bf","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no"},"elements":[{"id":"bb2b6ed","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"85e5ba8","elType":"widget","settings":{"rev_alias":"home14"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"2792548","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_position":"middle","structure":"20","padding_mobile":{"unit":"px","top":"50","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"ff77cdb","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"165","bottom":"0","left":"165","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"5ac8b34","elType":"widget","settings":{"editor":"<p>Intro<\/p>","align":"center","typography_typography":"custom","text_color":"#777777","typography_font_family":"Sacramento","typography_font_size":{"unit":"px","size":30},"typography_line_height":{"unit":"px","size":30}},"elements":[],"widgetType":"text-editor"},{"id":"9fb84da","elType":"widget","settings":{"title":"Beautiful design<\/br>\nmade identical to the original","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"typography_line_height_mobile":{"unit":"px","size":35},"_padding":{"unit":"px","top":"25","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d35b44d","elType":"widget","settings":{"width":{"unit":"px","size":60},"align":"center","gap":{"unit":"px","size":0},"_padding":{"unit":"px","top":"34","right":"0","bottom":"34","left":"0","isLinked":false}},"elements":[],"widgetType":"divider"},{"id":"efa9718","elType":"widget","settings":{"editor":"<p>The Grand Prix is available in six colours, including four types of wood: oak, beech, walnut and rosewood. The Grand Prix is an. It would look great in the kitchen or at the dining table.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"8966be8","elType":"widget","settings":{"text":"+ Show more","align":"center","typography_typography":"custom","typography_font_weight":"700","background_color":"#000000","hover_color":"#000000","button_background_hover_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"22","right":"54","bottom":"22","left":"54","isLinked":false},"_padding":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"69655a3","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#f5f5f5","padding":{"unit":"px","top":"95","right":"0","bottom":"80","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"bafde70","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h14-img01.png","id":1610},"image_size":"full","align":"center","background_hover_transition":{"unit":"px","size":0.5},"hover_animation":"grow"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"7307925","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_position":"middle","structure":"20","padding_mobile":{"unit":"px","top":"50","right":"0","bottom":"50","left":"0","isLinked":false},"reverse_order_mobile":"reverse-mobile"},"elements":[{"id":"818f1f1","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h14_bg01.jpg","id":1614},"background_position":"center center","background_size":"cover","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"3d6abbf","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=QeFMtZR_NQA","video_align":"center","icon_font":"fa fa-play-circle","video_size":{"unit":"px","size":85},"video_color":"#ffffff","video_border_radius":{"unit":"px","top":"5","right":"5","bottom":"5","left":"5","isLinked":true},"video_padding":{"unit":"px","top":"8","right":"23","bottom":"8","left":"23","isLinked":false},"_background_background":"classic","_background_position":"center center","_background_repeat":"no-repeat","_background_size":"auto","_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"video_align_tablet":"center","video_align_mobile":"center","video_hover_color":"#f9d4bd","_padding_mobile":{"unit":"px","top":"100","right":"0","bottom":"100","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-video-popup"}],"isInner":false},{"id":"e43ad34","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"200","right":"210","bottom":"215","left":"210","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"4c0cbdd","elType":"widget","settings":{"editor":"<p>Ideas<\/p>","align":"center","typography_typography":"custom","text_color":"#777777","typography_font_family":"Sacramento","typography_font_size":{"unit":"px","size":30},"typography_line_height":{"unit":"px","size":30}},"elements":[],"widgetType":"text-editor"},{"id":"b7f800d","elType":"widget","settings":{"title":"An idea from Swan","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":55},"typography_line_height_mobile":{"unit":"px","size":35},"_padding":{"unit":"px","top":"16","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"bd52c66","elType":"widget","settings":{"width":{"unit":"px","size":60},"align":"center","gap":{"unit":"px","size":0},"_padding":{"unit":"px","top":"34","right":"0","bottom":"34","left":"0","isLinked":false}},"elements":[],"widgetType":"divider"},{"id":"b2f8869","elType":"widget","settings":{"editor":"<p>The Grand Prix is available in six colours, including four types of wood: oak, beech, walnut and rosewood. The Grand Prix is an. It would look great in the kitchen or at the dining table.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":16}},"elements":[],"widgetType":"text-editor"},{"id":"7c21941","elType":"widget","settings":{"text":"+ Show more","align":"center","typography_typography":"custom","typography_font_weight":"700","background_color":"#000000","hover_color":"#000000","button_background_hover_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"22","right":"54","bottom":"22","left":"54","isLinked":false},"_padding":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"29d1733","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","content_position":"middle","structure":"20"},"elements":[{"id":"1c43dc5","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"210","bottom":"55","left":"210","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"dac10e4","elType":"widget","settings":{"editor":"<p>Design<\/p>","align":"center","typography_typography":"custom","text_color":"#777777","typography_font_family":"Sacramento","typography_font_size":{"unit":"px","size":30},"typography_line_height":{"unit":"px","size":30}},"elements":[],"widgetType":"text-editor"},{"id":"4ba5946","elType":"widget","settings":{"title":"Light & stackable chair","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_size_mobile":{"unit":"px","size":30},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":55},"typography_line_height_mobile":{"unit":"px","size":35},"_padding":{"unit":"px","top":"16","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"ba82c96","elType":"widget","settings":{"width":{"unit":"px","size":60},"align":"center","gap":{"unit":"px","size":0},"_padding":{"unit":"px","top":"34","right":"0","bottom":"34","left":"0","isLinked":false}},"elements":[],"widgetType":"divider"},{"id":"3ed317d","elType":"widget","settings":{"editor":"<p>The Grand Prix is available in six colours, including four types of wood: oak, beech, walnut and rosewood. The Grand Prix is an. It would look great in the kitchen or at the dining table.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":16}},"elements":[],"widgetType":"text-editor"},{"id":"1f9fa41","elType":"widget","settings":{"text":"+ Show more","align":"center","typography_typography":"custom","typography_font_weight":"700","background_color":"#000000","hover_color":"#000000","button_background_hover_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"22","right":"54","bottom":"22","left":"54","isLinked":false},"_padding":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"ed07e1f","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h14_bg02.jpg","id":1628},"background_position":"center center","background_size":"cover","animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"726a916","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h14_bg02.jpg","id":1628},"image_size":"full","opacity_hover":{"unit":"px","size":1},"css_filters_hover_css_filter":"custom","css_filters_hover_brightness":{"unit":"px","size":66},"css_filters_hover_contrast":{"unit":"px","size":94},"css_filters_hover_saturate":{"unit":"px","size":97},"hide_tablet":"hidden-tablet"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"adc77a8","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"240","right":0,"bottom":"185","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"100","right":0,"bottom":"100","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"50","left":0,"isLinked":true},"animation":"opal-scale-up","animation_duration":"fast"},"elements":[{"id":"7175328","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"da09058","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h14-banner01.png","id":1706},"image_size":"full","align":"center","hover_animation":"grow","_animation":"opal-scale-up","animation_duration":"fast"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"term-conditions":[{"id":"c01b0c1","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"120","right":"0","bottom":"85","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"content_width":{"unit":"px","size":920}},"elements":[{"id":"9cb2588","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"40b4732","elType":"section","settings":{"gap":"no"},"elements":[{"id":"0ebf6e1","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"7a428d9","elType":"widget","settings":{"title":"Terms","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"c3634d6","elType":"widget","settings":{"editor":"<p>Auros reserves the right to refuse service, remove or edit content, or cancel orders at their sole discretion. You will be emailed your receipt, pick up tracking information and details regarding your order.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"8d59d38","elType":"section","settings":{"gap":"no"},"elements":[{"id":"815d4d0","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"9270fcc","elType":"widget","settings":{"title":"Shipping ","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"eaf13a1","elType":"widget","settings":{"editor":"<p>Auros will attempt to ship all merchandise within two business days of purchase unless otherwise specified. Dependent on the location of the manufacturer in which your item was purchased from, lead times can range anywhere between 3-5 business days on stock items. For items with lead times greater than 5 days, the lead times will be specified in the description. Auros will not be liable for any loss, damage, cost, or expense related to any delay in shipment or delivery.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"e43d1fd","elType":"section","settings":{"gap":"no"},"elements":[{"id":"f7dff99","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"7fab571","elType":"widget","settings":{"title":"Returns","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"53b5d26","elType":"widget","settings":{"editor":"<p>Merchandise purchased from Auros may be returned within 10 days of delivery if accompanied by original receipt and be in new condition and in the original packaging. Returns must be pre-authorized by emailing info@Auros.com. Auros will not be responsible for any costs associated with shipping the return. Actual cost of shipping the item to you will not be credited or refunded. Claims for defective or damaged items must be filed within 5 days of delivery. Please inspect your items immediately upon delivery. Claims received after 5 days of delivery will be subject to respective vendor warranty policies. All lighting and electronic products may be subject to a minimum 25% or maximum 50% restocking fee in addition to any shipping charges incurred.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"035bfbf","elType":"section","settings":{"gap":"no"},"elements":[{"id":"b02105f","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"42bbd90","elType":"widget","settings":{"title":"Order cancellation","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"3e12958","elType":"widget","settings":{"editor":"<p>Orders cancelled after 24 hours may be subject to a minimum 25% or maximum 50% cancellation and restocking fee in addition to any shipping charges incurred.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"7c57bc3","elType":"widget","settings":{"editor":"<p>Orders cancelled after 24 hours may be subject to a minimum 25% or maximum 50% cancellation and restocking fee in addition to any shipping charges incurred.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"86c235d","elType":"widget","settings":{"editor":"<p>Auros reserves the right to modify or change the terms of use of this site with or without notification.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"69ad8ef","elType":"section","settings":{"gap":"no"},"elements":[{"id":"bd8ca72","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"be67653","elType":"widget","settings":{"title":"User Warranties","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"719984d","elType":"widget","settings":{"editor":"<p>In placing an order, you warrant that you are over 18 years of age, and that you are providing accurate, true, and complete information, and that you have the authority to place the order.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"0f147b7","elType":"section","settings":{"gap":"no"},"elements":[{"id":"99e4e0c","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"eb52cbe","elType":"widget","settings":{"title":"\nDisclaimer of Warranties","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"01bbeb2","elType":"widget","settings":{"editor":"<p>You expressly understand and agree that your use of this site is at your sole risk and that this site is provided on an \u201cas is\u201d and \u201cas available\u201d basis. Auros makes no representations or warranties of any kind, express or implied, as to the operation of this site or the information, content, materials or products included on this site. Indemnification<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"37ddfa6","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1440},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin":{"unit":"px","top":"60","right":0,"bottom":"120","left":0,"isLinked":false}},"elements":[{"id":"e90bfcd","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"ae3cbce","elType":"widget","settings":{"title":"Need a Support?","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":62},"_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"e8e4795","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"40","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"49b19c1","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"b6f7d82","elType":"widget","settings":{"icon":"opal-icon-chat-support","title_text":"Chat Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"d4df785","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"75bbc62","elType":"widget","settings":{"icon":"opal-icon-tweet-support","title_text":"Tweet Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"06b3b74","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"a224c9a","elType":"widget","settings":{"icon":"opal-icon-phone-support","title_text":"Phone Consultant","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"cb230ed","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"6991820","elType":"widget","settings":{"icon":"opal-icon-forum","title_text":"Visit Our Forum","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"home-3":[{"id":"266d192","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","html_tag":"div"},"elements":[{"id":"f63160e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"419292e","elType":"widget","settings":{"rev_alias":"home3"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"77e480e","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_width":{"unit":"px","size":1710},"padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"margin":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"0e7b258","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"4ae1156","elType":"widget","settings":{"categories":"stools","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_cate1.jpg","id":1414},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"0","right":"0","bottom":"42","left":"50","isLinked":false},"button_text":"View Collection","_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"83197b8","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"19f8183","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_cate2.jpg","id":1415},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"0","right":"0","bottom":"42","left":"50","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"8e76ecd","elType":"section","settings":{"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/banner3-3.jpg","id":1686},"background_position":"center right","background_attachment":"scroll","background_repeat":"no-repeat","background_size":"contain","padding":{"unit":"px","top":"150","right":"0","bottom":"150","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"gap":"no","stretch_section":"section-stretched","structure":"20","background_position_tablet":"initial","background_xpos_tablet":{"unit":"em","size":1000},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"6a8ba3d","elType":"column","settings":{"_column_size":50,"_inline_size":38.61500000000000198951966012828052043914794921875,"padding":{"unit":"px","top":"120","right":"0","bottom":"120","left":"0","isLinked":false},"_inline_size_tablet":100,"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"0","bottom":"80","left":"0","isLinked":false}},"elements":[{"id":"642be43","elType":"widget","settings":{"editor":"<p>#Furnitures<\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_text_transform":"uppercase","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"6647fcd","elType":"widget","settings":{"title":"Shell Chair Collection","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_weight":"600","_animation":"opal-move-up","typography_font_size_tablet":{"unit":"px","size":26},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"fbf54df","elType":"widget","settings":{"editor":"<p>Since 1991, Auros Furniture has been a purveyor of quality modern furniture in Ohi. With 20 international brands and counting in 2 shops along Jalan Maarof, Bangsar.<\/p>","align":"center","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"28b68f6","elType":"widget","settings":{"text":"Shop Now","align":"center","typography_typography":"custom","typography_font_weight":"600","background_color":"#222222","button_background_hover_color":"#000000","border_radius":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"18","right":"60","bottom":"18","left":"60","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"95b1b1c","elType":"column","settings":{"_column_size":50,"_inline_size":61.38499999999999801048033987171947956085205078125},"elements":[],"isInner":false}],"isInner":false},{"id":"df945ed","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"2a69a17","elType":"column","settings":{"_column_size":100},"elements":[{"id":"a8a8185","elType":"widget","settings":{"title":"Trending Products","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"_animation":"opal-move-up","typography_font_size_tablet":{"unit":"px","size":26},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"bc8207a","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"8f18267","elType":"widget","settings":{"limit":12,"column":"4","_animation":"opal-move-up","product_gutter":{"unit":"px","size":0},"product_style":"style-2","_margin":{"unit":"px","top":"70","right":"0","bottom":"0","left":"0","isLinked":false},"_background_background":"classic","_background_color":"#f5f5f5","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"1372f13","elType":"widget","settings":{"text":"+ See All Products","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_radius":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_animation":"opal-move-up","hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"3d405f4","elType":"section","settings":{"content_width":{"unit":"px","size":1000},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","stretch_section":"section-stretched","content_position":"middle","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"40","bottom":"80","left":"40","isLinked":false}},"elements":[{"id":"c1c9366","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"748a313","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":150},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search"},"elements":[],"widgetType":"opal-search-form"}],"isInner":false}],"isInner":false}],"home-13":[{"id":"e2492c5","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","html_tag":"div","margin":{"unit":"px","top":"0","right":0,"bottom":"85","left":0,"isLinked":false}},"elements":[{"id":"457ea47","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d5a460e","elType":"widget","settings":{"rev_alias":"home13"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"d0e416d","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"10","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"1fc00a9","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"afb5cdb","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"5208abd","tab_template":"3478"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"7325056","tab_template":"3421"},{"tab_title":" Chairs ","source":"template","tab_html":"<p>Tab Content<\/p>","tab_template":"3431","_id":"7fca044"},{"tab_title":"Lighting","source":"template","tab_html":"<p>Tab Content<\/p>","tab_template":"3435","_id":"f7327ff"},{"tab_title":"Decor","source":"template","tab_html":"<p>Tab Content<\/p>","tab_template":"3441","_id":"2a8118d"}],"align_items":"center","tabs_border_radius":{"unit":"%","top":"","right":"","bottom":"","left":"","isLinked":false},"tabs_padding":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"tabs_margin":{"unit":"%","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"tab_typography_typography":"custom","tab_typography_font_size":{"unit":"px","size":15},"tab_typography_font_weight":"600","title_color":"#777777","title_active_color":"#222222","tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"3","left":"6","isLinked":false},"border_tabs_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"tab_title_margin":{"unit":"px","top":"15","right":"15","bottom":"15","left":"15","isLinked":false},"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"title_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.5)"},"title_box_shadow_box_shadow_position":"inset","title_hover_box_shadow_box_shadow_type":"yes","title_hover_box_shadow_box_shadow":{"horizontal":0,"vertical":-7,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_hover_box_shadow_box_shadow_position":"inset","title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-7,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_active_box_shadow_box_shadow_position":"inset","tab_title_margin_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"padding":{"unit":"px","top":"30","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false},{"id":"b5db114","elType":"section","settings":{"margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false},"gap":"no"},"elements":[{"id":"f173e43","elType":"column","settings":{"_column_size":100},"elements":[{"id":"95b5011","elType":"widget","settings":{"text":"+ See All Products","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"button_box_shadow_box_shadow_position":"inset","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"10","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"home-7":[{"id":"e826bb9","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","html_tag":"div"},"elements":[{"id":"9e3f8df","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"87c805e","elType":"widget","settings":{"rev_alias":"home7"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"c1494fe","elType":"section","settings":{"stretch_section":"section-stretched","padding":{"unit":"px","top":"140","right":"30","bottom":"140","left":"30","isLinked":false},"background_background":"classic","background_color":"#f5f5f5","margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","content_width":{"unit":"px","size":1710},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"ccce3ee","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"sticky_show":"active","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"325be1a","elType":"widget","settings":{"title":"Trending Products","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"typography_font_size_tablet":{"unit":"px","size":26}},"elements":[],"widgetType":"heading"},{"id":"f904f9b","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"400","typography_line_height":{"unit":"px","size":25},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"4befe64","elType":"widget","settings":{"limit":12,"column":"4","product_gutter":{"unit":"px","size":0},"product_style":"style-2"},"elements":[],"widgetType":"opal-products"},{"id":"04e13ef","elType":"widget","settings":{"text":"+ See All Products","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_margin":{"unit":"px","top":"80","right":"0","bottom":"0","left":"0","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"26c59f6","elType":"section","settings":{"stretch_section":"section-stretched","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/bg7-1.jpg","id":2190},"structure":"40","padding":{"unit":"px","top":"140","right":"30","bottom":"140","left":"30","isLinked":false},"content_width":{"unit":"px","size":1710},"margin_mobile":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding_mobile":{"unit":"px","top":"40","right":"15","bottom":"40","left":"15","isLinked":false},"animation_duration":"fast"},"elements":[{"id":"64963db","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"6a08e2e","elType":"widget","settings":{"categories":"chairs","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"},{"id":"47c24ee","elType":"widget","settings":{"categories":"lighting","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"2f9a42f","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"015","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"fba1bc9","elType":"widget","settings":{"categories":"sofas","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":150},"elements":[],"widgetType":"opal-product-categories"},{"id":"bc881ae","elType":"widget","settings":{"categories":"stools","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":350},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"df44fd6","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"15","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"a93a874","elType":"widget","settings":{"categories":"decor","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-8,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"opal-product-categories"},{"id":"6268d86","elType":"widget","settings":{"categories":"uncategorized","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":350},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"74778fc","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"15","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"648c8a1","elType":"widget","settings":{"categories":"furnitures","categories_style":"embed","text_align_h":"left","text_align_v":"stretch","show_button":"yes","button_text":"View Collection","button_icon":"fa fa-plus","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":26},"category_name_typography_font_weight":"700","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":12},"item_typography_text_transform":"uppercase","overlay_color_hover":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"700","typography_text_transform":"uppercase","button_text_color":"#000000","button_background_color":"rgba(0,0,0,0)","button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"button_box_shadow_box_shadow_position":"inset","button_text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"_border_color":"#eeeeee","categories_embed":"4by3","show_button_when_hover":"active","category_name_color_hover":"#eb7025","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":250},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"8875b3a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"140","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false},"structure":"40","animation_duration":"fast"},"elements":[{"id":"41c6ab5","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"26f70b3","elType":"widget","settings":{"title_text":"Free shipping","description_text":"on all orders over $49.00","icon":"opal-icon-ship","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"icon_size":{"unit":"px","size":60}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"de41798","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"2e421c8","elType":"widget","settings":{"title_text":"15 days returns","description_text":"moneyback guarantee","icon":"opal-icon-return","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"icon_size":{"unit":"px","size":40}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"dfd22f3","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":200},"elements":[{"id":"caf7384","elType":"widget","settings":{"title_text":"Secure checkout","description_text":"100% protected by Paypal","icon":"opal-icon-checkout","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"icon_size":{"unit":"px","size":45}},"elements":[],"widgetType":"icon-box"}],"isInner":false},{"id":"9fdf056","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"a5a37a0","elType":"widget","settings":{"title_text":"100% free warranty ","description_text":"moneyback guarantee","icon":"opal-icon-coupon","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false},"icon_size":{"unit":"px","size":45}},"elements":[],"widgetType":"icon-box"}],"isInner":false}],"isInner":false},{"id":"90ec272","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding_mobile":{"unit":"px","top":"0","right":"15","bottom":"0","left":"15","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"a6de4ad","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e868946","elType":"widget","settings":{"username":"heygents","number":5,"per_row":"5","size":"large","show_username":"yes","username_align":"center","username_typography_typography":"custom","username_typography_font_size":{"unit":"px","size":15},"username_typography_font_weight":"400","username_typography_line_height":{"unit":"px","size":24},"username_typography_letter_spacing":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625},"username_text_color":"#222222","image_spacing":{"unit":"px","size":0},"per_row_mobile":"4","target":"_self","style":"insite","show_like":"yes"},"elements":[],"widgetType":"opal-instagram"}],"isInner":false}],"isInner":false},{"id":"0682854","elType":"section","settings":{"content_width":{"unit":"px","size":1000},"margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"gap":"no","stretch_section":"section-stretched","content_position":"middle","padding":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false}},"elements":[{"id":"f5f2f24","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"b843685","elType":"widget","settings":{"placeholder":"Enter your keywords...","button_type":"text_icon","button_text":"Search","input_typography_typography":"custom","input_typography_font_size":{"unit":"px","size":14},"input_typography_letter_spacing":{"unit":"px","size":0.5},"input_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"input_background_color_background":"classic","input_background_color_color":"#ffffff","button_width":{"unit":"px","size":210},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_typography_text_transform":"uppercase","button_text_color":"#222222","button_background_color":"#ffffff","button_text_color_hover":"#eb7025","border_button_search_border":"solid","border_button_search_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"1","isLinked":false},"border_button_search_color":"#eeeeee","button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_search_padding":{"unit":"px","top":"9","right":"40","bottom":"9","left":"40","isLinked":false},"icon_size":{"unit":"px","size":18},"icon_spacing":{"unit":"px","size":10},"_padding":{"unit":"px","top":"15","right":"0","bottom":"15","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"input_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"button_width_mobile":{"unit":"px","size":150},"button_typography_font_size_mobile":{"unit":"px","size":0},"button_search_padding_mobile":{"unit":"px","top":"6","right":"15","bottom":"6","left":"15","isLinked":false},"icon_spacing_mobile":{"unit":"px","size":0},"button_text_w_icon":"Search"},"elements":[],"widgetType":"opal-search-form"}],"isInner":false}],"isInner":false}],"header-02":[{"id":"efcf86a","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1600},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"background_background":"classic","padding_tablet":{"unit":"px","top":"30","right":"40","bottom":"30","left":"40","isLinked":false}},"elements":[{"id":"6a013ef","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":50},"elements":[{"id":"b68c028","elType":"widget","settings":{"align":"left","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"9a97115","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":50,"_inline_size_mobile":50},"elements":[{"id":"99b34df","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"destop","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":40},"menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":40},"color_menu_item":"#222222","color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":15},"menu_space_between":{"unit":"px","size":37},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":10},"padding_vertical_dropdown_item":{"unit":"px","size":5},"dropdown_top_distance":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"#f9f9f9","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":10},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":10},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"menu","toggle_spacing":{"unit":"px","size":15},"title_tongle_typography_typography":"custom","title_tongle_typography_font_size":{"unit":"px","size":12},"title_tongle_typography_font_weight":"600","title_tongle_color":"#222222","title_tongle_color_hover":"#eb7025","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"popup","menu_typography_font_size_mobile":{"unit":"px","size":40},"menu_typography_letter_spacing":{"unit":"px","size":1},"dropdown_typography_typography":"custom","dropdown_typography_font_size":{"unit":"px","size":14},"dropdown_typography_font_size_mobile":{"unit":"px","size":20}},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"21d953c","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":25,"_inline_size_mobile":100},"elements":[{"id":"5fc8fc4","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"home-9":[{"id":"cb7b8fa","elType":"section","settings":{"gap":"no","structure":"20","stretch_section":"section-stretched","padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"6fd3b51","elType":"column","settings":{"_column_size":50,"_inline_size":60.66199999999999903366187936626374721527099609375,"space_between_widgets":0,"background_background":"classic","background_color":"#f3f3f3","margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"128e102","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h9_ct01-1.png","id":1512},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":25},"category_name_typography_font_weight":"700","item_typography_typography":"custom","text_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"50","isLinked":false},"button_text":"View Collection","_animation":"opal-move-right","category_name_color_hover":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"03c6da4","elType":"column","settings":{"_column_size":50,"_inline_size":39.33800000000000096633812063373625278472900390625,"space_between_widgets":0,"padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[{"id":"e8624a5","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"0","right":0,"bottom":"30","left":0,"isLinked":false}},"elements":[{"id":"ee0ed39","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_color":"#d8eef4"},"elements":[{"id":"f1c88a2","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h9_ct02.jpg","id":1550},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":25},"category_name_typography_font_weight":"700","text_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"50","isLinked":false},"button_text":"View Collection","_animation":"opal-move-left","category_name_color_hover":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true},{"id":"037313c","elType":"section","settings":{"gap":"no","background_background":"classic"},"elements":[{"id":"1bfd3ea","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"background_background":"classic"},"elements":[{"id":"bd42dfa","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h9_ct03.jpg","id":1555},"text_align_h":"left","text_align_v":"flex-start","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":25},"category_name_typography_font_weight":"700","text_padding":{"unit":"px","top":"50","right":"0","bottom":"0","left":"50","isLinked":false},"button_text":"View Collection","_animation":"opal-move-left","category_name_color_hover":"#eb7025","animation_duration":"fast"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"cc8fa83","elType":"section","settings":{"gap":"no","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"138","right":"0","bottom":"140","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"100","right":"40","bottom":"100","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"ab73365","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e68cb21","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"bbd604f","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","_padding":{"unit":"px","top":"15","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"de3d292","elType":"widget","settings":{"limit":8,"column":"4","_padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"b9a3324","elType":"widget","settings":{"text":"+ See All Products","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":25},"button_text_color":"#000000","background_color":"rgba(249,212,189,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(241,192,162,0.66)"},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","_animation":"opal-scale-up","button_background_hover_color":"#f1c0a2","button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"6e94964","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":650},"gap":"no","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h2_bg_1.jpg","id":1835},"background_position":"center center","background_attachment":"fixed","padding":{"unit":"px","top":"200","right":"20","bottom":"200","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false}},"elements":[{"id":"0e2a5b3","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"bba2814","elType":"widget","settings":{"title":"Newsletter","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"837ee36","elType":"widget","settings":{"editor":"<p>It only takes a second to be the first to find out about our latest news and promotions...<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"0c9a3b7","elType":"widget","settings":{"hide_icon":"none","width_input":{"unit":"%","size":70},"width_input_mobile":{"unit":"%","size":100},"width_button":{"unit":"%","size":30},"width_button_mobile":{"unit":"%","size":100},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_bacground":"#222222","button_bacground_hover":"#c36b5a","button_color_hover":"#ffffff","button_border_hover":"#c36b5a","border_button_border":"solid","border_button_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_button_color":"#222222","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":false}],"isInner":false}],"home-4":[{"id":"4c59165","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","layout":"full_width"},"elements":[{"id":"3cd097a","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"1b6262a","elType":"widget","settings":{"rev_alias":"home4"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"cc38695","elType":"section","settings":{"gap":"no","structure":"30","content_position":"middle","padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"margin":{"unit":"px","top":"130","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"70c7ba7","elType":"column","settings":{"_column_size":33,"_inline_size":45.71399999999999863575794734060764312744140625,"space_between_widgets":0,"_inline_size_mobile":100,"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"74a38a4","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h4_ct01.jpg","id":1379},"text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":22},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"item_color":"#777777","button_text":"View Collection","category_name_color_hover":"#eb7025","category_name_color":"#222222","text_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-product-categories"},{"id":"8b75135","elType":"widget","settings":{"text":"+ Show All","align":"center","typography_typography":"custom","typography_font_weight":"600","button_text_color":"#000000","background_color":"#ffffff","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"text_padding":{"unit":"px","top":"16","right":"44","bottom":"16","left":"44","isLinked":false},"button_hover_border_color":"#f9d4bd","button_background_hover_color":"#f1c0a2"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"cfa7d97","elType":"column","settings":{"_column_size":33,"_inline_size":8.5709999999999997299937604111619293689727783203125,"space_between_widgets":0},"elements":[],"isInner":false},{"id":"79bb830","elType":"column","settings":{"_column_size":33,"_inline_size":45.71399999999999863575794734060764312744140625,"space_between_widgets":0,"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"animation":"opal-move-left","animation_duration":"fast"},"elements":[{"id":"270dcaf","elType":"widget","settings":{"categories":"stools","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h4_ct02.jpg","id":1380},"text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":22},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"item_color":"#777777","button_text":"View Collection","category_name_color_hover":"#eb7025","text_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-product-categories"},{"id":"024592b","elType":"widget","settings":{"text":"+ Show All","align":"center","typography_typography":"custom","typography_font_weight":"600","button_text_color":"#000000","background_color":"#ffffff","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"text_padding":{"unit":"px","top":"16","right":"44","bottom":"16","left":"44","isLinked":false},"button_hover_border_color":"#f9d4bd","button_background_hover_color":"#f1c0a2"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"b2d5891","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"0","right":"0","bottom":"120","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"14b3c2d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"709c3a9","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h4_ct03.jpg","id":1409},"text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":22},"category_name_typography_font_weight":"600","item_typography_typography":"custom","item_typography_font_size":{"unit":"px","size":14},"item_color":"#777777","button_text":"View Collection","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"},{"id":"354952d","elType":"widget","settings":{"text":"+ Show All","align":"center","typography_typography":"custom","typography_font_weight":"600","button_text_color":"#000000","background_color":"#ffffff","border_border":"solid","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"text_padding":{"unit":"px","top":"16","right":"44","bottom":"16","left":"44","isLinked":false},"button_hover_border_color":"#f9d4bd","button_background_hover_color":"#f1c0a2"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"3b0d258","elType":"section","settings":{"gap":"no","border_border":"solid","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"110","right":"0","bottom":"140","left":"0","isLinked":false}},"elements":[{"id":"32adc8b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f71e208","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"88d8b7e","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","_padding":{"unit":"px","top":"15","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":200},"elements":[],"widgetType":"text-editor"},{"id":"35f79f8","elType":"widget","settings":{"limit":4,"column":"4","_padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast","_animation_delay":400},"elements":[],"widgetType":"opal-products"},{"id":"640bc62","elType":"widget","settings":{"text":"+ See All Products","align":"center","typography_typography":"custom","typography_line_height":{"unit":"px","size":25},"button_text_color":"#000000","background_color":"rgba(249,212,189,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(241,192,162,0.67)"},"text_padding":{"unit":"px","top":"0","right":"10","bottom":"0","left":"10","isLinked":false},"typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","_z_index":1,"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"on","nofollow":""},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast","_animation_delay":400},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"home-5":[{"id":"53192b3","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"100","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"f4f3b65","elType":"column","settings":{"_column_size":50,"_inline_size":38.5,"background_background":"classic","background_color":"#ffd8d4","_inline_size_tablet":100,"background_overlay_background":"classic","background_overlay_hover_background":"classic","background_overlay_hover_transition":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625}},"elements":[{"id":"992e7cb","elType":"section","settings":{"background_background":"classic","background_color":"#f3f3f3","text_align":"center","padding":{"unit":"px","top":"200","right":"15","bottom":"110","left":"15","isLinked":false},"background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(235,112,37,0.07)","background_overlay_hover_transition":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625}},"elements":[{"id":"9077691","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"f2236b0","elType":"widget","settings":{"title":"Zuiver","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":80},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":8},"typography_font_size_mobile":{"unit":"px","size":60},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_animation":"fadeInDown","_animation_delay":100,"animation_duration":"slow","typography_font_weight":"700"},"elements":[],"widgetType":"heading"},{"id":"e7a3815","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_text_brush.png","id":3136},"_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_animation":"zoomIn","_animation_delay":200,"animation_duration":"slow"},"elements":[],"widgetType":"image"},{"id":"254be28","elType":"widget","settings":{"text":"+ More Options","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"bold","typography_text_transform":"uppercase","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":65,"vertical":0,"blur":0,"spread":0,"color":"#eb7025"},"button_box_shadow_box_shadow_position":"inset","text_padding":{"unit":"px","top":"22","right":"0","bottom":"22","left":"35","isLinked":false},"_animation":"fadeInUp","_animation_delay":100,"animation_duration":"slow"},"elements":[],"widgetType":"button"}],"isInner":true}],"isInner":true},{"id":"6ee1abd","elType":"section","settings":{"gap":"no","content_position":"middle","background_background":"classic","background_color":"#ffd8d4","padding":{"unit":"px","top":"20","right":"15","bottom":"20","left":"15","isLinked":false},"background_overlay_hover_background":"classic","background_overlay_hover_color":"rgba(235,112,37,0.3)","background_overlay_hover_transition":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625}},"elements":[{"id":"abfd955","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0,"content_position":"bottom","padding":{"unit":"px","top":"0","right":"0","bottom":"22.5","left":"0","isLinked":false}},"elements":[{"id":"5f343e1","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_layout1_01.png","id":1371},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"e59eb67"}],"img_layers_margin":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"img_layers_container_margin":{"unit":"px","top":"","right":"","bottom":"","left":"","isLinked":false},"_animation":"headShake","_animation_delay":100},"elements":[],"widgetType":"opal-images-layers"},{"id":"80b1a6f","elType":"widget","settings":{"title":"White","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":30},"typography_font_weight":"bold","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1.8000000000000000444089209850062616169452667236328125},"show_dot_before":"yes","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":70},"dot_before_height":{"unit":"px","size":15},"dot_before_border_margin":{"unit":"px","top":"0","right":"-20","bottom":"5","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"link":{"url":"#","is_external":"","nofollow":""},"align":"right","_margin":{"unit":"px","top":"-55","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"fadeInRight","_animation_delay":200},"elements":[],"widgetType":"heading"}],"isInner":true}],"isInner":true}],"isInner":false},{"id":"2d272b1","elType":"column","settings":{"_column_size":50,"_inline_size":61.5,"space_between_widgets":0,"background_background":"classic","background_color":"#bde1dd","padding":{"unit":"px","top":"125","right":"15","bottom":"40","left":"15","isLinked":false},"background_hover_background":"classic","background_overlay_hover_background":"classic","background_overlay_hover_transition":{"unit":"px","size":0.40000000000000002220446049250313080847263336181640625},"background_overlay_hover_color":"rgba(235,112,37,0.3)","_inline_size_tablet":100},"elements":[{"id":"35fa8e5","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_layout1_02.png","id":1372},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":60,"img_layers_animation_switcher":"","img_layers_animation":"","img_layers_animation_duration":"","img_layers_animation_delay":"","img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-10,"img_layers_align":"center","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"bf44fb7"}],"_background_hover_background":"classic","_background_background":"classic","_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"_padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"headShake","_animation_delay":100},"elements":[],"widgetType":"opal-images-layers"},{"id":"05ee6f0","elType":"widget","settings":{"title":"Black","align":"right","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":30},"typography_font_weight":"bold","typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":1.8000000000000000444089209850062616169452667236328125},"show_dot_before":"yes","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":70},"dot_before_height":{"unit":"px","size":15},"dot_before_border_margin":{"unit":"px","top":"0","right":"-20","bottom":"5","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"60","bottom":"0","left":"0","isLinked":false},"show_dot_after":"yes","link":{"url":"#","is_external":"","nofollow":""},"_margin_mobile":{"unit":"%","top":"","right":"","bottom":"","left":"","isLinked":true},"_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"fadeInRight","_animation_delay":100},"elements":[],"widgetType":"heading"}],"isInner":false}],"isInner":false},{"id":"c87aa8f","elType":"section","settings":{"structure":"30","gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false}},"elements":[{"id":"0ee69fe","elType":"column","settings":{"_column_size":33,"_inline_size":null,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2019\/02\/h5_bg_1adsfds.jpg","id":4374},"margin":{"unit":"px","top":"0","right":"27","bottom":"0","left":"0","isLinked":false},"background_position":"center right","background_repeat":"no-repeat","background_size":"cover","_inline_size_tablet":100,"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"2e493ff","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_tablet":{"unit":"px","top":"120","right":"0","bottom":"120","left":"45","isLinked":false},"reverse_order_tablet":"reverse-tablet","margin_tablet":{"unit":"px","top":"0","right":0,"bottom":"0","left":0,"isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"0","bottom":"100","left":"10","isLinked":false}},"elements":[{"id":"45c2e44","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","_inline_size_tablet":100,"space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"af9a683","elType":"widget","settings":{"editor":"<p>#Living<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"044af2b","elType":"widget","settings":{"title":"The Funel\n& Sweepers","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d6af00e","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"09f7c42","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","_inline_size_tablet":100},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"45c444d","elType":"column","settings":{"_column_size":33,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_bgr_2.jpg","id":1279},"margin":{"unit":"px","top":"0","right":"13","bottom":"0","left":"13","isLinked":false},"space_between_widgets":0,"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","_inline_size_tablet":50,"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_tablet":{"unit":"px","top":"0","right":"10","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"animation":"opal-move-up","animation_delay":150,"animation_duration":"fast"},"elements":[{"id":"2d3f722","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_tablet":{"unit":"px","top":"100","right":"0","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"0","bottom":"100","left":"10","isLinked":false}},"elements":[{"id":"dcc3786","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"5491812","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"0cd3ffb","elType":"widget","settings":{"title":"White\nCeramics","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"9581364","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"3801f92","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false},{"id":"856c5d6","elType":"column","settings":{"_column_size":33,"_inline_size":null,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/niches_05_bgr_3.jpg","id":1280},"background_position":"center left","background_repeat":"no-repeat","background_size":"cover","margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"27","isLinked":false},"_inline_size_tablet":50,"box_shadow_hover_box_shadow_type":"yes","box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"10","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_delay":300,"animation_duration":"fast"},"elements":[{"id":"5173d3a","elType":"section","settings":{"gap":"no","background_background":"classic","background_position":"center right","background_repeat":"no-repeat","structure":"20","background_size":"cover","padding":{"unit":"px","top":"100","right":"0","bottom":"100","left":"45","isLinked":false},"padding_mobile":{"unit":"px","top":"100","right":"0","bottom":"100","left":"10","isLinked":false}},"elements":[{"id":"6246025","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left","space_between_widgets":0,"_inline_size_mobile":50},"elements":[{"id":"ab91d55","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"normal","dot_before_background_color":"#eb7025","dot_before_width":{"unit":"px","size":90},"dot_before_height":{"unit":"px","size":9},"dot_before_border_margin":{"unit":"px","top":"0","right":"-67","bottom":"-13","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"typography_text_transform":"uppercase"},"elements":[],"widgetType":"text-editor"},{"id":"237a64a","elType":"widget","settings":{"title":"Vega Table \nLamp\n","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_font_weight":"600","typography_line_height":{"unit":"em","size":1.37999999999999989341858963598497211933135986328125},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"cba47b5","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_padding":{"unit":"px","top":"0","right":"5","bottom":"5","left":"5","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.4)"},"button_box_shadow_box_shadow_position":"inset","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":true},{"id":"0acf963","elType":"column","settings":{"_column_size":50,"_inline_size":null,"text_align":"left"},"elements":[],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"fdd5e28","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"20","left":0,"isLinked":false}},"elements":[{"id":"c1ec0fc","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"c991eaf","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","_margin":{"unit":"px","top":"0","right":"0","bottom":"015","left":"0","isLinked":false},"_animation":"fadeInUp","_animation_delay":200},"elements":[],"widgetType":"heading"},{"id":"61a7d2b","elType":"widget","settings":{"align":"center","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"normal","_margin":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"editor":"<p>Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_animation":"fadeInUp","_animation_delay":200},"elements":[],"widgetType":"text-editor"},{"id":"6fe9f4e","elType":"widget","settings":{"limit":8,"column":"4","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"}],"isInner":false}],"isInner":false},{"id":"eac29fc","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false}},"elements":[{"id":"a1674be","elType":"column","settings":{"_column_size":100},"elements":[{"id":"619cc19","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop","is_external":"on","nofollow":""},"align":"center","_animation":"fadeInUp","typography_letter_spacing":{"unit":"px","size":0.299999999999999988897769753748434595763683319091796875},"_background_background":"classic","animation_duration":"fast","hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"e136739","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"140","left":0,"isLinked":false}},"elements":[{"id":"57be542","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"60c7b05","elType":"widget","settings":{"rev_alias":"home_5","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"6cbe43c","elType":"section","settings":{"gap":"no","structure":"20","margin":{"unit":"px","top":"0","right":0,"bottom":"65","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"566dfbd","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"3a85c84","elType":"widget","settings":{"title":"Our Blogs","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":42},"typography_font_weight":"600","_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"ac6d9ec","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection<\/p>","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"typography_font_weight":"normal"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"b13d847","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"3f63db2","elType":"widget","settings":{"space":{"unit":"px","size":25}},"elements":[],"widgetType":"spacer"},{"id":"ec58bd0","elType":"widget","settings":{"text":"+ Read All Blogs","align":"right","typography_typography":"custom","typography_font_size":{"unit":"px","size":13},"typography_font_weight":"600","typography_text_transform":"uppercase","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-5,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"button_box_shadow_box_shadow_position":"inset","text_padding":{"unit":"px","top":"0","right":"3","bottom":"0","left":"3","isLinked":false},"typography_letter_spacing":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"hover_animation":"grow"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"277acc8","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"0","right":0,"bottom":"40","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"de1bccb","elType":"column","settings":{"_column_size":100},"elements":[{"id":"f07d92c","elType":"widget","settings":{"posts_per_page":3,"style":"post-style-2","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"2bc3fde","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"stretch_section":"section-stretched","content_position":"middle","layout":"full_width","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false}},"elements":[{"id":"42c007c","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic"},"elements":[{"id":"a9ac2de","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"home-2":[{"id":"76d0e68","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","html_tag":"div"},"elements":[{"id":"d8f48c2","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"92a6512","elType":"widget","settings":{"rev_alias":"home2"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"05a52ad","elType":"section","settings":{"gap":"no","structure":"20","margin":{"unit":"px","top":"100","right":0,"bottom":"100","left":0,"isLinked":true},"margin_mobile":{"unit":"px","top":"60","right":0,"bottom":"60","left":0,"isLinked":true}},"elements":[{"id":"51f2431","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/img_1.jpg","id":1250},"background_position":"center left","background_repeat":"no-repeat","padding":{"unit":"px","top":"100","right":"55","bottom":"100","left":"55","isLinked":false},"_inline_size":null,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"background_overlay_background":"classic","background_overlay_opacity":{"unit":"px","size":1},"overlay_blend_mode":"overlay","background_overlay_hover_background":"classic","background_overlay_hover_opacity":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"26e1094","elType":"widget","settings":{"editor":"<p>#Living<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":2},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"ffd9008","elType":"widget","settings":{"title":"The Sweepers<br>\nand Funel","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":31},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":39},"typography_letter_spacing":{"unit":"px","size":-1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"7a67d09","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"_animation_delay":400,"hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"175dc59","elType":"column","settings":{"_column_size":50,"space_between_widgets":0,"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/img_2.jpg","id":1333},"background_position":"center left","background_repeat":"no-repeat","padding":{"unit":"px","top":"100","right":"55","bottom":"100","left":"55","isLinked":false},"_inline_size":null,"margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"box_shadow_hover_box_shadow":{"horizontal":0,"vertical":0,"blur":40,"spread":15,"color":"rgba(0,0,0,0.1)"},"padding_mobile":{"unit":"px","top":"30","right":"30","bottom":"30","left":"30","isLinked":true},"background_overlay_hover_background":"classic","background_overlay_hover_opacity":{"unit":"px","size":0.6999999999999999555910790149937383830547332763671875},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"976eb88","elType":"widget","settings":{"editor":"<p>#Lighting<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_line_height":{"unit":"px","size":18},"typography_letter_spacing":{"unit":"px","size":2},"_margin":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"99d2da2","elType":"widget","settings":{"title":"Vega Table <br>\nLamp\n","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":31},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":39},"typography_letter_spacing":{"unit":"px","size":-1},"_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation_delay":200,"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"f91507f","elType":"widget","settings":{"text":"Shop Now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"_animation_delay":400,"hover_animation":"grow","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"8cbbc5d","elType":"section","settings":{"gap":"no"},"elements":[{"id":"1f18598","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"d111d4c","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"35c130f","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"fcebade","elType":"widget","settings":{"_animation_delay":100,"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"15c1cd8","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"50","right":"0","bottom":"100","left":"-5","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","_background_background":"classic","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"a59f470","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#c36b5a","margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"padding":{"unit":"px","top":"140","right":"20","bottom":"350","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[{"id":"d9ba33a","elType":"column","settings":{"_column_size":100,"content_position":"center","space_between_widgets":0},"elements":[{"id":"2a53f40","elType":"widget","settings":{"title":"Calio Bird Chair","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"a1f11aa","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension.<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"text_color":"#ffffff","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"3827a56","elType":"widget","settings":{"text":"Shop now","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#ffffff","background_color":"#222222","text_padding":{"unit":"px","top":"15","right":"60","bottom":"15","left":"60","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":20,"spread":10,"color":"rgba(249,212,189,0.27)"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop\/","is_external":"","nofollow":""},"align":"center","typography_line_height":{"unit":"px","size":30},"hover_color":"#eb7025","button_background_hover_color":"#ffffff","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"e721669","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"-340","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"60","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"6bc3fc2","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"00c1c99","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/11\/Layer-1.png","id":4273},"image_size":"full","align":"right","hover_animation":"grow","spin":"elementor-image-spin","_margin":{"unit":"px","top":"0","right":"200","bottom":"-70","left":"0","isLinked":false}},"elements":[],"widgetType":"image"},{"id":"f9dcc6a","elType":"widget","settings":{"img_layers_images_repeater":[{"layers_select":"image","img_layers_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/11\/img_31.png","id":4296},"img_layers_alt":"","thumbnail_size":"full","thumbnail_custom_dimension":{"width":"","height":""},"text_layers":"Lorem ipsum dolor sit amet","text_typo_typography":"","text_typo_font_family":"","text_typo_font_size":{"unit":"px","size":""},"text_typo_font_size_tablet":{"unit":"px","size":""},"text_typo_font_size_mobile":{"unit":"px","size":""},"text_typo_font_weight":"","text_typo_text_transform":"","text_typo_font_style":"","text_typo_text_decoration":"","text_typo_line_height":{"unit":"em","size":""},"text_typo_line_height_tablet":{"unit":"em","size":""},"text_typo_line_height_mobile":{"unit":"em","size":""},"text_typo_letter_spacing":{"unit":"px","size":""},"text_typo_letter_spacing_tablet":{"unit":"px","size":""},"text_typo_letter_spacing_mobile":{"unit":"px","size":""},"text_color":"#00000","img_layers_position":"relative","img_layers_hor_position":{"unit":"%","size":50},"img_layers_hor_position_tablet":{"unit":"px","size":""},"img_layers_hor_position_mobile":{"unit":"px","size":""},"img_layers_ver_position":{"unit":"%","size":50},"img_layers_ver_position_tablet":{"unit":"px","size":""},"img_layers_ver_position_mobile":{"unit":"px","size":""},"img_layers_link_switcher":"","img_layers_link_selection":"url","img_layers_link":{"url":"#","is_external":"","nofollow":""},"img_layers_rotate":"","img_layers_rotatex":"","img_layers_animation_switcher":"yes","img_layers_animation":"fadeInUp","img_layers_animation_duration":"","img_layers_animation_delay":400,"img_layers_mouse":"yes","img_layers_mouse_type":"parallax","img_layers_rate":-20,"img_layers_align":"left","img_layers_align_tablet":"","img_layers_align_mobile":"","img_layers_zindex":1,"img_layers_class":"","_id":"92beedb"}],"_animation_delay":400},"elements":[],"widgetType":"opal-images-layers"}],"isInner":false}],"isInner":false},{"id":"6c419c4","elType":"section","settings":{"gap":"no"},"elements":[{"id":"ef2331f","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"086272f","elType":"widget","settings":{"title":"Our Blogs","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"c789769","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"80","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"530b3f3","elType":"widget","settings":{"posts_per_page":2,"categories":["healthy"],"column":"2","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","_animation_delay":100,"style":"post-style-3","column_tablet":"1","column_mobile":"1","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-post-grid"},{"id":"20809a6","elType":"widget","settings":{"text":"+ Read All Blogs","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","_margin":{"unit":"px","top":"50","right":"0","bottom":"100","left":"0","isLinked":false},"link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/blog-list\/","is_external":"","nofollow":""},"align":"center","hover_color":"#eb7025","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false},{"id":"0238b13","elType":"section","settings":{"content_width":{"unit":"px","size":1170},"gap":"no","structure":"50","border_border":"solid","border_width":{"unit":"px","top":"1","right":"0","bottom":"0","left":"0","isLinked":false},"border_color":"#eeeeee"},"elements":[{"id":"0281934","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"a437d2c","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-1.png","id":1821},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"70","right":"20","bottom":"70","left":"20","isLinked":false},"_animation_delay":100,"_margin_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"498fb36","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":100},"elements":[{"id":"1470bbc","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-2.png","id":1822},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"70","right":"20","bottom":"70","left":"20","isLinked":false},"_animation_delay":200,"_margin_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"d338080","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"7b15ce1","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-3.png","id":1823},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"70","right":"20","bottom":"70","left":"20","isLinked":false},"_animation_delay":300,"_margin_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"93f7832","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":300},"elements":[{"id":"28dad04","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-4.png","id":1824},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"70","right":"20","bottom":"70","left":"20","isLinked":false},"_animation_delay":400,"_margin_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"790b5c3","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast","animation_delay":400},"elements":[{"id":"19d2c86","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-5.png","id":1825},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"70","right":"20","bottom":"70","left":"20","isLinked":false},"_animation_delay":500,"_margin_mobile":{"unit":"px","top":"20","right":"20","bottom":"60","left":"20","isLinked":false}},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"61d005b","elType":"section","settings":{"stretch_section":"section-stretched","content_width":{"unit":"px","size":550},"gap":"no","background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/h2_bg_1.jpg","id":1835},"background_position":"center center","background_attachment":"fixed","padding":{"unit":"px","top":"200","right":"20","bottom":"200","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"10","bottom":"60","left":"10","isLinked":false},"background_repeat":"no-repeat"},"elements":[{"id":"0969294","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"607824d","elType":"widget","settings":{"title":"Newsletter","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"21511f2","elType":"widget","settings":{"editor":"<p>It only takes a second to be the first to find out about our latest news and promotions...<\/p>","align":"center","_margin":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"text-editor"},{"id":"2614eea","elType":"widget","settings":{"hide_icon":"none","width_input":{"unit":"%","size":70},"width_input_mobile":{"unit":"%","size":100},"width_button":{"unit":"%","size":30},"width_button_mobile":{"unit":"%","size":100},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"button_bacground":"#222222","button_bacground_hover":"#eb7025","button_color_hover":"#ffffff","button_border_hover":"#eb7025","border_button_border":"solid","border_button_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"border_button_color":"#222222","align_input_mobile":"center","button_bacground_focus":"#eb7025","button_color_focus":"#ffffff","button_border_focus":"#eb7025","input_bacground":"#ffffff","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-mailchmip"}],"isInner":false}],"isInner":false}],"support-page":[{"id":"35b35de","elType":"section","settings":{"gap":"no","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#e9e9e9","padding":{"unit":"px","top":"150","right":"40","bottom":"235","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_tablet":{"unit":"px","top":"140","right":"030","bottom":"140","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false},"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/bg_support-page.jpg","id":3026},"background_attachment":"fixed","background_size":"cover","content_width":{"unit":"px","size":780}},"elements":[{"id":"fc4917e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"607aab4","elType":"widget","settings":{"title":"How can we help?","align":"center","title_color":"#ffffff","typography_typography":"custom","typography_font_size":{"unit":"px","size":48}},"elements":[],"widgetType":"heading"},{"id":"f01c0fd","elType":"widget","settings":{"placeholder":"Search for answers or find help for your product","button_type":"text_icon","button_text":"Search","input_background_color_background":"classic","input_background_color_color":"#ffffff","input_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"input_border_color":"#959595","button_text_color":"#ffffff","button_background_color_background":"classic","button_background_color_color":"#eb7025","button_background_color_hover_background":"classic","button_background_color_hover_color":"#000000","size":{"unit":"px","size":60},"button_typography_typography":"custom","_padding":{"unit":"px","top":"47","right":"0","bottom":"30","left":"0","isLinked":false},"input_padding":{"unit":"px","top":"20","right":"20","bottom":"21","left":"20","isLinked":false},"button_width":{"unit":"px","size":180},"button_typography_font_size":{"unit":"px","size":16},"button_typography_font_weight":"600","button_typography_line_height":{"unit":"px","size":40},"button_search_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"icon_spacing":{"unit":"px","size":7},"button_search_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"button_width_mobile":{"unit":"px","size":120},"button_typography_font_size_mobile":{"unit":"px","size":0},"icon_spacing_mobile":{"unit":"px","size":0}},"elements":[],"widgetType":"opal-search-form"},{"id":"ee7ffa4","elType":"widget","settings":{"editor":"<p>or Browser Our <span style=\"color: #eb7025;\"><a style=\"color: #eb7025;\" href=\"https:\/\/demo2wpopal.b-cdn.net\/auros\/privacy-policy\/\" target=\"_blank\" rel=\"noopener\">Frequence Asked<\/a><\/span><\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":14}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"f1240cc","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","gap":"no","background_background":"classic","margin":{"unit":"px","top":"-80","right":0,"bottom":"0","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false}},"elements":[{"id":"b82e2c9","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"f35d0f7","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"30"},"elements":[{"id":"3a5a38b","elType":"column","settings":{"_column_size":33,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"40","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"60b3d44","elType":"widget","settings":{"icon":"opal-icon-knowledge-base","title_text":"Knowledge Base","description_text":"You\u2019ll design industry-leading website templates and produce beautiful. content con","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_bottom_space":{"unit":"px","size":20},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"title_typography_text_transform":"uppercase","description_color":"#222222","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"70","right":"40","bottom":"70","left":"40","isLinked":false},"_background_background":"classic","_background_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-knowledge-base","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"5f4fe11","elType":"column","settings":{"_column_size":33,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"40","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[{"id":"1972e0b","elType":"widget","settings":{"icon":"opal-icon-fAQs","title_text":"FAQS","description_text":"You\u2019ll design industry-leading website templates and produce beautiful. ","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_bottom_space":{"unit":"px","size":20},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"title_typography_text_transform":"uppercase","description_color":"#222222","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"70","right":"40","bottom":"70","left":"40","isLinked":false},"_background_background":"classic","_background_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-fAQs","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"d1d1381","elType":"column","settings":{"_column_size":33,"_inline_size":null,"_inline_size_tablet":100,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"40","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"0b54bbc","elType":"widget","settings":{"icon":"opal-icon-community","title_text":"Community","description_text":"You\u2019ll design industry-leading website templates and produce beautiful. ","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_bottom_space":{"unit":"px","size":20},"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"title_typography_text_transform":"uppercase","description_color":"#222222","description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":15},"_padding":{"unit":"px","top":"70","right":"40","bottom":"70","left":"40","isLinked":false},"_background_background":"classic","_background_color":"#ffffff","_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-community","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"d2b729a","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","background_background":"classic","background_color":"#f5f5f5","padding":{"unit":"px","top":"120","right":"20","bottom":"140","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"80","right":"40","bottom":"80","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"20","bottom":"60","left":"20","isLinked":false},"margin":{"unit":"px","top":"120","right":0,"bottom":"0","left":0,"isLinked":false},"content_width":{"unit":"px","size":920}},"elements":[{"id":"07d5178","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"3ef0cc5","elType":"widget","settings":{"title":"Featured topics","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_line_height":{"unit":"px","size":""},"dot_before_background_color":"#e43636","dot_before_width":{"unit":"px","size":10},"dot_before_height":{"unit":"px","size":10},"dot_before_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":false},"dot_before_border_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"align":"center"},"elements":[],"widgetType":"heading"},{"id":"4738047","elType":"widget","settings":{"editor":"<p>The business cerrent account that is your <strong>accounting software<\/strong>. A simple way to run your bussiness lorem ipsum dolor sit amet<\/p>","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":17},"_padding":{"unit":"px","top":"0","right":"75","bottom":"65","left":"75","isLinked":false},"_padding_mobile":{"unit":"px","top":"20","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"ac8fe36","elType":"widget","settings":{"tabs":[{"tab_title":"When will the payment be processed?","tab_content":"<p>All reports will be posted on the blockchain in an encrypted format. For each smart contract, Eco will provide a private key to both the buyer and the seller, which will enable them to view the details in plain script. This makes the transaction clearly viewable on the blockchain while ensuring data privacy.<\/p>","_id":"14392c7"},{"tab_title":"How to shopping with Auros online?","tab_content":"<p>All reports will be posted on the blockchain in an encrypted format. For each smart contract, Eco will provide a private key to both the buyer and the seller, which will enable them to view the details in plain script. This makes the transaction clearly viewable on the blockchain while ensuring data privacy.<\/p>","_id":"dd963f2"},{"tab_title":"How much does every smart contract transaction cost?","tab_content":"<p>All reports will be posted on the blockchain in an encrypted format. For each smart contract, Eco will provide a private key to both the buyer and the seller, which will enable them to view the details in plain script. This makes the transaction clearly viewable on the blockchain while ensuring data privacy.<\/p>","_id":"ca5f6a9"},{"tab_title":"Is Auros similar to BAT and ADEX models?","tab_content":"<p>All reports will be posted on the blockchain in an encrypted format. For each smart contract, Eco will provide a private key to both the buyer and the seller, which will enable them to view the details in plain script. This makes the transaction clearly viewable on the blockchain while ensuring data privacy.<\/p>","_id":"eacec5c"}],"icon":"fa fa-caret-down","icon_active":"fa fa-caret-up","title_color":"#222222","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"title_padding":{"unit":"px","top":"29","right":"30","bottom":"29","left":"30","isLinked":false},"_background_background":"classic","_background_color":"#ffffff","border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":false},"border_accordion_item_color":"#efefef","border_accordion_item_radius":{"unit":"px","top":"3","right":"3","bottom":"3","left":"3","isLinked":false},"accordion_item_box_shadow_box_shadow_type":"yes","accordion_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":2,"spread":0,"color":"rgba(0,0,0,0.04)"},"border_accordion_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"border_accordion_title_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"icon_space":{"unit":"px","size":20},"content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":15},"content_typography_font_weight":"400","content_typography_line_height":{"unit":"px","size":27},"border_accordion_content_border":"solid","border_accordion_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"content_padding":{"unit":"px","top":"10","right":"65","bottom":"50","left":"65","isLinked":false},"title_padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"content_padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false}},"elements":[],"widgetType":"accordion"}],"isInner":false}],"isInner":false},{"id":"30b1efc","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1440},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin":{"unit":"px","top":"60","right":0,"bottom":"120","left":0,"isLinked":false}},"elements":[{"id":"327ca6d","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"2db4c02","elType":"widget","settings":{"title":"Other ways to get help","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":62},"_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"9eb992f","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"40","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"1976aaa","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"0947d91","elType":"widget","settings":{"icon":"opal-icon-chat-support","title_text":"Chat Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-chat-support","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"48b5ccb","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"10df48a","elType":"widget","settings":{"icon":"opal-icon-tweet-support","title_text":"Tweet Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-tweet-support","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"fec0c34","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"186c05e","elType":"widget","settings":{"icon":"opal-icon-phone-support","title_text":"Phone Consultant","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-phone-support","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"50a19b6","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"1139e2b","elType":"widget","settings":{"icon":"opal-icon-forum","title_text":"Visit Our Forum","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-forum","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"warranty-and-services":[{"id":"97c3719","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"120","right":"0","bottom":"85","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"60","right":"0","bottom":"60","left":"0","isLinked":false},"content_width":{"unit":"px","size":920}},"elements":[{"id":"b8c3b7e","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"e521b55","elType":"section","settings":{"gap":"no"},"elements":[{"id":"46479a2","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"8e116bd","elType":"widget","settings":{"title":"Warranty & Support Services\n","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"127822a","elType":"widget","settings":{"editor":"<p>Your warranty details let you know what coverage and protection you\'re entitled to for your Auros product. Find information here for all of Auros\'s warranty options. Check warranty status, renew, transfer, or register your Auros product. Or get one-time support for expired-warranty Auros products.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"e9fae36","elType":"section","settings":{"gap":"no","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"65c1d12","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"3220966","elType":"widget","settings":{"title":"Warranty Status","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"d8e9de2","elType":"widget","settings":{"editor":"<p>Is your product covered under warranty? Check its warranty status and warranty expiration date here.<br \/>Ownership Transfer<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"22","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"f8ab20b","elType":"widget","settings":{"editor":"<p>Purchased a used Auros product or moved to another country? Transfer the ownership and\/or warranty from one person to another or from one country to another.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"44","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"a9dcddf","elType":"section","settings":{"gap":"no","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"03bd932","elType":"column","settings":{"_column_size":100,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"134f5c9","elType":"widget","settings":{"title":"Retail Registration","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":24},"typography_font_weight":"600","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"b75bb6a","elType":"widget","settings":{"editor":"<p>In addition to any applicable Consumer and\/or statutory rights, the Supplier offers a manufacturer\'s guarantee. The manufacturer guarantee is that the materials and workmanship of the Goods will be free from defects for a period of 10 years from the date that the Goods were collected by the Buyer or the third party carrier. The product guarantee does not cover normal wear and tear. The 10 year guarantee is only applicable to orders placed on or after 1st March 2016, any orders placed prior to this will have a 1 year guarantee. Clearance products do not qualify for this guarantee.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"b977bc5","elType":"widget","settings":{"editor":"<p>However this entire Clause 7.1 not apply if a fault arises due to: <br \/>Abnormal use or working conditions, failure to follow instructions, misuse, alteration or unauthorised repair, wilful damage, improper maintenance or negligence on the part of the Buyer or a third party; or<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"a60698c","elType":"widget","settings":{"editor":"<p>Any subsequent mechanical, chemical, electrolytic or other damage after risk has passed to the Buyer, which is not due to a defect in the Goods.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"e12647d","elType":"widget","settings":{"editor":"<p>Where Goods are faulty the Buyer must contact us within 7 days of the discovery of the fault or within 7 days of the collection of the Goods where the Goods were faulty on collection.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"7ea7306","elType":"widget","settings":{"editor":"<p>The Buyer must supply the requested information and images in order for the Supplier to be able to deal with the Buyer\u2019s complaint. The Buyer will obtain full instructions upon notifying the Supplier of a fault.<\/p>","_padding":{"unit":"px","top":"0","right":"0","bottom":"25","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"6d172c9","elType":"widget","settings":{"editor":"<p>A claim will be compensated for at the Supplier\u2019s discretion. We reserve the right to offer a compensation. Compensation is normally paid within 28 days of the date of the Supplier\'s confirmation.<\/p>"},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"56a5756","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","padding":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_width":{"unit":"px","size":1440},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin":{"unit":"px","top":"60","right":0,"bottom":"120","left":0,"isLinked":false}},"elements":[{"id":"f14f3d5","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"d33b7ae","elType":"widget","settings":{"title":"Need a Support?","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"typography_font_weight":"600","typography_line_height":{"unit":"px","size":62},"_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"57caa8e","elType":"section","settings":{"content_width":{"unit":"px","size":1440},"gap":"no","structure":"40","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"65c281c","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"461342e","elType":"widget","settings":{"icon":"opal-icon-chat-support","title_text":"Chat Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-chat-support","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"bb80ed3","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"padding_mobile":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"dd3d4e4","elType":"widget","settings":{"icon":"opal-icon-tweet-support","title_text":"Tweet Support","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-tweet-support","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"cf389f5","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"82f4932","elType":"widget","settings":{"icon":"opal-icon-phone-support","title_text":"Phone Consultant","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-phone-support","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true},{"id":"891e518","elType":"column","settings":{"_column_size":25,"_inline_size":null,"_inline_size_tablet":50,"space_between_widgets":0,"margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"30","left":"0","isLinked":false},"margin_tablet":{"unit":"px","top":"0","right":"20","bottom":"30","left":"20","isLinked":false}},"elements":[{"id":"5f3122a","elType":"widget","settings":{"icon":"opal-icon-forum","title_text":"Visit Our Forum","description_text":"","primary_color":"#000000","icon_margin":{"unit":"px","top":"0","right":"0","bottom":"15","left":"0","isLinked":false},"icon_size":{"unit":"px","size":70},"hover_primary_color":"#f0935b","title_color_hover":"#000000","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":20},"_padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"_border_border":"solid","_border_width":{"unit":"px","top":"1","right":"1","bottom":"1","left":"1","isLinked":true},"_border_color":"#eeeeee","_box_shadow_hover_box_shadow_type":"yes","_box_shadow_hover_box_shadow":{"horizontal":7,"vertical":7,"blur":30,"spread":0.299999999999999988897769753748434595763683319091796875,"color":"rgba(0,0,0,0.1)"},"selected_icon":{"value":"fas opal-icon-forum","library":"fa-solid"}},"elements":[],"widgetType":"icon-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false}],"blog-list":[{"id":"c3172f6","elType":"section","settings":[],"elements":[{"id":"4b319e9","elType":"column","settings":{"_column_size":100},"elements":[{"id":"b0a0f05","elType":"widget","settings":{"column":"1","pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;"},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false}],"footer-02":[{"id":"ed07b09","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"20","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_color":"#eeeeee","padding":{"unit":"px","top":"50","right":"0","bottom":"50","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"50","right":"20","bottom":"50","left":"20","isLinked":false}},"elements":[{"id":"134acb2","elType":"column","settings":{"_column_size":50,"_inline_size":75,"_inline_size_tablet":50,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false}},"elements":[{"id":"8a1a9f6","elType":"widget","settings":{"align":"left","align_mobile":"center","width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"b24af20","elType":"column","settings":{"_column_size":50,"_inline_size":25,"_inline_size_tablet":50},"elements":[{"id":"978b09f","elType":"widget","settings":{"menu":"company","pointer":"none","enable_mobile_dropdown":"","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"color_menu_item":"#777777","padding_horizontal_menu_item":{"unit":"px","size":0},"padding_vertical_menu_item":{"unit":"px","size":5},"menu_space_between":{"unit":"px","size":35},"color_menu_item_hover":"#eb7025","color_menu_item_active":"#eb7025","menu-toggle-title":"Menu","align_items_mobile":"justify"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false}],"isInner":false},{"id":"e970d74","elType":"section","settings":{"structure":"30","gap":"no","padding":{"unit":"px","top":"35","right":"0","bottom":"60","left":"0","isLinked":false},"padding_tablet":{"unit":"px","top":"35","right":"0","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"35","right":"20","bottom":"10","left":"20","isLinked":false}},"elements":[{"id":"2b7fcd3","elType":"column","settings":{"_column_size":33,"_inline_size":42,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"9444a84","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska <br>United State<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"006dba4","elType":"column","settings":{"_column_size":33,"_inline_size":32.66599999999999681676854379475116729736328125,"margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"padding":{"unit":"px","top":"0","right":"30","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"2938c83","elType":"widget","settings":{"editor":"<p>907-723-4608 <br \/>Aurosfurniture@domain.vn<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"em","size":1.79000000000000003552713678800500929355621337890625},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false},{"id":"873f56a","elType":"column","settings":{"_column_size":33,"_inline_size":25},"elements":[{"id":"847459e","elType":"widget","settings":{"social_icon_list":[{"social":"fa fa-facebook","_id":"1903068","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-twitter","_id":"0c74b2e","link":{"url":"","is_external":"true","nofollow":""}},{"social":"fa fa-instagram","link":{"url":"","is_external":"true","nofollow":""},"_id":"68aff0e"},{"social":"fa fa-vk","link":{"url":"","is_external":"true","nofollow":""},"_id":"6dadf1f"}],"align":"left","shape":"circle","icon_color":"custom","icon_primary_color":"rgba(235,112,37,0)","icon_secondary_color":"#888888","icon_size":{"unit":"px","size":16},"icon_spacing":{"unit":"px","size":0},"hover_primary_color":"rgba(235,112,37,0.62)","hover_animation":"pulse","_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"-10","isLinked":false},"align_mobile":"center","_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"social-icons"}],"isInner":false}],"isInner":false},{"id":"17d2f55","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"45","right":"0","bottom":"45","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[{"id":"f2b2532","elType":"column","settings":{"_column_size":100},"elements":[{"id":"28fd8f6","elType":"widget","settings":{"editor":"<p>Copyright \u00a9 2019\u00a0<strong><span class=\"\" data-color-group=\"turquoise\">Auros.<\/span><\/strong> All rights reserved.<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"align_mobile":"center"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false}],"header-01":[{"id":"d5c6f4b","elType":"section","settings":{"gap":"no","content_position":"middle","structure":"30","padding":{"unit":"px","top":"40","right":"40","bottom":"40","left":"40","isLinked":false},"stretch_section":"section-stretched","padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":false},"padding_tablet":{"unit":"px","top":"20","right":"40","bottom":"20","left":"40","isLinked":false},"content_width":{"unit":"px","size":1710}},"elements":[{"id":"a3e191e","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":100,"_inline_size_mobile":50},"elements":[{"id":"46747b1","elType":"widget","settings":{"align":"left","align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_mobile":"left","logo_select":"customize","image_logo":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/09\/Logo.svg","id":4280},"width":{"unit":"px","size":130}},"elements":[],"widgetType":"opal-site-logo"}],"isInner":false},{"id":"3cbdbfe","elType":"column","settings":{"_column_size":33,"_inline_size":71.6640000000000014779288903810083866119384765625,"space_between_widgets":0,"_inline_size_tablet":80,"_inline_size_mobile":50},"elements":[{"id":"c1602d7","elType":"widget","settings":{"indicator":"angle","subMenusMinWidth":{"unit":"px","size":270},"dropdown":"mobile","toggle_align":"right","menu_typography_typography":"custom","menu_typography_font_size":{"unit":"px","size":14},"menu_typography_font_weight":"600","menu_typography_text_transform":"capitalize","menu_typography_line_height":{"unit":"px","size":""},"color_menu_item":"#222222","color_menu_item_hover":"#222222","color_menu_item_active":"#222222","padding_horizontal_menu_item":{"unit":"px","size":10},"padding_vertical_menu_item":{"unit":"px","size":0},"menu_space_between":{"unit":"px","size":15},"dropdown_box_shadow_box_shadow_type":"yes","dropdown_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":30,"spread":0,"color":"rgba(0,0,0,0.05)"},"padding_horizontal_dropdown_item":{"unit":"px","size":20},"padding_vertical_dropdown_item":{"unit":"px","size":10},"dropdown_top_distance":{"unit":"px","size":10},"toggle_color":"#000000","toggle_background_color":"rgba(197,156,108,0)","toggle_color_hover":"#eb7025","toggle_size":{"unit":"px","size":17},"toggle_border_width":{"unit":"px","size":0},"toggle_border_radius":{"unit":"px","size":5},"color_dropdown_item_hover":"#eb7025","background_color_dropdown_item_hover":"rgba(34,34,34,0.1)","dropdown_typography_text_transform":"capitalize","padding_horizontal_dropdown_item_mobile":{"unit":"px","size":20},"padding_vertical_dropdown_item_mobile":{"unit":"px","size":5},"animation_line":"grow","pointer_color_menu_item_hover":"#35e1db","pointer_color_menu_item_active":"#35e1db","pointer_width":{"unit":"px","size":3},"padding_vertical_menu_item_tablet":{"unit":"px","size":8},"menu":"main-menu","content_delay_time":"0.50","width_dropdown_mobile":{"unit":"px","size":290},"color_dropdown_item":"#494c4f","wave_show_1":"","wave_color_1":"","wave_bones_1":3,"wave_animate_1":0.25,"wave_height_1":60,"wave_amplitude_1":40,"wave_show_2":"","wave_color_2":"","wave_bones_2":3,"wave_animate_2":0.25,"wave_height_2":60,"wave_amplitude_2":40,"wave_show_3":"","wave_color_3":"","wave_bones_3":3,"wave_animate_3":0.25,"wave_height_3":60,"wave_amplitude_3":40,"section_delay_on":"","scheduled_content_on":"","schedule_start_date":"","schedule_end_date":"01\/01\/2019 00:00:00","pointer":"none","menu_item_box_shadow_box_shadow_type":"yes","menu_item_box_shadow_box_shadow":{"horizontal":0,"vertical":0,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_box_shadow_position":"inset","menu_item_box_shadow_hover_box_shadow_type":"yes","menu_item_box_shadow_hover_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_hover_box_shadow_position":"inset","menu_item_box_shadow_active_box_shadow_type":"yes","menu_item_box_shadow_active_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"menu_item_box_shadow_active_box_shadow_position":"inset","menu-toggle-title":"","full_width":"stretch","toggle_align_mobile":"right","dropdown_layout":"canvas"},"elements":[],"widgetType":"opal-nav-menu"}],"isInner":false},{"id":"747ac74","elType":"column","settings":{"_column_size":33,"_inline_size":14,"space_between_widgets":0,"_inline_size_tablet":20,"_inline_size_mobile":100},"elements":[{"id":"4406c80","elType":"widget","settings":{"show_search":"yes","show_account":"yes","show_cart":"yes","title_wishtlist_hover":"View wishlist ","skin":"full_screen","placeholder":"","button_text":"Search","toggle_size":{"unit":"px","size":20},"show_icon_account":"yes","text_account":"","config_account_margin":{"unit":"px","top":"0","right":"25","bottom":"0","left":"25","isLinked":false},"title_cart":"","title_cart_hover":"","show_count":"yes","cart_align":"justify-content-center","input_text_color":"#ffffff","input_border_color":"#ffffff","button_border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_radius":{"unit":"px","size":0},"toggle_color":"#000000","toggle_background_color":"rgba(0,0,0,0)","toggle_color_hover":"#eb7025","toggle_icon_size":{"unit":"px","size":100},"name_text_color":"#000000","name_text_hover_color":"#eb7025","icon_color":"#000000","icon_hover_color":"#eb7025","icon_account_size":{"unit":"px","size":20},"cart_background_color":"rgba(0,0,0,0)","cart_background_hover_color":"rgba(0,0,0,0)","text_padding_cart":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_cart_color":"#000000","icon_cart_hover_color":"#eb7025","icon_cart_size":{"unit":"px","size":20},"icon_cart_spacing":{"unit":"px","size":0},"cart_title_spacing":{"unit":"px","size":0},"count_color":"#ffffff","count_background_color":"#eb7025","count_font_size":{"unit":"px","size":8},"count_size":{"unit":"px","size":10},"count_border_radius":{"unit":"px","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"count_padding":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"count_margin":{"unit":"px","top":"-15","right":"0","bottom":"0","left":"-1","isLinked":false},"hide_mobile":"hidden-phone"},"elements":[],"widgetType":"opal-header-group"}],"isInner":false}],"isInner":false}],"404-page":[{"id":"ded2ec7","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"55","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[{"id":"6417725","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"01d486f","elType":"widget","settings":{"title":"404","align":"center","typography_typography":"custom","typography_font_size":{"unit":"px","size":160},"typography_font_size_mobile":{"unit":"px","size":100}},"elements":[],"widgetType":"heading"},{"id":"197a575","elType":"widget","settings":{"title":"Not Found","header_size":"div","align":"center","title_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":36},"typography_font_weight":"300","_padding":{"unit":"px","top":"30","right":"0","bottom":"30","left":"0","isLinked":false},"typography_font_size_mobile":{"unit":"px","size":28}},"elements":[],"widgetType":"heading"},{"id":"4e8530e","elType":"widget","settings":{"weight":{"unit":"px","size":3},"color":"#666666","width":{"unit":"px","size":100},"align":"center","gap":{"unit":"px","size":2}},"elements":[],"widgetType":"divider"},{"id":"eb195c8","elType":"widget","settings":{"editor":"<p>It looks like nothing was found at this location. Maybe try a search?<\/p>","align":"center","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":20},"_margin":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_padding":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true},"typography_font_size_mobile":{"unit":"px","size":18}},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"21a8e2b","elType":"section","settings":{"structure":"20","margin":{"unit":"px","top":"10","right":0,"bottom":"100","left":0,"isLinked":false}},"elements":[{"id":"3c6246b","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100},"elements":[{"id":"352b0a7","elType":"widget","settings":{"text":"Go back to previous page","link":{"url":"javascript: history.go(-1)","is_external":"","nofollow":""},"align":"right","size":"md","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"em","size":1.8000000000000000444089209850062616169452667236328125},"typography_letter_spacing":{"unit":"px","size":5},"background_color":"#e43636","button_background_hover_color":"#000000","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_tablet":"center","typography_letter_spacing_mobile":{"unit":"px","size":1},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"button"}],"isInner":false},{"id":"c575c46","elType":"column","settings":{"_column_size":50,"_inline_size":null,"_inline_size_tablet":100},"elements":[{"id":"ad6acad","elType":"widget","settings":{"text":"Return to homepage","link":{"url":"https:\/\/demo1.wpopal.com\/strollik\/","is_external":"","nofollow":""},"align":"left","size":"md","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_font_weight":"500","typography_text_transform":"uppercase","typography_line_height":{"unit":"em","size":1.8000000000000000444089209850062616169452667236328125},"typography_letter_spacing":{"unit":"px","size":5},"background_color":"#e43636","button_background_hover_color":"#000000","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_padding":{"unit":"px","top":"20","right":"0","bottom":"20","left":"0","isLinked":false},"_border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"align_tablet":"center","typography_letter_spacing_mobile":{"unit":"px","size":1},"_padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true}},"elements":[],"widgetType":"button"}],"isInner":false}],"isInner":false}],"home-page":[{"id":"4a17baa","elType":"section","settings":{"gap":"no","stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"f8d05b3","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"_inline_size":null},"elements":[{"id":"5ba2039","elType":"widget","settings":{"rev_alias":"home1"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"9b653bb","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","structure":"20","content_width":{"unit":"px","size":1710},"padding_tablet":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"40","right":"20","bottom":"40","left":"20","isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"content_delay_time":"0.50"},"elements":[{"id":"22815ff","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"40","right":"20","bottom":"0","left":"0","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"bbc84df","elType":"widget","settings":{"categories":"stools","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_cate1.jpg","id":1414},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"0","right":"0","bottom":"42","left":"50","isLinked":false},"button_text":"View Collection","_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"40","left":"0","isLinked":false},"category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false},{"id":"e7e37af","elType":"column","settings":{"_column_size":50,"_inline_size":null,"space_between_widgets":0,"padding":{"unit":"px","top":"40","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","animation_delay":200},"elements":[{"id":"d2d6260","elType":"widget","settings":{"categories":"sofas","category_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/home1_cate2.jpg","id":1415},"text_align_h":"left","text_align_v":"flex-end","category_name_typography_typography":"custom","category_name_typography_font_size":{"unit":"px","size":34},"category_name_typography_font_weight":"600","text_padding":{"unit":"px","top":"0","right":"0","bottom":"42","left":"50","isLinked":false},"_padding":{"unit":"em","top":"","right":"","bottom":"","left":"","isLinked":true},"button_text":"View Collection","category_name_color":"#222222","category_name_color_hover":"#eb7025"},"elements":[],"widgetType":"opal-product-categories"}],"isInner":false}],"isInner":false},{"id":"163c072","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"130","right":0,"bottom":"0","left":0,"isLinked":false},"margin_tablet":{"unit":"px","top":"100","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"fbdeb74","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"0eb223f","elType":"widget","settings":{"title":"Trending This Week","align":"center","title_color":"#000000","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"7937c6f","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","typography_typography":"custom"},"elements":[],"widgetType":"text-editor"},{"id":"ff43d76","elType":"widget","settings":{"limit":4,"column":"4","categories":["stools"],"_padding":{"unit":"px","top":"60","right":"0","bottom":"0","left":"0","isLinked":false},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"opal-products"},{"id":"a84463f","elType":"widget","settings":{"text":"+ See All Products","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_font_weight":"600","button_text_color":"#222222","background_color":"rgba(0,0,0,0)","text_padding":{"unit":"px","top":"0","right":"10","bottom":"5","left":"5","isLinked":false},"_z_index":1,"button_box_shadow_box_shadow_type":"yes","button_box_shadow_box_shadow":{"horizontal":0,"vertical":-9,"blur":0,"spread":0,"color":"#f9d4bd"},"border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"button_box_shadow_box_shadow_position":"inset","link":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/shop","is_external":"on","nofollow":""},"align":"center","typography_letter_spacing":{"unit":"px","size":0.5},"_background_background":"classic","_padding":{"unit":"px","top":"22","right":"0","bottom":"72","left":"0","isLinked":false},"hover_animation":"grow","_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"button"},{"id":"55dc090","elType":"widget","settings":{"color":"#eeeeee","text":"Divider"},"elements":[],"widgetType":"divider"}],"isInner":false}],"isInner":false},{"id":"27aa53d","elType":"section","settings":{"gap":"no","margin":{"unit":"px","top":"65","right":0,"bottom":"0","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"e1bbe6b","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"44b14e4","elType":"widget","settings":{"title":"New Design","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_margin":{"unit":"px","top":"0","right":"0","bottom":"-40","left":"0","isLinked":false},"align_tablet":"center","_margin_tablet":{"unit":"px","top":"0","right":"0","bottom":"20","left":"0","isLinked":false},"_padding":{"unit":"%","top":"0","right":"50","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"},{"id":"b023ca9","elType":"widget","settings":{"tabs":[{"tab_title":"All","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"ac6196c","tab_template":"2184"},{"tab_title":"Furnitures","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"08344e0","tab_template":"1983"},{"tab_title":"Chairs          ","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"3169eda","tab_template":"2100"},{"tab_title":"Lighting","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"6c7f10b","tab_template":"2130"},{"tab_title":"Decor","source":"template","tab_html":"<p>I am tab content. Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.<\/p>","_id":"98378fe","tab_template":"2141"}],"align_items":"flex-end","title_color":"#777777","title_active_color":"#777777","border_tabs_title_border":"solid","border_tabs_title_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"tab_title_padding":{"unit":"px","top":"0","right":"6","bottom":"0","left":"6","isLinked":false},"tab_title_margin":{"unit":"px","top":"10","right":"15","bottom":"10","left":"15","isLinked":false},"border_content_border":"solid","border_content_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"padding":{"unit":"px","top":"65","right":"0","bottom":"0","left":"0","isLinked":false},"title_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_box_shadow_box_shadow_position":"inset","title_hover_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_hover_box_shadow_box_shadow_position":"inset","title_active_box_shadow_box_shadow_type":"yes","title_active_box_shadow_box_shadow":{"horizontal":0,"vertical":-6,"blur":0,"spread":0,"color":"rgba(235,112,37,0.3)"},"title_active_box_shadow_box_shadow_position":"inset","align_items_tablet":"center","title_hover_box_shadow_box_shadow_type":"yes","padding_tablet":{"unit":"px","top":"40","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-tabs"}],"isInner":false}],"isInner":false},{"id":"f1a95cb","elType":"section","settings":{"stretch_section":"section-stretched","gap":"no","content_width":{"unit":"px","size":1710},"margin":{"unit":"px","top":"80","right":0,"bottom":"0","left":0,"isLinked":false},"padding":{"unit":"px","top":"0","right":"40","bottom":"0","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"5283b52","elType":"column","settings":{"_column_size":100,"space_between_widgets":0},"elements":[{"id":"8ae6ed1","elType":"widget","settings":{"rev_alias":"home1_slider2"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"0be9206","elType":"section","settings":{"gap":"no","padding":{"unit":"px","top":"130","right":"0","bottom":"0","left":"0","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"0f35fb8","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"b6032c9","elType":"widget","settings":{"title":"Our Blogs","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":40},"typography_line_height":{"unit":"px","size":50},"_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"99a278f","elType":"widget","settings":{"editor":"<p>Find a bright ideal to suit your taste with our great selection of suspension, wall, floor and table lights.<\/p>","align":"center","_padding":{"unit":"px","top":"0","right":"0","bottom":"60","left":"0","isLinked":false}},"elements":[],"widgetType":"text-editor"},{"id":"07ad555","elType":"widget","settings":{"pagination_page_limit":"5","pagination_prev_label":"&laquo; Previous","pagination_next_label":"Next &raquo;","posts_per_page":3},"elements":[],"widgetType":"opal-post-grid"}],"isInner":false}],"isInner":false},{"id":"429762f","elType":"section","settings":{"gap":"no","background_background":"classic","margin":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true},"stretch_section":"section-stretched","content_width":{"unit":"px","size":1710},"content_position":"middle","padding":{"unit":"px","top":"60","right":"40","bottom":"15","left":"40","isLinked":false},"padding_mobile":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-up","animation_duration":"fast","content_delay_time":"0.50"},"elements":[{"id":"7c3fed3","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"background_background":"classic","background_color":"#ffd8d4","padding":{"unit":"px","top":"100","right":"30","bottom":"100","left":"30","isLinked":false},"padding_mobile":{"unit":"px","top":"60","right":"15","bottom":"60","left":"15","isLinked":false}},"elements":[{"id":"9bdd9c0","elType":"widget","settings":{"testimonials":[{"testimonial_content":"Very good Design. Flexible. Fast Support.   ","testimonial_image":{"url":"","id":""},"testimonial_name":"Steve John ","testimonial_job":"(customer)","_id":"c44e6a2"}],"job_text_color":"#000000","setting_job_inline":"yes","testimonial_layout":"layout_2","content_content_color":"#222222","content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":30},"content_typography_font_weight":"600","name_text_color":"#222222","name_typography_typography":"custom","name_typography_font_size":{"unit":"px","size":20},"name_typography_font_weight":"normal","name_margin":{"unit":"px","top":"0","right":"7","bottom":"0","left":"22","isLinked":false},"name_divider":"yes","setting_divider":"#000000","spacing_line":{"unit":"px","size":10},"job_typography_typography":"custom","job_typography_font_size":{"unit":"px","size":14},"job_typography_font_weight":"normal","job_typography_font_style":"italic","content_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"_margin":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"_padding":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"width_content":{"unit":"%","size":""},"width_content_tablet":{"unit":"%","size":55},"width_content_mobile":{"unit":"%","size":100},"content_typography_line_height":{"unit":"px","size":50},"content_typography_line_height_mobile":{"unit":"px","size":40},"content_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"name_typography_line_height":{"unit":"px","size":""},"name_margin_mobile":{"unit":"px","top":"0","right":"7","bottom":"0","left":"0","isLinked":false},"width_divider_mobile":{"unit":"px","size":0},"height_divider_mobile":{"unit":"px","size":0},"spacing_line_mobile":{"unit":"px","size":0},"job_typography_line_height":{"unit":"px","size":""}},"elements":[],"widgetType":"opal-testimonials"}],"isInner":false}],"isInner":false}],"about-us":[{"id":"67b8099","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"margin":{"unit":"px","top":"80","right":0,"bottom":"80","left":0,"isLinked":true}},"elements":[{"id":"4e0b897","elType":"column","settings":{"_column_size":100},"elements":[{"id":"b19034e","elType":"widget","settings":{"title":"Auros - Powerful Theme for Shop","align":"left","title_color":"#222222","typography_typography":"custom","_animation":"fadeInUp","typography_font_size_mobile":{"unit":"px","size":26}},"elements":[],"widgetType":"heading"},{"id":"744f424","elType":"widget","settings":{"editor":"<p>Auros curates a selection of objects focused on quality, minimalism, and functionality. Our mission is to provide a unique set of products that fascinate and inspire the user. We review each product, down to its packaging, to ensure that we continuously provide the best in both quality and design.<\/p><p><em>Our selection of products are designed and imported from all over the world. Whether from Denmark or Japan, some of these items have never received exposure in the United States. In addition, we are the exclusive North American distributor for a number of brands found within our store.<\/em><\/p><p>We\'re happy to help. If you have any questions regarding a product or an order, please feel free to reach out to us at info@domain.com.<\/p>","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":15},"_animation":"fadeInUp"},"elements":[],"widgetType":"text-editor"}],"isInner":false}],"isInner":false},{"id":"dba616d","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"structure":"20","margin_tablet":{"unit":"px","top":"","right":0,"bottom":"","left":0,"isLinked":true}},"elements":[{"id":"61b4377","elType":"column","settings":{"_column_size":50,"_inline_size":null,"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"47592ca","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/bannerau-1.jpg","id":3284},"_animation":"fadeInLeft"},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"ca6d932","elType":"column","settings":{"_column_size":50,"_inline_size":null,"animation":"opal-move-left","animation_duration":"fast"},"elements":[{"id":"5d21fc3","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/bannerau-2.jpg","id":3285},"_animation":"fadeInRight"},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false},{"id":"b225e54","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"margin":{"unit":"px","top":"100","right":0,"bottom":"100","left":0,"isLinked":true}},"elements":[{"id":"ca42837","elType":"column","settings":{"_column_size":100},"elements":[{"id":"0312e00","elType":"widget","settings":{"title":"Why Us?","align":"center","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":48},"_padding":{"unit":"px","top":"0","right":"0","bottom":"10","left":"0","isLinked":false},"_animation":"opal-move-up","typography_font_size_mobile":{"unit":"px","size":26},"animation_duration":"fast"},"elements":[],"widgetType":"heading"},{"id":"a6731d5","elType":"section","settings":{"structure":"30"},"elements":[{"id":"d887348","elType":"column","settings":{"_column_size":33,"_inline_size":null},"elements":[{"id":"982ceac","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/Ico_Chat-Support-1.svg","id":3290},"title_text":"24\/7 Support","description_text":"Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. ","svg_size":{"unit":"px","size":60},"title_color":"#222222","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14},"_animation":"opal-move-right","animation_duration":"fast"},"elements":[],"widgetType":"image-box"}],"isInner":true},{"id":"1179cfc","elType":"column","settings":{"_column_size":33,"_inline_size":null},"elements":[{"id":"a587c71","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/Ico_Ship2.svg","id":3291},"title_text":"Free Shipping","description_text":"Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. ","svg_size":{"unit":"px","size":60},"title_color":"#222222","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14},"_animation":"opal-move-up","animation_duration":"fast"},"elements":[],"widgetType":"image-box"}],"isInner":true},{"id":"e93f152","elType":"column","settings":{"_column_size":33,"_inline_size":null},"elements":[{"id":"3896a37","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/Ico_Refund.svg","id":3292},"title_text":"Refund Anytime","description_text":"Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum. ","svg_size":{"unit":"px","size":60},"title_color":"#222222","title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":18},"description_typography_typography":"custom","description_typography_font_size":{"unit":"px","size":14},"_animation":"opal-move-left","animation_duration":"fast"},"elements":[],"widgetType":"image-box"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"f54374d","elType":"section","settings":{"background_background":"classic","background_image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/bannerau-3.jpg","id":3295},"stretch_section":"section-stretched","layout":"full_width","gap":"no","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"7c7fb73","elType":"column","settings":{"_column_size":100},"elements":[{"id":"8cdd211","elType":"widget","settings":{"video_link":"https:\/\/www.youtube.com\/watch?v=Kg2HOk1XHsA","video_align":"center","icon_font":"fa fa-play","video_size":{"unit":"px","size":32},"video_width":{"unit":"px","size":60},"video_height":{"unit":"px","size":60},"video_color":"#c9c9c9","video_background_color":"#ffffff","video_border_radius":{"unit":"%","top":"50","right":"50","bottom":"50","left":"50","isLinked":true},"_padding":{"unit":"px","top":"300","right":"0","bottom":"300","left":"0","isLinked":false}},"elements":[],"widgetType":"opal-video-popup"}],"isInner":false}],"isInner":false},{"id":"959122f","elType":"section","settings":{"stretch_section":"section-stretched","layout":"full_width","animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"6e569c7","elType":"column","settings":{"_column_size":100},"elements":[{"id":"8c826f0","elType":"widget","settings":{"rev_alias":"about_us"},"elements":[],"widgetType":"opal-revslider"}],"isInner":false}],"isInner":false},{"id":"a7b734f","elType":"section","settings":{"content_width":{"unit":"px","size":1170},"gap":"no","structure":"50","margin":{"unit":"px","top":"40","right":0,"bottom":"100","left":0,"isLinked":false},"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"3d64777","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"a833e9e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-1.png","id":1821},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"fadeInUp","_animation_delay":100},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"f553c0e","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"1f0bb9a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-2.png","id":1822},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"fadeInUp","_animation_delay":200},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"a875130","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"d3c750a","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-3.png","id":1823},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"fadeInUp","_animation_delay":300},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"b24fd14","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"b531052","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-4.png","id":1824},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"fadeInUp","_animation_delay":400},"elements":[],"widgetType":"image"}],"isInner":false},{"id":"096273c","elType":"column","settings":{"_column_size":20,"_inline_size":null,"space_between_widgets":0},"elements":[{"id":"4bfa63e","elType":"widget","settings":{"image":{"url":"https:\/\/demo2wpopal.b-cdn.net\/auros\/wp-content\/uploads\/2018\/10\/brand-5.png","id":1825},"image_size":"full","align":"center","hover_animation":"grow","_margin":{"unit":"px","top":"0","right":"20","bottom":"0","left":"20","isLinked":false},"_animation":"fadeInUp","_animation_delay":500},"elements":[],"widgetType":"image"}],"isInner":false}],"isInner":false}],"contact-us":[{"id":"64cf89e","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"gap":"no","structure":"20","margin":{"unit":"px","top":"70","right":0,"bottom":"0","left":0,"isLinked":false}},"elements":[{"id":"d115863","elType":"column","settings":{"_column_size":50,"_inline_size":31.120999999999998664179656771011650562286376953125,"space_between_widgets":0,"animation":"opal-move-right","animation_duration":"fast"},"elements":[{"id":"03ec63f","elType":"widget","settings":{"editor":"<p>contact<\/p>","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2}},"elements":[],"widgetType":"text-editor"},{"id":"993ee0e","elType":"widget","settings":{"title":"Infomation","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_text_transform":"uppercase","_padding":{"unit":"px","top":"5","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"a348646","elType":"column","settings":{"_column_size":50,"_inline_size":68.8790000000000048885340220294892787933349609375,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"0","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"e550d3b","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20"},"elements":[{"id":"071927a","elType":"column","settings":{"_column_size":50,"_inline_size":9.135999999999999232613845379091799259185791015625,"_inline_size_mobile":25,"space_between_widgets":0},"elements":[{"id":"70e095e","elType":"widget","settings":{"editor":"<p>add:<\/p>","align":"left","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","typography_text_transform":"capitalize"},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"9c0b5d3","elType":"column","settings":{"_column_size":50,"_inline_size":90.8599999999999994315658113919198513031005859375,"_inline_size_mobile":75,"space_between_widgets":0},"elements":[{"id":"6010340","elType":"widget","settings":{"editor":"<p>2593 Timbercrest Road, Chisana, Alaska Badalas United State<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":14}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"bd9aefa","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20","padding":{"unit":"px","top":"10","right":"0","bottom":"10","left":"0","isLinked":false}},"elements":[{"id":"010bf4e","elType":"column","settings":{"_column_size":50,"_inline_size":9.135999999999999232613845379091799259185791015625,"_inline_size_mobile":25,"space_between_widgets":0},"elements":[{"id":"f3bc66a","elType":"widget","settings":{"editor":"<p>Phone:<\/p>","align":"left","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","typography_text_transform":"capitalize"},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"832c3ad","elType":"column","settings":{"_column_size":50,"_inline_size":90.8599999999999994315658113919198513031005859375,"_inline_size_mobile":75,"space_between_widgets":0},"elements":[{"id":"08c932f","elType":"widget","settings":{"editor":"<p>(+91)7-723-4608<\/p>","text_color":"#777777","typography_typography":"custom","typography_font_size":{"unit":"px","size":14}},"elements":[],"widgetType":"text-editor"}],"isInner":true}],"isInner":true},{"id":"ea3ad31","elType":"section","settings":{"gap":"no","content_position":"top","structure":"20"},"elements":[{"id":"f9ac6d2","elType":"column","settings":{"_column_size":50,"_inline_size":9.135999999999999232613845379091799259185791015625,"_inline_size_mobile":25,"space_between_widgets":0},"elements":[{"id":"caf46a8","elType":"widget","settings":{"editor":"<p>Mail:<\/p>","align":"left","text_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":16},"typography_font_weight":"600","typography_text_transform":"capitalize"},"elements":[],"widgetType":"text-editor"}],"isInner":true},{"id":"423158e","elType":"column","settings":{"_column_size":50,"_inline_size":90.8599999999999994315658113919198513031005859375,"_inline_size_mobile":75,"space_between_widgets":0},"elements":[{"id":"765ff28","elType":"widget","settings":{"text":"Aurosfurniture@domain.vn","typography_typography":"custom","typography_font_size":{"unit":"px","size":14},"typography_line_height":{"unit":"px","size":""},"button_text_color":"#777777","background_color":"rgba(0,0,0,0)","hover_color":"#eb7025","button_hover_border_color":"#eb7025","border_border":"solid","border_width":{"unit":"px","top":"0","right":"0","bottom":"2","left":"0","isLinked":false},"border_color":"#f9d4bd","border_radius":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"text_padding":{"unit":"px","top":"0","right":"0","bottom":"3","left":"0","isLinked":false},"align_mobile":"left"},"elements":[],"widgetType":"button"}],"isInner":true}],"isInner":true}],"isInner":false}],"isInner":false},{"id":"da299af","elType":"section","settings":{"content_width":{"unit":"px","size":1160},"gap":"no","structure":"20","margin":{"unit":"px","top":"115","right":0,"bottom":"135","left":0,"isLinked":false},"margin_mobile":{"unit":"px","top":"50","right":0,"bottom":"50","left":0,"isLinked":true}},"elements":[{"id":"53dc52d","elType":"column","settings":{"_column_size":50,"_inline_size":31.120999999999998664179656771011650562286376953125,"space_between_widgets":0,"animation":"opal-move-right"},"elements":[{"id":"099c74a","elType":"widget","settings":{"editor":"<p>contact<\/p>","text_color":"#666666","typography_typography":"custom","typography_font_size":{"unit":"px","size":12},"typography_text_transform":"uppercase","typography_letter_spacing":{"unit":"px","size":2}},"elements":[],"widgetType":"text-editor"},{"id":"877d7e2","elType":"widget","settings":{"title":"Drop us a line","title_color":"#222222","typography_typography":"custom","typography_font_size":{"unit":"px","size":26},"typography_text_transform":"uppercase","text_shadow_text_shadow_type":"yes","text_shadow_text_shadow":{"horizontal":0,"vertical":0,"blur":0,"color":"rgba(0,0,0,0.3)"},"_padding":{"unit":"px","top":"5","right":"0","bottom":"0","left":"0","isLinked":false}},"elements":[],"widgetType":"heading"}],"isInner":false},{"id":"e94a58d","elType":"column","settings":{"_column_size":50,"_inline_size":68.8790000000000048885340220294892787933349609375,"space_between_widgets":0,"padding_tablet":{"unit":"px","top":"0","right":"0","bottom":"0","left":"20","isLinked":false},"padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"0","left":"20","isLinked":false},"animation":"opal-move-left","animation_duration":"fast","animation_delay":200},"elements":[{"id":"ccb37a1","elType":"widget","settings":{"cf_id":"5","form_name":"Contact form","input_typography_font_weight":"400","input_typography_line_height":{"unit":"px","size":""},"button_typography_typography":"custom","button_typography_font_size":{"unit":"px","size":14},"button_typography_font_weight":"600","button_text_color":"#ffffff","background_color":"#222222","button_background_hover_color":"#ffffff","button_hover_border_color":"#000000","input_typography_typography":"custom","text_padding":{"unit":"px","top":"14","right":"28","bottom":"14","left":"28","isLinked":false},"label_typography_typography":"custom","border_border":"solid","hover_color":"#000000","border_width":{"unit":"px","top":"2","right":"2","bottom":"2","left":"2","isLinked":true},"border_color":"#222222","input_background_color":"rgba(0,0,0,0)","border_input_border":"solid","border_input_width":{"unit":"px","top":"0","right":"0","bottom":"1","left":"0","isLinked":false},"border_input_color":"#222222","input_padding":{"unit":"px","top":"5","right":"0","bottom":"5","left":"0","isLinked":false},"input_margin":{"unit":"px","top":"10","right":"0","bottom":"60","left":"0","isLinked":false},"_margin":{"unit":"px","top":"0","right":"0","bottom":"115","left":"0","isLinked":false},"input_padding_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"input_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"text_margin":{"unit":"px","top":"15","right":"0","bottom":"0","left":"0","isLinked":false},"_margin_mobile":{"unit":"px","top":"0","right":"0","bottom":"50","left":"0","isLinked":false},"label_typography_font_size":{"unit":"px","size":16},"label_typography_font_weight":"600","input_typography_font_size":{"unit":"px","size":16}},"elements":[],"widgetType":"opal-contactform7"},{"id":"c66a7d7","elType":"widget","settings":{"address":"London Eye, London, United Kingdom","_animation":"opal-scale-up","animation_duration":"fast","_animation_delay":300},"elements":[],"widgetType":"google_maps"}],"isInner":false}],"isInner":false}],"faq":[{"id":"bba43ed","elType":"section","settings":{"gap":"no","content_width":{"unit":"px","size":920},"margin":{"unit":"px","top":"70","right":0,"bottom":"140","left":0,"isLinked":false}},"elements":[{"id":"e1d0703","elType":"column","settings":{"_column_size":100,"space_between_widgets":0,"animation":"opal-move-up","animation_duration":"fast"},"elements":[{"id":"b4dbf8e","elType":"widget","settings":{"tabs":[{"tab_title":"How to shopping with Auros online?","tab_content":"<p><span style=\"font-size: 16px; font-weight: bold; color: #222222;\">Add items to your bag:<\/span><\/p><ol><li>Ensure you are on the website.<\/li><li>Browse the categories across the top navigation bar which includes New In, Clothing, Bags &amp; Accessories, Shoes, Collections, Stores, and Sale.<\/li><li>Once you have found an item to purchase, select your preferred colour, size (if applicable) and the quantity you wish to purchase then simply click \u2018ADD TO CART\u2019.<\/li><li>You can then continue shopping or click \u2018CHECKOUT\u2019 to review the items in your bag and to finalise your order.<\/li><\/ol><p><span style=\"font-size: 16px; font-weight: bold; color: #222222;\">Proceed to purchasing items:<\/span><\/p><ol><li>Once you have finished browsing and have added the items you wish to purchase to your bag, click<br \/>the \u2018CHECKOUT\u2019 button located at the top right of the website.<\/li><li>Within the checkout you can also amend the quantity selected for each item or delete unwanted<br \/>by simply clicking the \u2018EDIT\u2019 button that is located on the right hand side within the Order Overview<br \/>section of the checkout. Your amendments will be updated and allow you to proceed with the<br \/>checkout process.<\/li><\/ol>","_id":"f064cac"},{"tab_title":"Delivery Infomation","tab_content":"<p>A wonderful serenity has taken possession of my entire soul, like these sweet mornings of spring which I enjoy with my whole heart. I am alone, and feel the charm of existence in this spot, which was created for the bliss of souls like mine. I am so happy, my dear friend, so absorbed in the exquisite sense of mere tranquil existence, that I neglect my talents. I should be incapable of drawing a single stroke at the present moment; and yet I feel that I never was a greater artist than now.<\/p>","_id":"0b96a01"}],"title_typography_typography":"custom","title_typography_font_size":{"unit":"px","size":16},"title_background":"#222222","title_color":"#ffffff","content_padding":{"unit":"px","top":"30","right":"65","bottom":"30","left":"65","isLinked":false},"border_accordion_item_border":"solid","border_accordion_item_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":true},"icon_space":{"unit":"px","size":30},"content_typography_typography":"custom","content_typography_font_size":{"unit":"px","size":14},"content_typography_font_weight":"400","_border_width":{"unit":"px","top":"0","right":"0","bottom":"0","left":"0","isLinked":false},"content_padding_mobile":{"unit":"px","top":"20","right":"20","bottom":"20","left":"20","isLinked":true}},"elements":[],"widgetType":"accordion"}],"isInner":false}],"isInner":false}],"cart":null}', true);
    }
}

return new OSF_Import();
